@@ -36,8 +36,7 @@
 #define _D_ABSTRACT_BT_MESSAGE_H_
 
 #include "BtMessage.h"
-
-#include <deque>
+#include "Command.h"
 
 namespace aria2 {
 
@@ -51,78 +50,113 @@ class BtMessageValidator;
 class Logger;
 
 class AbstractBtMessage : public BtMessage {
+private:
+  bool sendingInProgress_;
+  bool invalidate_;
+  bool uploading_;
+  cuid_t cuid_;
+
+  std::string name_;
+
+  SharedHandle<PieceStorage> pieceStorage_;
+
+  SharedHandle<Peer> peer_;
+
+  WeakHandle<BtMessageDispatcher> dispatcher_;
+
+  WeakHandle<BtMessageFactory> messageFactory_;
+
+  WeakHandle<BtRequestFactory> requestFactory_;
+
+  WeakHandle<PeerConnection> peerConnection_;
+
+  SharedHandle<BtMessageValidator> validator_;
+
+  bool metadataGetMode_;
+
+  Logger* logger_;
 protected:
-  bool sendingInProgress;
-  bool invalidate;
-  bool uploading;
-  int32_t cuid;
+  Logger* getLogger() const
+  {
+    return logger_;
+  }
 
-  std::string _name;
+  const SharedHandle<PieceStorage>& getPieceStorage() const
+  {
+    return pieceStorage_;
+  }
 
-  SharedHandle<PieceStorage> pieceStorage;
+  const WeakHandle<PeerConnection>& getPeerConnection() const
+  {
+    return peerConnection_;
+  }
 
-  SharedHandle<Peer> peer;
+  const WeakHandle<BtMessageDispatcher>& getBtMessageDispatcher() const
+  {
+    return dispatcher_;
+  }
 
-  WeakHandle<BtMessageDispatcher> dispatcher;
+  const WeakHandle<BtRequestFactory>& getBtRequestFactory() const
+  {
+    return requestFactory_;
+  }
 
-  WeakHandle<BtMessageFactory> messageFactory;
+  const WeakHandle<BtMessageFactory>& getBtMessageFactory() const
+  {
+    return messageFactory_;
+  }
 
-  WeakHandle<BtRequestFactory> requestFactory;
-
-  WeakHandle<PeerConnection> peerConnection;
-
-  SharedHandle<BtMessageValidator> validator;
-
-  bool _metadataGetMode;
-
-  Logger* logger;
+  bool isMetadataGetMode() const
+  {
+    return metadataGetMode_;
+  }
 public:
   AbstractBtMessage(uint8_t id, const std::string& name);
 
   virtual ~AbstractBtMessage();
 
   virtual bool isSendingInProgress() {
-    return sendingInProgress;
+    return sendingInProgress_;
   }
 
   void setSendingInProgress(bool sendingInProgress) {
-    this->sendingInProgress = sendingInProgress;
+    sendingInProgress_ = sendingInProgress;
   }
 
   virtual bool isInvalidate() {
-    return invalidate;
+    return invalidate_;
   }
 
   void setInvalidate(bool invalidate) {
-    this->invalidate = invalidate;
+    invalidate_ = invalidate;
   }
 
   virtual bool isUploading() {
-    return uploading;
+    return uploading_;
   }
 
   void setUploading(bool uploading) {
-    this->uploading = uploading;
+    uploading_ = uploading;
   }
 
-  int32_t getCuid() const {
-    return cuid;
+  cuid_t getCuid() const {
+    return cuid_;
   }
 
-  void setCuid(int32_t cuid) {
-    this->cuid = cuid;
+  void setCuid(cuid_t cuid) {
+    cuid_ = cuid;
   }
 
   const SharedHandle<Peer>& getPeer() const
   {
-    return peer;
+    return peer_;
   }
 
   void setPeer(const SharedHandle<Peer>& peer);
 
   virtual void doReceivedAction() {}
 
-  virtual bool validate(std::deque<std::string>& errors);
+  virtual void validate();
   
   virtual void onQueued() {}
 
@@ -138,7 +172,8 @@ public:
 
   void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage);
 
-  void setBtMessageDispatcher(const WeakHandle<BtMessageDispatcher>& dispatcher);
+  void setBtMessageDispatcher
+  (const WeakHandle<BtMessageDispatcher>& dispatcher);
 
   void setPeerConnection(const WeakHandle<PeerConnection>& peerConnection);
 
@@ -148,12 +183,12 @@ public:
 
   const std::string& getName() const
   {
-    return _name;
+    return name_;
   }
 
   void enableMetadataGetMode()
   {
-    _metadataGetMode = true;
+    metadataGetMode_ = true;
   }
 };
 
