@@ -37,7 +37,7 @@
 
 #include "Command.h"
 #include "SharedHandle.h"
-#include "TimeA2.h"
+#include "TimerA2.h"
 #include "FileEntry.h"
 #include "RequestGroup.h"
 
@@ -55,19 +55,87 @@ class AsyncNameResolver;
 
 class AbstractCommand : public Command {
 private:
-  Time checkPoint;
-  time_t timeout;
-protected:
-  RequestGroup* _requestGroup;
-  SharedHandle<Request> req;
-  SharedHandle<FileEntry> _fileEntry;
-  DownloadEngine* e;
-  SharedHandle<SocketCore> socket;
-  std::vector<SharedHandle<Segment> > _segments;
+  Timer checkPoint_;
+  time_t timeout_;
+
+  RequestGroup* requestGroup_;
+  SharedHandle<Request> req_;
+  SharedHandle<FileEntry> fileEntry_;
+  DownloadEngine* e_;
+  SharedHandle<SocketCore> socket_;
+  std::vector<SharedHandle<Segment> > segments_;
 
 #ifdef ENABLE_ASYNC_DNS
-  SharedHandle<AsyncNameResolver> _asyncNameResolver;
+  SharedHandle<AsyncNameResolver> asyncNameResolver_;
+#endif // ENABLE_ASYNC_DNS
 
+  bool checkSocketIsReadable_;
+  bool checkSocketIsWritable_;
+  SharedHandle<SocketCore> readCheckTarget_;
+  SharedHandle<SocketCore> writeCheckTarget_;
+  bool nameResolverCheck_;
+
+  bool incNumConnection_;
+
+  size_t calculateMinSplitSize() const;
+
+#ifdef ENABLE_ASYNC_DNS
+  void setNameResolverCheck(const SharedHandle<AsyncNameResolver>& resolver);
+
+  void disableNameResolverCheck
+  (const SharedHandle<AsyncNameResolver>& resolver);
+
+  bool nameResolveFinished() const;
+#endif // ENABLE_ASYNC_DNS
+protected:
+  RequestGroup* getRequestGroup() const
+  {
+    return requestGroup_;
+  }
+
+  const SharedHandle<Request>& getRequest() const
+  {
+    return req_;
+  }
+
+  void setRequest(const SharedHandle<Request>& request)
+  {
+    req_ = request;
+  }
+
+  const SharedHandle<FileEntry>& getFileEntry() const
+  {
+    return fileEntry_;
+  }
+
+  void setFileEntry(const SharedHandle<FileEntry>& fileEntry)
+  {
+    fileEntry_ = fileEntry;
+  }
+
+  DownloadEngine* getDownloadEngine() const
+  {
+    return e_;
+  }
+
+  const SharedHandle<SocketCore>& getSocket() const
+  {
+    return socket_;
+  }
+
+  void setSocket(const SharedHandle<SocketCore>& s)
+  {
+    socket_ = s;
+  }
+
+  void createSocket();
+
+  const std::vector<SharedHandle<Segment> >& getSegments() const
+  {
+    return segments_;
+  }
+
+#ifdef ENABLE_ASYNC_DNS
   bool isAsyncNameResolverInitialized() const;
 
   void initAsyncNameResolver(const std::string& hostname);
@@ -77,6 +145,14 @@ protected:
   const std::vector<std::string>& getResolvedAddresses();
 #endif // ENABLE_ASYNC_DNS
 
+  // Resolves hostname.  The resolved addresses are stored in addrs
+  // and first element is returned.  If resolve is not finished,
+  // return empty string. In this case, call this function with same
+  // arguments until resolved address is returned.  Exception is
+  // thrown on error. port is used for retrieving cached addresses.
+  std::string resolveHostname
+  (std::vector<std::string>& addrs, const std::string& hostname, uint16_t port);
+
   void tryReserved();
   virtual bool prepareForRetry(time_t wait);
   virtual void onAbort();
@@ -98,7 +174,7 @@ protected:
    */
   void setWriteCheckSocketIf(const SharedHandle<SocketCore>& socket, bool pred);
 
-  void setTimeout(time_t timeout) { this->timeout = timeout; }
+  void setTimeout(time_t timeout) { timeout_ = timeout; }
 
   void prepareForNextAction(Command* nextCommand = 0);
 
@@ -125,7 +201,6 @@ protected:
    */
   SharedHandle<Request> createProxyRequest() const;
 
-
   // Returns proxy method for given protocol. Either V_GET or V_TUNNEL
   // is returned.  For HTTPS, always returns V_TUNNEL.
   const std::string& resolveProxyMethod(const std::string& protocol) const;
@@ -134,28 +209,25 @@ protected:
 
   const SharedHandle<DownloadContext>& getDownloadContext() const
   {
-    return _requestGroup->getDownloadContext();
+    return requestGroup_->getDownloadContext();
   }
-private:
-  bool checkSocketIsReadable;
-  bool checkSocketIsWritable;
-  SharedHandle<SocketCore> readCheckTarget;
-  SharedHandle<SocketCore> writeCheckTarget;
-  bool nameResolverCheck;
 
-#ifdef ENABLE_ASYNC_DNS
+  const SharedHandle<SegmentMan>& getSegmentMan() const
+  {
+    return requestGroup_->getSegmentMan();
+  }
 
-  void setNameResolverCheck(const SharedHandle<AsyncNameResolver>& resolver);
-
-  void disableNameResolverCheck(const SharedHandle<AsyncNameResolver>& resolver);
-  bool nameResolveFinished() const;
-
-#endif // ENABLE_ASYNC_DNS
+  const SharedHandle<PieceStorage>& getPieceStorage() const
+  {
+    return requestGroup_->getPieceStorage();
+  }
 public:
-  AbstractCommand(int32_t cuid, const SharedHandle<Request>& req,
-                  const SharedHandle<FileEntry>& fileEntry,
-                  RequestGroup* requestGroup, DownloadEngine* e,
-                  const SharedHandle<SocketCore>& s = SharedHandle<SocketCore>());
+  AbstractCommand
+  (cuid_t cuid, const SharedHandle<Request>& req,
+   const SharedHandle<FileEntry>& fileEntry,
+   RequestGroup* requestGroup, DownloadEngine* e,
+   const SharedHandle<SocketCore>& s = SharedHandle<SocketCore>(),
+   bool incNumConnection = true);
 
   virtual ~AbstractCommand();
   bool execute();
