@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -45,46 +45,56 @@
 #include "CookieStorage.h"
 #include "AuthConfigFactory.h"
 #include "AuthConfig.h"
+#include "DownloadContext.h"
+#include "RequestGroupMan.h"
+#include "ServerStatMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
 
 namespace aria2 {
 
 AbstractProxyRequestCommand::AbstractProxyRequestCommand
-(int cuid,
- const RequestHandle& req,
+(cuid_t cuid,
+ const SharedHandle<Request>& req,
+ const SharedHandle<FileEntry>& fileEntry,
  RequestGroup* requestGroup,
  DownloadEngine* e,
  const SharedHandle<Request>& proxyRequest,
  const SocketHandle& s)
   :
-  AbstractCommand(cuid, req, requestGroup, e, s),
-  _proxyRequest(proxyRequest),
-  httpConnection(new HttpConnection(cuid, s, getOption().get()))
+  AbstractCommand(cuid, req, fileEntry, requestGroup, e, s),
+  proxyRequest_(proxyRequest),
+  httpConnection_(new HttpConnection(cuid, s))
 {
   setTimeout(getOption()->getAsInt(PREF_CONNECT_TIMEOUT));
   disableReadCheckSocket();
-  setWriteCheckSocket(socket);
+  setWriteCheckSocket(getSocket());
 }
 
 AbstractProxyRequestCommand::~AbstractProxyRequestCommand() {}
 
 bool AbstractProxyRequestCommand::executeInternal() {
   //socket->setBlockingMode();
-  if(httpConnection->sendBufferIsEmpty()) {
-    HttpRequestHandle httpRequest(new HttpRequest());
+  if(httpConnection_->sendBufferIsEmpty()) {
+    if(!checkIfConnectionEstablished
+       (getSocket(), connectedHostname_, connectedAddr_, connectedPort_)) {
+      return true;
+    }
+    SharedHandle<HttpRequest> httpRequest(new HttpRequest());
     httpRequest->setUserAgent(getOption()->get(PREF_USER_AGENT));
-    httpRequest->setRequest(req);
-    httpRequest->setProxyRequest(_proxyRequest);
+    httpRequest->setRequest(getRequest());
+    httpRequest->setProxyRequest(proxyRequest_);
 
-    httpConnection->sendProxyRequest(httpRequest);
+    httpConnection_->sendProxyRequest(httpRequest);
   } else {
-    httpConnection->sendPendingData();
+    httpConnection_->sendPendingData();
   }
-  if(httpConnection->sendBufferIsEmpty()) {
-    e->commands.push_back(getNextCommand());
+  if(httpConnection_->sendBufferIsEmpty()) {
+    getDownloadEngine()->addCommand(getNextCommand());
     return true;
   } else {
-    setWriteCheckSocket(socket);
-    e->commands.push_back(this);
+    setWriteCheckSocket(getSocket());
+    getDownloadEngine()->addCommand(this);
     return false;
   }
 }
