@@ -43,18 +43,23 @@ class HttpConnection;
 class SocketCore;
 
 class AbstractProxyRequestCommand : public AbstractCommand {
+private:
+  SharedHandle<Request> proxyRequest_;
+
+  SharedHandle<HttpConnection> httpConnection_;
+
+  std::string connectedHostname_;
+  std::string connectedAddr_;
+  uint16_t connectedPort_;
 protected:
-  SharedHandle<Request> _proxyRequest;
-
-  SharedHandle<HttpConnection> httpConnection;
-
-  std::string _connectedHostname;
-  std::string _connectedAddr;
-  uint16_t _connectedPort;
-
   virtual bool executeInternal();
+
+  const SharedHandle<HttpConnection>& getHttpConnection() const
+  {
+    return httpConnection_;
+  }
 public:
-  AbstractProxyRequestCommand(int cuid,
+  AbstractProxyRequestCommand(cuid_t cuid,
                               const SharedHandle<Request>& req,
                               const SharedHandle<FileEntry>& fileEntry,
                               RequestGroup* requestGroup,
@@ -69,9 +74,9 @@ public:
   void setConnectedAddr
   (const std::string& hostname, const std::string& addr, uint16_t port)
   {
-    _connectedHostname = hostname;
-    _connectedAddr = addr;
-    _connectedPort = port;
+    connectedHostname_ = hostname;
+    connectedAddr_ = addr;
+    connectedPort_ = port;
   }
 };
 
