@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,24 +37,36 @@
 
 #include "AbstractCommand.h"
 
+namespace aria2 {
+
 class HttpConnection;
-typedef SharedHandle<HttpConnection> HttpConnectionHandle;
+class SocketCore;
 
 class AbstractProxyResponseCommand : public AbstractCommand {
+private:
+  SharedHandle<HttpConnection> httpConnection_;
 protected:
-  HttpConnectionHandle httpConnection;
-
   virtual bool executeInternal();
+
+  const SharedHandle<HttpConnection>& getHttpConnection() const
+  {
+    return httpConnection_;
+  }
 public:
-  AbstractProxyResponseCommand(int cuid,
-			       const RequestHandle& req,
-			       RequestGroup* requestGroup,
-			       const HttpConnectionHandle& httpConnection,
-			       DownloadEngine* e,
-			       const SocketHandle& s);
+  AbstractProxyResponseCommand
+  (cuid_t cuid,
+   const SharedHandle<Request>& req,
+   const SharedHandle<FileEntry>& fileEntry,
+   RequestGroup* requestGroup,
+   const SharedHandle<HttpConnection>& httpConnection,
+   DownloadEngine* e,
+   const SharedHandle<SocketCore>& s);
+
   virtual ~AbstractProxyResponseCommand();
 
   virtual Command* getNextCommand() = 0;
 };
 
+} // namespace aria2
+
 #endif // _D_ABSTRACT_PROXY_RESPONSE_COMMAND_H_
