@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,16 +36,21 @@
 #define _D_ABSTRACT_SINGLE_DISK_ADAPTOR_H_
 
 #include "DiskAdaptor.h"
-#include "DiskWriter.h"
+
+namespace aria2 {
+
+class DiskWriter;
+class FileAllocationIterator;
 
 class AbstractSingleDiskAdaptor : public DiskAdaptor {
-protected:
-  DiskWriterHandle diskWriter;
-  int64_t totalLength;
+private:
+  SharedHandle<DiskWriter> diskWriter_;
+  uint64_t totalLength_;
+  bool readOnly_;
 public:
-  AbstractSingleDiskAdaptor():diskWriter(0), totalLength(0) {}
+  AbstractSingleDiskAdaptor();
 
-  virtual ~AbstractSingleDiskAdaptor() {}
+  virtual ~AbstractSingleDiskAdaptor();
 
   virtual void initAndOpenFile();
 
@@ -55,45 +60,50 @@ public:
 
   virtual void openExistingFile();
 
-  virtual void writeData(const unsigned char* data, int32_t len,
-			 int64_t offset);
+  virtual void writeData(const unsigned char* data, size_t len,
+                         off_t offset);
 
-  virtual int32_t readData(unsigned char* data, int32_t len, int64_t offset);
+  virtual ssize_t readData(unsigned char* data, size_t len, off_t offset);
 
   virtual bool fileExists();
 
-  virtual int64_t size() const
-  {
-    return diskWriter->size();
-  }
+  virtual uint64_t size();
 
-  virtual void truncate(int64_t length)
-  {
-    diskWriter->truncate(length);
-  }
+  virtual void truncate(uint64_t length);
   
-  virtual FileAllocationIteratorHandle fileAllocationIterator();
+  virtual SharedHandle<FileAllocationIterator> fileAllocationIterator();
 
   virtual void enableDirectIO();
 
   virtual void disableDirectIO();
   
-  virtual bool directIOAllowed() const
-  {
-    return diskWriter->directIOAllowed();
-  }
+  // Make sure that DiskWriter is set before calling this function.
+  virtual void enableReadOnly();
+
+  // Make sure that DiskWriter is set before calling this function.
+  virtual void disableReadOnly();
+    
+  virtual bool isReadOnlyEnabled() const { return readOnly_; }
   
-  void setDiskWriter(const DiskWriterHandle diskWriter) {
-    this->diskWriter = diskWriter;
+  virtual void cutTrailingGarbage();
+
+  virtual const std::string& getFilePath() = 0;
+
+  void setDiskWriter(const SharedHandle<DiskWriter>& diskWriter);
+
+  const SharedHandle<DiskWriter>& getDiskWriter() const
+  {
+    return diskWriter_;
   }
 
-  DiskWriterHandle getDiskWriter() const { return diskWriter; }
+  void setTotalLength(const uint64_t& totalLength);
 
-  void setTotalLength(const int64_t& totalLength) {
-    this->totalLength = totalLength;
+  uint64_t getTotalLength() const
+  {
+    return totalLength_;
   }
-
-  int64_t getTotalLength() const { return totalLength; }
 };
 
+} // namespace aria2
+
 #endif // _D_ABSTRACT_SINGLE_DISK_ADAPTOR_H_
