@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -35,29 +35,22 @@
 #ifndef _D_BT_ABORT_OUTSTANDING_REQUEST_EVENT_H_
 #define _D_BT_ABORT_OUTSTANDING_REQUEST_EVENT_H_
 
-#include "BtEvent.h"
+#include "common.h"
+#include "SharedHandle.h"
+#include "Piece.h"
 
 namespace aria2 {
 
-class Piece;
-
-class BtAbortOutstandingRequestEvent : public BtEvent {
+class BtAbortOutstandingRequestEvent {
 private:
-  SharedHandle<Piece> piece;
+  SharedHandle<Piece> piece_;
 public:
-  BtAbortOutstandingRequestEvent(const SharedHandle<Piece>& piece):piece(piece) {}
+  BtAbortOutstandingRequestEvent(const SharedHandle<Piece>& piece):
+    piece_(piece) {}
 
-  SharedHandle<Piece> getPiece() const {
-    return piece;
-  }
-
-  void setPiece(const SharedHandle<Piece>& piece) {
-    this->piece = piece;
-  }
+  const SharedHandle<Piece>& getPiece() const { return piece_; }
 };
 
-typedef SharedHandle<BtAbortOutstandingRequestEvent> BtAbortOutstandingRequestEventHandle;
-
 } // namespace aria2
 
 #endif // _D_BT_ABORT_OUTSTANDING_REQUEST_EVENT_H_
