@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,6 +36,11 @@
 #define _D_BT_ANNOUNCE_H_
 
 #include "common.h"
+#include "SharedHandle.h"
+#include "a2time.h"
+#include <string>
+
+namespace aria2 {
 
 class BtAnnounce {
 public:
@@ -57,7 +62,7 @@ public:
   /**
    * Returns announe URL with all necessary parameters included.
    */
-  virtual string getAnnounceUrl() = 0;
+  virtual std::string getAnnounceUrl() = 0;
 
   /**
    * Tells that the announce process has just started.
@@ -87,8 +92,8 @@ public:
   /**
    * Processes the repsponse from the tracker.
    */
-  virtual void processAnnounceResponse(const char* trackerResponse,
-				       size_t trackerResponseLength) = 0;
+  virtual void processAnnounceResponse(const unsigned char* trackerResponse,
+                                       size_t trackerResponseLength) = 0;
 
   /**
    * Returns true if no more announce is needed.
@@ -99,8 +104,30 @@ public:
    * Shuffles the URLs in each announce tier.
    */
   virtual void shuffleAnnounce() = 0;
+
+  virtual void overrideMinInterval(time_t interval) = 0;
+
+  static const std::string FAILURE_REASON;
+
+  static const std::string WARNING_MESSAGE;
+
+  static const std::string TRACKER_ID;
+
+  static const std::string INTERVAL;
+
+  static const std::string MIN_INTERVAL;
+
+  static const std::string COMPLETE;
+
+  static const std::string INCOMPLETE;
+
+  static const std::string PEERS;
+
+  static const time_t DEFAULT_ANNOUNCE_INTERVAL = 120;
 };
 
 typedef SharedHandle<BtAnnounce> BtAnnounceHandle;
 
+} // namespace aria2
+
 #endif // _D_BT_ANNOUNCE_H_
