@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -42,39 +42,41 @@
 #include "BtHandshakeMessage.h"
 #include "util.h"
 #include "StringFormat.h"
+#include "BtConstants.h"
 
 namespace aria2 {
 
 class BtHandshakeMessageValidator : public BtMessageValidator {
 private:
-  const BtHandshakeMessage* message;
-  unsigned char infoHash[20];
+  const BtHandshakeMessage* message_;
+  unsigned char infoHash_[INFO_HASH_LENGTH];
 public:
   BtHandshakeMessageValidator(const BtHandshakeMessage* message,
-			      const unsigned char* infoHash):
-    message(message)
+                              const unsigned char* infoHash):
+    message_(message)
   {
-    memcpy(this->infoHash, infoHash, sizeof(this->infoHash));
+    memcpy(infoHash_, infoHash, sizeof(infoHash_));
   }
 
-  virtual bool validate(Errors& error) {
-    // TODO
-    if(message->getPstrlen() != 19) {
+  virtual void validate()
+  {
+    if(message_->getPstrlen() != 19) {
       throw DL_ABORT_EX(StringFormat("invalid handshake pstrlen=%u",
-				   message->getPstrlen()).str());
+                                     message_->getPstrlen()).str());
     }
-    if(memcmp(BtHandshakeMessage::BT_PSTR, message->getPstr(), 19) != 0) {
+    if(memcmp(BtHandshakeMessage::BT_PSTR, message_->getPstr(), 19) != 0) {
       throw DL_ABORT_EX
-	(StringFormat("invalid handshake pstr=%s",
-		      util::urlencode(message->getPstr(), 19).c_str()).str());
+        (StringFormat("invalid handshake pstr=%s",
+                      util::percentEncode
+                      (message_->getPstr(), 19).c_str()).str());
     }
-    if(memcmp(infoHash, message->getInfoHash(), 20) != 0) {
+    if(memcmp(infoHash_, message_->getInfoHash(), sizeof(infoHash_)) != 0) {
       throw DL_ABORT_EX
-	(StringFormat("invalid handshake info hash: expected:%s, actual:%s",
-		      util::toHex(infoHash, 20).c_str(),
-		      util::toHex(message->getInfoHash(), 20).c_str()).str());
+        (StringFormat("invalid handshake info hash: expected:%s, actual:%s",
+                      util::toHex(infoHash_, sizeof(infoHash_)).c_str(),
+                      util::toHex(message_->getInfoHash(),
+                                  INFO_HASH_LENGTH).c_str()).str());
     }
-    return true;
   }
 };
 
