@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -46,33 +46,31 @@ class DHTTaskFactory;
 
 class BtPortMessage : public SimpleBtMessage {
 private:
-  uint16_t _port;
-  unsigned char* _msg;
+  uint16_t port_;
   static const size_t MESSAGE_LENGTH = 7;
 
-  WeakHandle<DHTNode> _localNode;
+  WeakHandle<DHTNode> localNode_;
 
-  WeakHandle<DHTRoutingTable> _routingTable;
+  WeakHandle<DHTRoutingTable> routingTable_;
 
-  WeakHandle<DHTTaskQueue> _taskQueue;
+  WeakHandle<DHTTaskQueue> taskQueue_;
 
-  WeakHandle<DHTTaskFactory> _taskFactory;
+  WeakHandle<DHTTaskFactory> taskFactory_;
 public:
   BtPortMessage(uint16_t port);
 
-  virtual ~BtPortMessage();
-
   static const uint8_t ID = 9;
 
-  uint16_t getPort() const { return _port; }
+  static const std::string NAME;
 
-  static SharedHandle<BtPortMessage> create(const unsigned char* data, size_t dataLength);
+  uint16_t getPort() const { return port_; }
 
-  virtual uint8_t getId() { return ID; }
+  static SharedHandle<BtPortMessage> create
+  (const unsigned char* data, size_t dataLength);
 
   virtual void doReceivedAction();
 
-  virtual const unsigned char* getMessage();
+  virtual unsigned char* createMessage();
 
   virtual size_t getMessageLength();
 
