@@ -66,8 +66,8 @@ void BtPostDownloadHandler::getNextRequestGroups
 (std::vector<SharedHandle<RequestGroup> >& groups,
  RequestGroup* requestGroup)
 {
-  _logger->info("Generating RequestGroups for Torrent file %s",
-                requestGroup->getFirstFilePath().c_str());
+  getLogger()->info("Generating RequestGroups for Torrent file %s",
+                    requestGroup->getFirstFilePath().c_str());
   std::string content;
   try {
     requestGroup->getPieceStorage()->getDiskAdaptor()->openExistingFile();
@@ -82,6 +82,11 @@ void BtPostDownloadHandler::getNextRequestGroups
                                   std::vector<std::string>(),
                                   content);
   requestGroup->followedBy(newRgs.begin(), newRgs.end());
+  SharedHandle<MetadataInfo> mi =
+    createMetadataInfoFromFirstFileEntry(requestGroup->getDownloadContext());
+  if(!mi.isNull()) {
+    setMetadataInfo(newRgs.begin(), newRgs.end(), mi);
+  }
   groups.insert(groups.end(), newRgs.begin(), newRgs.end());
 }
 
