@@ -45,49 +45,48 @@
 namespace aria2 {
 
 SharedHandle<DownloadContext>
-BtRegistry::getDownloadContext(int32_t gid) const
+BtRegistry::getDownloadContext(gid_t gid) const
 {
-  return get(gid)._downloadContext;
+  return get(gid).downloadContext_;
 }
 
 SharedHandle<DownloadContext>
 BtRegistry::getDownloadContext(const std::string& infoHash) const
 {
   SharedHandle<DownloadContext> dctx;
-  for(std::map<int32_t, BtObject>::const_iterator i = _pool.begin(),
-        eoi = _pool.end(); i != eoi; ++i) {
-    const BDE& attrs =
-      (*i).second._downloadContext->getAttribute(bittorrent::BITTORRENT);
-    if(attrs[bittorrent::INFO_HASH].s() == infoHash) {
-      dctx = (*i).second._downloadContext;
+  for(std::map<gid_t, BtObject>::const_iterator i = pool_.begin(),
+        eoi = pool_.end(); i != eoi; ++i) {
+    if(bittorrent::getTorrentAttrs((*i).second.downloadContext_)->infoHash ==
+       infoHash) {
+      dctx = (*i).second.downloadContext_;
       break;
     }
-  }
+  }      
   return dctx;
 }
 
-void BtRegistry::put(int32_t gid, const BtObject& obj)
+void BtRegistry::put(gid_t gid, const BtObject& obj)
 {
-  _pool[gid] = obj;
+  pool_[gid] = obj;
 }
 
-BtObject BtRegistry::get(int32_t gid) const
+BtObject BtRegistry::get(gid_t gid) const
 {
-  std::map<int32_t, BtObject>::const_iterator i = _pool.find(gid);
-  if(i == _pool.end()) {
+  std::map<gid_t, BtObject>::const_iterator i = pool_.find(gid);
+  if(i == pool_.end()) {
     return BtObject();
   } else {
     return (*i).second;
   }
 }
 
-bool BtRegistry::remove(int32_t gid)
+bool BtRegistry::remove(gid_t gid)
 {
-  return _pool.erase(gid);
+  return pool_.erase(gid);
 }
 
 void BtRegistry::removeAll() {
-  _pool.clear();
+  pool_.clear();
 }
 
 } // namespace aria2
