@@ -69,10 +69,15 @@
 #include "LpdMessageDispatcher.h"
 #include "message.h"
 #include "SocketCore.h"
+#include "RequestGroupMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
+#include "ServerStatMan.h"
+#include "DlAbortEx.h"
 
 namespace aria2 {
 
-BtSetup::BtSetup():_logger(LogFactory::getInstance()) {}
+BtSetup::BtSetup():logger_(LogFactory::getInstance()) {}
 
 void BtSetup::setup(std::vector<Command*>& commands,
                     RequestGroup* requestGroup,
@@ -82,14 +87,14 @@ void BtSetup::setup(std::vector<Command*>& commands,
   if(!requestGroup->getDownloadContext()->hasAttribute(bittorrent::BITTORRENT)){
     return;
   }
-  const BDE& torrentAttrs =
-    requestGroup->getDownloadContext()->getAttribute(bittorrent::BITTORRENT);
-  bool metadataGetMode = !torrentAttrs.containsKey(bittorrent::METADATA);
+  SharedHandle<TorrentAttribute> torrentAttrs =
+    bittorrent::getTorrentAttrs(requestGroup->getDownloadContext());
+  bool metadataGetMode = torrentAttrs->metadata.empty();
   BtObject btObject = e->getBtRegistry()->get(requestGroup->getGID());
-  SharedHandle<PieceStorage> pieceStorage = btObject._pieceStorage;
-  SharedHandle<PeerStorage> peerStorage = btObject._peerStorage;
-  SharedHandle<BtRuntime> btRuntime = btObject._btRuntime;
-  SharedHandle<BtAnnounce> btAnnounce = btObject._btAnnounce;
+  SharedHandle<PieceStorage> pieceStorage = btObject.pieceStorage_;
+  SharedHandle<PeerStorage> peerStorage = btObject.peerStorage_;
+  SharedHandle<BtRuntime> btRuntime = btObject.btRuntime_;
+  SharedHandle<BtAnnounce> btAnnounce = btObject.btAnnounce_;
   // commands
   {
     TrackerWatcherCommand* c =
@@ -121,12 +126,12 @@ void BtSetup::setup(std::vector<Command*>& commands,
     commands.push_back(c);
   }
 
-  if((metadataGetMode || torrentAttrs[bittorrent::PRIVATE].i() == 0) &&
+  if((metadataGetMode || !torrentAttrs->privateTorrent) &&
      DHTSetup::initialized()) {
     DHTGetPeersCommand* command =
       new DHTGetPeersCommand(e->newCUID(), requestGroup, e);
-    command->setTaskQueue(DHTRegistry::_taskQueue);
-    command->setTaskFactory(DHTRegistry::_taskFactory);
+    command->setTaskQueue(DHTRegistry::getData().taskQueue);
+    command->setTaskFactory(DHTRegistry::getData().taskFactory);
     command->setBtRuntime(btRuntime);
     command->setPeerStorage(peerStorage);
     commands.push_back(command);
@@ -160,12 +165,12 @@ void BtSetup::setup(std::vector<Command*>& commands,
   }
   if(PeerListenCommand::getNumInstance() == 0) {
     PeerListenCommand* listenCommand = PeerListenCommand::getInstance(e);
-    IntSequence seq = util::parseIntRange(e->option->get(PREF_LISTEN_PORT));
+    IntSequence seq =util::parseIntRange(e->getOption()->get(PREF_LISTEN_PORT));
     uint16_t port;
     if(listenCommand->bindPort(port, seq)) {
       btRuntime->setListenPort(port);
       // Add command to DownloadEngine directly.
-      e->commands.push_back(listenCommand);
+      e->addCommand(listenCommand);
     } else {
       delete listenCommand;
       throw DL_ABORT_EX(_("Errors occurred while binding port.\n"));
@@ -175,13 +180,14 @@ void BtSetup::setup(std::vector<Command*>& commands,
     btRuntime->setListenPort(listenCommand->getPort());
   }
   if(option->getAsBool(PREF_BT_ENABLE_LPD) &&
-     (metadataGetMode || torrentAttrs[bittorrent::PRIVATE].i() == 0)) {
+     (metadataGetMode || !torrentAttrs->privateTorrent)) {
     if(LpdReceiveMessageCommand::getNumInstance() == 0) {
-      _logger->info("Initializing LpdMessageReceiver.");
+      logger_->info("Initializing LpdMessageReceiver.");
       SharedHandle<LpdMessageReceiver> receiver
         (new LpdMessageReceiver(LPD_MULTICAST_ADDR, LPD_MULTICAST_PORT));
       bool initialized = false;
-      const std::string& lpdInterface = e->option->get(PREF_BT_LPD_INTERFACE);
+      const std::string& lpdInterface =
+        e->getOption()->get(PREF_BT_LPD_INTERFACE);
       if(lpdInterface.empty()) {
         if(receiver->init("")) {
           initialized = true;
@@ -200,15 +206,15 @@ void BtSetup::setup(std::vector<Command*>& commands,
         }
       }
       if(initialized) {
-        _logger->info("LpdMessageReceiver initialized. multicastAddr=%s:%u,"
+        logger_->info("LpdMessageReceiver initialized. multicastAddr=%s:%u,"
                       " localAddr=%s",
                       LPD_MULTICAST_ADDR, LPD_MULTICAST_PORT,
                       receiver->getLocalAddress().c_str());
         LpdReceiveMessageCommand* cmd =
           LpdReceiveMessageCommand::getInstance(e, receiver);
-        e->commands.push_back(cmd);
+        e->addCommand(cmd);
       } else {
-        _logger->info("LpdMessageReceiver not initialized.");
+        logger_->info("LpdMessageReceiver not initialized.");
       }
     }
     if(LpdReceiveMessageCommand::getNumInstance()) {
@@ -216,20 +222,20 @@ void BtSetup::setup(std::vector<Command*>& commands,
         bittorrent::getInfoHash(requestGroup->getDownloadContext());
       SharedHandle<LpdMessageReceiver> receiver =
         LpdReceiveMessageCommand::getInstance()->getLpdMessageReceiver();
-      _logger->info("Initializing LpdMessageDispatcher.");      
+      logger_->info("Initializing LpdMessageDispatcher.");      
       SharedHandle<LpdMessageDispatcher> dispatcher
         (new LpdMessageDispatcher
          (std::string(&infoHash[0], &infoHash[INFO_HASH_LENGTH]),
           btRuntime->getListenPort(),
           LPD_MULTICAST_ADDR, LPD_MULTICAST_PORT));
       if(dispatcher->init(receiver->getLocalAddress(), /*ttl*/1, /*loop*/0)) {
-        _logger->info("LpdMessageDispatcher initialized.");      
+        logger_->info("LpdMessageDispatcher initialized.");      
         LpdDispatchMessageCommand* cmd =
           new LpdDispatchMessageCommand(e->newCUID(), dispatcher, e);
         cmd->setBtRuntime(btRuntime);
-        e->commands.push_back(cmd);
+        e->addCommand(cmd);
       } else {
-        _logger->info("LpdMessageDispatcher not initialized.");
+        logger_->info("LpdMessageDispatcher not initialized.");
       }
     }
   }
