@@ -45,10 +45,9 @@ typedef SharedHandle<BtUnchokeMessage> BtUnchokeMessageHandle;
 
 class BtUnchokeMessage : public ZeroBtMessage {
 private:
-  unsigned char* msg;
   static const size_t MESSAGE_LENGTH = 5;
 public:
-  BtUnchokeMessage():ZeroBtMessage(ID, NAME) {}
+  BtUnchokeMessage();
 
   static const uint8_t ID = 1;
 
