@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -42,11 +42,13 @@
 #include "DownloadEngine.h"
 #include "Option.h"
 #include "DownloadContext.h"
+#include "RequestGroupMan.h"
+#include "ServerStatMan.h"
 
 namespace aria2 {
 
 CheckIntegrityEntry::CheckIntegrityEntry(RequestGroup* requestGroup,
-					 Command* nextCommand):
+                                         Command* nextCommand):
   RequestGroupEntry(requestGroup, nextCommand)
 {}
 
@@ -54,52 +56,57 @@ CheckIntegrityEntry::~CheckIntegrityEntry() {}
 
 void CheckIntegrityEntry::validateChunk()
 {
-  _validator->validateChunk();
+  validator_->validateChunk();
 }
 
 uint64_t CheckIntegrityEntry::getTotalLength()
 {
-  if(_validator.isNull()) {
+  if(validator_.isNull()) {
     return 0;
   } else {
-    return _validator->getTotalLength();
+    return validator_->getTotalLength();
   }
 }
 
 off_t CheckIntegrityEntry::getCurrentLength()
 {
-  if(_validator.isNull()) {
+  if(validator_.isNull()) {
     return 0;
   } else {
-    return _validator->getCurrentOffset();
+    return validator_->getCurrentOffset();
   }
 }
 
 bool CheckIntegrityEntry::finished()
 {
-  return _validator->finished();
+  return validator_->finished();
 }
 
 void CheckIntegrityEntry::cutTrailingGarbage()
 {
-  _requestGroup->getPieceStorage()->getDiskAdaptor()->cutTrailingGarbage();
+  getRequestGroup()->getPieceStorage()->getDiskAdaptor()->cutTrailingGarbage();
 }
 
 void CheckIntegrityEntry::proceedFileAllocation
-(std::deque<Command*>& commands,
+(std::vector<Command*>& commands,
  const SharedHandle<FileAllocationEntry>& entry,
  DownloadEngine* e)
 {
-  if(_requestGroup->needsFileAllocation()) {
-    e->_fileAllocationMan->pushEntry(entry);
+  if(getRequestGroup()->needsFileAllocation()) {
+    e->getFileAllocationMan()->pushEntry(entry);
   } else {
     entry->prepareForNextAction(commands, e);
   }
   // Disable directIO when fallocation() is going to be used.
-  if(_requestGroup->getOption()->get(PREF_FILE_ALLOCATION) == V_FALLOC) {
+  if(getRequestGroup()->getOption()->get(PREF_FILE_ALLOCATION) == V_FALLOC) {
     entry->disableDirectIO();
   }
 }
 
+void CheckIntegrityEntry::setValidator
+(const SharedHandle<IteratableValidator>& validator)
+{
+  validator_ = validator;
+}
 
 } // namespace aria2
