@@ -39,6 +39,9 @@
 #include "IteratableChecksumValidator.h"
 #include "DownloadEngine.h"
 #include "PieceStorage.h"
+#include "RequestGroupMan.h"
+#include "FileAllocationEntry.h"
+#include "ServerStatMan.h"
 
 namespace aria2 {
 
@@ -49,22 +52,25 @@ ChecksumCheckIntegrityEntry::~ChecksumCheckIntegrityEntry() {}
 
 bool ChecksumCheckIntegrityEntry::isValidationReady()
 {
-  return !_requestGroup->getDownloadContext()->getChecksum().empty() &&
-    !_requestGroup->getDownloadContext()->getChecksumHashAlgo().empty();
+  return !getRequestGroup()->getDownloadContext()->getChecksum().empty() &&
+    !getRequestGroup()->getDownloadContext()->getChecksumHashAlgo().empty();
 }
 
 void ChecksumCheckIntegrityEntry::initValidator()
 {
-  _validator.reset(new IteratableChecksumValidator
-                   (_requestGroup->getDownloadContext(),
-                    _requestGroup->getPieceStorage()));
-  _validator->init();
+  SharedHandle<IteratableChecksumValidator> validator
+    (new IteratableChecksumValidator(getRequestGroup()->getDownloadContext(),
+                                     getRequestGroup()->getPieceStorage()));
+  validator->init();
+  setValidator(validator);
 }
 
 void
 ChecksumCheckIntegrityEntry::onDownloadFinished
 (std::vector<Command*>& commands, DownloadEngine* e)
-{}
+{
+  getRequestGroup()->getDownloadContext()->setChecksumVerified(true);
+}
 
 void
 ChecksumCheckIntegrityEntry::onDownloadIncomplete
