@@ -44,14 +44,15 @@ private:
   enum STATE {
     READ_SIZE,
     READ_DATA,
+    READ_TRAILER,
     STREAM_END
   };
 
-  std::string _buf;
+  std::string buf_;
 
-  uint64_t _chunkSize;
+  uint64_t chunkSize_;
 
-  STATE _state;
+  STATE state_;
   
   static const std::string NAME;
 
