@@ -37,15 +37,12 @@
 
 #include "common.h"
 #include <stdint.h>
-#include <deque>
 
 namespace aria2 {
 
 class Logger;
 
-typedef int32_t CommandUuid;
-
-typedef int32_t cuid_t;
+typedef int64_t cuid_t;
 
 class Command {
 public:
@@ -57,17 +54,40 @@ public:
     STATUS_ONESHOT_REALTIME
   };
 private:
-  CommandUuid uuid;
-  static int32_t uuidGen;
-  STATUS status;
-protected:
-  int32_t cuid;
-  Logger* logger;
+  STATUS status_;
 
-  bool _readEvent;
-  bool _writeEvent;
-  bool _errorEvent;
-  bool _hupEvent;
+  cuid_t cuid_;
+  Logger* logger_;
+
+  bool readEvent_;
+  bool writeEvent_;
+  bool errorEvent_;
+  bool hupEvent_;
+protected:
+  Logger* getLogger() const
+  {
+    return logger_;
+  }
+
+  bool readEventEnabled() const
+  {
+    return readEvent_;
+  }
+
+  bool writeEventEnabled() const
+  {
+    return writeEvent_;
+  }
+
+  bool errorEventEnabled() const
+  {
+    return errorEvent_;
+  }
+
+  bool hupEventEnabled() const
+  {
+    return hupEvent_;
+  }
 public:
   Command(cuid_t cuid);
 
@@ -75,21 +95,19 @@ public:
 
   virtual bool execute() = 0;
 
-  cuid_t getCuid() const { return cuid; }
+  cuid_t getCuid() const { return cuid_; }
 
-  const CommandUuid& getUuid() const { return uuid; }
+  void setStatusActive() { status_ = STATUS_ACTIVE; }
 
-  void setStatusActive() { this->status = STATUS_ACTIVE; }
+  void setStatusInactive() { status_ = STATUS_INACTIVE; }
 
-  void setStatusInactive() { this->status = STATUS_INACTIVE; }
-
-  void setStatusRealtime() { this->status = STATUS_REALTIME; }
+  void setStatusRealtime() { status_ = STATUS_REALTIME; }
 
   void setStatus(STATUS status);
 
   bool statusMatch(Command::STATUS statusFilter) const
   {
-    return statusFilter <= status;
+    return statusFilter <= status_;
   }
 
   void transitStatus();
@@ -105,8 +123,6 @@ public:
   void clearIOEvents();
 };
 
-typedef std::deque<Command*> Commands;
-
 } // namespace aria2
 
 #endif // _D_COMMAND_H_
