@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -61,14 +61,14 @@ bool ContentTypeRequestGroupCriteria::match
   if(requestGroup->getDownloadContext()->getFileEntries().size() != 1) {
     return false;
   }
-  if(tailMatch(_extensions.begin(), _extensions.end(),
-	       requestGroup->getFirstFilePath())) {
+  if(tailMatch(extensions_.begin(), extensions_.end(),
+               requestGroup->getFirstFilePath())) {
     return true;
   } else {
     return
-      std::find(_contentTypes.begin(), _contentTypes.end(),
-		requestGroup->getDownloadContext()->getFirstFileEntry()->
-		getContentType()) != _contentTypes.end();
+      std::find(contentTypes_.begin(), contentTypes_.end(),
+                requestGroup->getDownloadContext()->getFirstFileEntry()->
+                getContentType()) != contentTypes_.end();
   }
 }
 
