@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -51,17 +51,17 @@ static std::string prependDotIfNotExists(const std::string& domain)
   //   OPTIONAL.  The value of the Domain attribute specifies the domain
   //   for which the cookie is valid.  If an explicitly specified value
   //   does not start with a dot, the user agent supplies a leading dot.
-  return (!domain.empty() && domain[0] != '.') ? "."+domain : domain;
+  return (!domain.empty() && domain[0] != '.') ? A2STR::DOT_C+domain : domain;
 }
 
-static std::string normalizeDomain(const std::string& domain)
+std::string Cookie::normalizeDomain(const std::string& domain)
 {
-  if(domain.empty() || util::isNumbersAndDotsNotation(domain)) {
+  if(domain.empty() || util::isNumericHost(domain)) {
     return domain;
   }
   std::string md = prependDotIfNotExists(domain);
   // TODO use util::split to strict verification
-  std::string::size_type p = md.find_last_of(".");
+  std::string::size_type p = md.find_last_of(A2STR::DOT_C);
   if(p == 0 || p == std::string::npos) {
     md += ".local";
   }
@@ -69,42 +69,46 @@ static std::string normalizeDomain(const std::string& domain)
 }
 
 Cookie::Cookie(const std::string& name,
-	       const std::string& value,
-	       time_t  expiry,
-	       const std::string& path,
-	       const std::string& domain,
-	       bool secure):
-  _name(name),
-  _value(value),
-  _expiry(expiry),
-  _path(path),
-  _domain(normalizeDomain(domain)),
-  _secure(secure) {}
+               const std::string& value,
+               time_t  expiry,
+               const std::string& path,
+               const std::string& domain,
+               bool secure):
+  name_(name),
+  value_(value),
+  expiry_(expiry),
+  path_(path),
+  domain_(normalizeDomain(domain)),
+  secure_(secure),
+  creationTime_(time(0)),
+  lastAccess_(creationTime_) {}
 
 Cookie::Cookie(const std::string& name,
-	       const std::string& value,
-	       const std::string& path,
-	       const std::string& domain,
-	       bool secure):
-  _name(name),
-  _value(value),
-  _expiry(0),
-  _path(path),
-  _domain(normalizeDomain(domain)),
-  _secure(secure) {}
+               const std::string& value,
+               const std::string& path,
+               const std::string& domain,
+               bool secure):
+  name_(name),
+  value_(value),
+  expiry_(0),
+  path_(path),
+  domain_(normalizeDomain(domain)),
+  secure_(secure),
+  creationTime_(time(0)),
+  lastAccess_(creationTime_) {}
 
-Cookie::Cookie():_expiry(0), _secure(false) {}
+Cookie::Cookie():expiry_(0), secure_(false), lastAccess_(time(0)) {}
 
 Cookie::~Cookie() {}
 
 std::string Cookie::toString() const
 {
-  return strconcat(_name, "=", _value);
+  return strconcat(name_, "=", value_);
 }
 
 bool Cookie::good() const
 {
-  return !_name.empty();
+  return !name_.empty();
 }
 
 static bool pathInclude(const std::string& requestPath, const std::string& path)
@@ -117,14 +121,14 @@ static bool pathInclude(const std::string& requestPath, const std::string& path)
       return false;
     }
   } else if(*path.rbegin() != '/' || *requestPath.rbegin() == '/' ||
-	    !util::startsWith(requestPath+"/", path)) {
+            !util::startsWith(requestPath+"/", path)) {
     return false;
   }
   return true;
 }
 
 static bool domainMatch(const std::string& normReqHost,
-			const std::string& domain)
+                        const std::string& domain)
 {
   // RFC2965 stated that:
   //
@@ -134,19 +138,19 @@ static bool domainMatch(const std::string& normReqHost,
   //
   // Also original Netscape implementation behaves exactly the same.
 
-  // _domain always starts ".". See Cookie::Cookie().
+  // domain_ always starts ".". See Cookie::Cookie().
   return util::endsWith(normReqHost, domain);
 }
 
 bool Cookie::match(const std::string& requestHost,
-		   const std::string& requestPath,
-		   time_t date, bool secure) const
+                   const std::string& requestPath,
+                   time_t date, bool secure) const
 {
-  std::string normReqHost = normalizeDomain(requestHost);
-  if((secure || (!_secure && !secure)) &&
-     domainMatch(normReqHost, _domain) &&
-     pathInclude(requestPath, _path) &&
-     (isSessionCookie() || (date < _expiry))) {
+  if((secure || (!secure_ && !secure)) &&
+     (requestHost == domain_ || // For default domain or IP address
+      domainMatch(normalizeDomain(requestHost), domain_)) &&
+     pathInclude(requestPath, path_) &&
+     (isSessionCookie() || (date < expiry_))) {
     return true;
   } else {
     return false;
@@ -156,40 +160,43 @@ bool Cookie::match(const std::string& requestHost,
 bool Cookie::validate(const std::string& requestHost,
                       const std::string& requestPath) const
 {
-  std::string normReqHost = normalizeDomain(requestHost);
-  // If _domain is IP address, then it should be matched to requestHost.
-  // In other words, _domain == normReqHost
-  if(normReqHost != _domain) {
-    // domain must start with '.'
-    if(*_domain.begin() != '.') {
-      return false;
+  // If domain_ doesn't start with "." or it is IP address, then it
+  // must equal to requestHost. Otherwise, do domain tail match.
+  if(requestHost != domain_) {
+    std::string normReqHost = normalizeDomain(requestHost);
+    if(normReqHost != domain_) {
+      // domain must start with '.'
+      if(*domain_.begin() != '.') {
+        return false;
+      }
+      // domain must not end with '.'
+      if(*domain_.rbegin() == '.') {
+        return false;
+      }
+      // domain must include at least one embeded '.'
+      if(domain_.size() < 4 ||
+         domain_.find(A2STR::DOT_C, 1) == std::string::npos) {
+        return false;
+      }
+      if(!util::endsWith(normReqHost, domain_)) {
+        return false;
+      }
+      // From RFC2965 3.3.2 Rejecting Cookies
+      // * The request-host is a HDN (not IP address) and has the form HD,
+      //   where D is the value of the Domain attribute, and H is a string
+      //   that contains one or more dots.
+      size_t dotCount = std::count(normReqHost.begin(),
+                                   normReqHost.begin()+
+                                   (normReqHost.size()-domain_.size()), '.');
+      if(dotCount > 1 || (dotCount == 1 && normReqHost[0] != '.')) {
+        return false;
+      } 
     }
-    // domain must not end with '.'
-    if(*_domain.rbegin() == '.') {
-      return false;
-    }
-    // domain must include at least one embeded '.'
-    if(_domain.size() < 4 || _domain.find(".", 1) == std::string::npos) {
-      return false;
-    }
-    if(!util::endsWith(normReqHost, _domain)) {
-      return false;
-    }
-    // From RFC2965 3.3.2 Rejecting Cookies
-    // * The request-host is a HDN (not IP address) and has the form HD,
-    //   where D is the value of the Domain attribute, and H is a string
-    //   that contains one or more dots.
-    size_t dotCount = std::count(normReqHost.begin(),
-                                 normReqHost.begin()+
-                                 (normReqHost.size()-_domain.size()), '.');
-    if(dotCount > 1 || (dotCount == 1 && normReqHost[0] != '.')) {
-      return false;
-    } 
   }
-  if(requestPath != _path) {
+  if(requestPath != path_) {
     // From RFC2965 3.3.2 Rejecting Cookies
     // * The value for the Path attribute is not a prefix of the request-URI.
-    if(!pathInclude(requestPath, _path)) {
+    if(!pathInclude(requestPath, path_)) {
       return false;
     }
   }
@@ -198,36 +205,48 @@ bool Cookie::validate(const std::string& requestHost,
 
 bool Cookie::operator==(const Cookie& cookie) const
 {
-  return _domain == cookie._domain && _path == cookie._path &&
-    _name == cookie._name;
+  return domain_ == cookie.domain_ && path_ == cookie.path_ &&
+    name_ == cookie.name_;
 }
 
 bool Cookie::isExpired() const
 {
-  return !_expiry == 0 && Time().getTime() >= _expiry;
+  return !expiry_ == 0 && Time().getTime() >= expiry_;
 }
 
 std::string Cookie::toNsCookieFormat() const
 {
   std::stringstream ss;
-  ss << _domain << "\t";
-  if(util::startsWith(_domain, ".")) {
+  ss << domain_ << "\t";
+  if(util::startsWith(domain_, A2STR::DOT_C)) {
     ss << "TRUE";
   } else {
     ss << "FALSE";
   }
   ss << "\t";
-  ss << _path << "\t";
-  if(_secure) {
+  ss << path_ << "\t";
+  if(secure_) {
     ss << "TRUE";
   } else {
     ss << "FALSE";
   }
   ss << "\t";
-  ss << _expiry << "\t";
-  ss << _name << "\t";
-  ss << _value;
+  ss << expiry_ << "\t";
+  ss << name_ << "\t";
+  ss << value_;
   return ss.str();
 }
 
+void Cookie::markOriginServerOnly()
+{
+  if(util::startsWith(domain_, A2STR::DOT_C)) {
+    domain_.erase(domain_.begin(), domain_.begin()+1);
+  }
+}
+
+void Cookie::updateLastAccess()
+{
+  lastAccess_ = time(0);
+}
+
 } // namespace aria2
