@@ -45,7 +45,6 @@
 #include "bittorrent_helper.h"
 #include "Peer.h"
 #include "util.h"
-#include "bencode.h"
 #include "a2functional.h"
 
 namespace aria2 {
@@ -58,12 +57,13 @@ const std::string DHTGetPeersReplyMessage::VALUES("values");
 
 const std::string DHTGetPeersReplyMessage::NODES("nodes");
 
-DHTGetPeersReplyMessage::DHTGetPeersReplyMessage(const SharedHandle<DHTNode>& localNode,
-                                                 const SharedHandle<DHTNode>& remoteNode,
-                                                 const std::string& token,
-                                                 const std::string& transactionID):
+DHTGetPeersReplyMessage::DHTGetPeersReplyMessage
+(const SharedHandle<DHTNode>& localNode,
+ const SharedHandle<DHTNode>& remoteNode,
+ const std::string& token,
+ const std::string& transactionID):
   DHTResponseMessage(localNode, remoteNode, transactionID),
-  _token(token) {}
+  token_(token) {}
 
 DHTGetPeersReplyMessage::~DHTGetPeersReplyMessage() {}
 
@@ -72,17 +72,17 @@ void DHTGetPeersReplyMessage::doReceivedAction()
   // Returned peers and nodes are handled in DHTPeerLookupTask.
 }
 
-BDE DHTGetPeersReplyMessage::getResponse()
+SharedHandle<Dict> DHTGetPeersReplyMessage::getResponse()
 {
-  BDE rDict = BDE::dict();
-  rDict[DHTMessage::ID] = BDE(_localNode->getID(), DHT_ID_LENGTH);
-  rDict[TOKEN] = _token;
-  if(_values.empty()) {
+  SharedHandle<Dict> rDict = Dict::g();
+  rDict->put(DHTMessage::ID, String::g(getLocalNode()->getID(), DHT_ID_LENGTH));
+  rDict->put(TOKEN, token_);
+  if(values_.empty()) {
     size_t offset = 0;
     unsigned char buffer[DHTBucket::K*26];
-    for(std::deque<SharedHandle<DHTNode> >::const_iterator i =
-          _closestKNodes.begin();
-        i != _closestKNodes.end() && offset < DHTBucket::K*26; ++i) {
+    for(std::vector<SharedHandle<DHTNode> >::const_iterator i =
+          closestKNodes_.begin(), eoi = closestKNodes_.end();
+        i != eoi && offset < DHTBucket::K*26; ++i) {
       SharedHandle<DHTNode> node = *i;
       memcpy(buffer+offset, node->getID(), DHT_ID_LENGTH);
       if(bittorrent::createcompact
@@ -90,7 +90,7 @@ BDE DHTGetPeersReplyMessage::getResponse()
         offset += 26;
       }
     }
-    rDict[NODES] = BDE(buffer, offset);
+    rDict->put(NODES, String::g(buffer, offset));
   } else {
     // Limit the size of values list.  The maxmum size of UDP datagram
     // is limited to 65535 bytes. aria2 uses 20bytes token and 2byte
@@ -112,42 +112,37 @@ BDE DHTGetPeersReplyMessage::getResponse()
     // template may get bigger than 87 bytes. So we use 100 as maximum
     // number of peer info that a message can carry.
     static const size_t MAX_VALUES_SIZE = 100;
-    BDE valuesList = BDE::list();
-    for(std::deque<SharedHandle<Peer> >::const_iterator i = _values.begin();
-        i != _values.end() && valuesList.size() < MAX_VALUES_SIZE; ++i) {
+    SharedHandle<List> valuesList = List::g();
+    for(std::vector<SharedHandle<Peer> >::const_iterator i = values_.begin(),
+          eoi = values_.end(); i != eoi && valuesList->size() < MAX_VALUES_SIZE;
+        ++i) {
       const SharedHandle<Peer>& peer = *i;
       unsigned char buffer[6];
-      if(bittorrent::createcompact(buffer, peer->ipaddr, peer->port)) {
-        valuesList << BDE(buffer, sizeof(buffer));
+      if(bittorrent::createcompact
+         (buffer, peer->getIPAddress(), peer->getPort())) {
+        valuesList->append(String::g(buffer, sizeof(buffer)));
       }
     }
-    rDict[VALUES] = valuesList;
+    rDict->put(VALUES, valuesList);
   }
   return rDict;  
 }
 
-std::string DHTGetPeersReplyMessage::getMessageType() const
+const std::string& DHTGetPeersReplyMessage::getMessageType() const
 {
   return GET_PEERS;
 }
 
-void DHTGetPeersReplyMessage::validate() const {}
-
-void DHTGetPeersReplyMessage::setClosestKNodes(const std::deque<SharedHandle<DHTNode> >& closestKNodes)
+void DHTGetPeersReplyMessage::accept(DHTMessageCallback* callback)
 {
-  _closestKNodes = closestKNodes;
-}
-
-void DHTGetPeersReplyMessage::setValues(const std::deque<SharedHandle<Peer> >& peers)
-{
-  _values = peers;
+  callback->visit(this);
 }
 
 std::string DHTGetPeersReplyMessage::toStringOptional() const
 {
-  return strconcat("token=", util::toHex(_token),
-                   ", values=", util::uitos(_values.size()),
-                   ", nodes=", util::uitos(_closestKNodes.size()));
+  return strconcat("token=", util::toHex(token_),
+                   ", values=", util::uitos(values_.size()),
+                   ", nodes=", util::uitos(closestKNodes_.size()));
 }
 
 } // namespace aria2
