@@ -37,7 +37,7 @@
 
 #include "DHTResponseMessage.h"
 
-#include <deque>
+#include <vector>
 
 #include "DHTConstants.h"
 
@@ -47,11 +47,11 @@ class Peer;
 
 class DHTGetPeersReplyMessage:public DHTResponseMessage {
 private:
-  std::string _token;
+  std::string token_;
 
-  std::deque<SharedHandle<DHTNode> > _closestKNodes;
+  std::vector<SharedHandle<DHTNode> > closestKNodes_;
 
-  std::deque<SharedHandle<Peer> > _values;
+  std::vector<SharedHandle<Peer> > values_;
 protected:
   virtual std::string toStringOptional() const;
 public:
@@ -64,29 +64,36 @@ public:
 
   virtual void doReceivedAction();
 
-  virtual BDE getResponse();
+  virtual SharedHandle<Dict> getResponse();
 
-  virtual std::string getMessageType() const;
+  virtual const std::string& getMessageType() const;
 
-  virtual void validate() const;
+  virtual void accept(DHTMessageCallback* callback);
 
-  const std::deque<SharedHandle<DHTNode> >& getClosestKNodes() const
+  const std::vector<SharedHandle<DHTNode> >& getClosestKNodes() const
   {
-    return _closestKNodes;
+    return closestKNodes_;
   }
 
-  const std::deque<SharedHandle<Peer> >& getValues() const
+  const std::vector<SharedHandle<Peer> >& getValues() const
   {
-    return _values;
+    return values_;
   }
 
-  void setClosestKNodes(const std::deque<SharedHandle<DHTNode> >& closestKNodes);
+  void setClosestKNodes
+  (const std::vector<SharedHandle<DHTNode> >& closestKNodes)
+  {
+    closestKNodes_ = closestKNodes;
+  }
 
-  void setValues(const std::deque<SharedHandle<Peer> >& peers);
+  void setValues(const std::vector<SharedHandle<Peer> >& peers)
+  {
+    values_ = peers;
+  }
   
   const std::string& getToken() const
   {
-    return _token;
+    return token_;
   }
 
   static const std::string GET_PEERS;
