@@ -46,43 +46,48 @@
 #include "util.h"
 #include "DHTBucket.h"
 #include "bittorrent_helper.h"
+#include "DHTPeerLookupTaskCallback.h"
+#include "DHTQueryMessage.h"
 
 namespace aria2 {
 
 DHTPeerLookupTask::DHTPeerLookupTask
 (const SharedHandle<DownloadContext>& downloadContext):
-  DHTAbstractNodeLookupTask(bittorrent::getInfoHash(downloadContext)) {}
+  DHTAbstractNodeLookupTask<DHTGetPeersReplyMessage>
+  (bittorrent::getInfoHash(downloadContext)) {}
 
 void
 DHTPeerLookupTask::getNodesFromMessage
 (std::vector<SharedHandle<DHTNode> >& nodes,
- const SharedHandle<DHTMessage>& message)
+ const DHTGetPeersReplyMessage* message)
 {
-  SharedHandle<DHTGetPeersReplyMessage> m
-    (dynamic_pointer_cast<DHTGetPeersReplyMessage>(message));
-  if(!m.isNull()) {
-    const std::vector<SharedHandle<DHTNode> >& knodes = m->getClosestKNodes();
-    nodes.insert(nodes.end(), knodes.begin(), knodes.end());
-  }
+  const std::vector<SharedHandle<DHTNode> >& knodes =
+    message->getClosestKNodes();
+  nodes.insert(nodes.end(), knodes.begin(), knodes.end());
 }
   
-void DHTPeerLookupTask::onReceivedInternal(const SharedHandle<DHTMessage>& message)
+void DHTPeerLookupTask::onReceivedInternal
+(const DHTGetPeersReplyMessage* message)
 {
-  SharedHandle<DHTGetPeersReplyMessage> m(dynamic_pointer_cast<DHTGetPeersReplyMessage>(message));
-  if(m.isNull()) {
-    return;
-  }
-  SharedHandle<DHTNode> remoteNode = m->getRemoteNode();
-  _tokenStorage[util::toHex(remoteNode->getID(), DHT_ID_LENGTH)] = m->getToken();
+  SharedHandle<DHTNode> remoteNode = message->getRemoteNode();
+  tokenStorage_[util::toHex(remoteNode->getID(), DHT_ID_LENGTH)] =
+    message->getToken();
+  peerStorage_->addPeer(message->getValues());
+  peers_.insert(peers_.end(),
+                message->getValues().begin(), message->getValues().end());
+  getLogger()->info("Received %u peers.", message->getValues().size());
+}
+  
+SharedHandle<DHTMessage> DHTPeerLookupTask::createMessage
+(const SharedHandle<DHTNode>& remoteNode)
+{
+  return getMessageFactory()->createGetPeersMessage(remoteNode, getTargetID());
+}
 
-  _peerStorage->addPeer(m->getValues());
-  _peers.insert(_peers.end(), m->getValues().begin(), m->getValues().end());
-  _logger->info("Received %u peers.", m->getValues().size());
-}
-  
-SharedHandle<DHTMessage> DHTPeerLookupTask::createMessage(const SharedHandle<DHTNode>& remoteNode)
+SharedHandle<DHTMessageCallback> DHTPeerLookupTask::createCallback()
 {
-  return _factory->createGetPeersMessage(remoteNode, _targetID);
+  return SharedHandle<DHTPeerLookupTaskCallback>
+    (new DHTPeerLookupTaskCallback(this));
 }
 
 void DHTPeerLookupTask::onFinish()
@@ -90,29 +95,29 @@ void DHTPeerLookupTask::onFinish()
   // send announce_peer message to K closest nodes
   size_t num = DHTBucket::K;
   for(std::deque<SharedHandle<DHTNodeLookupEntry> >::const_iterator i =
-        _entries.begin(), eoi = _entries.end(); i != eoi && num > 0; ++i,
-        --num) {
-    if((*i)->_used) {
-      const SharedHandle<DHTNode>& node = (*i)->_node;
+        getEntries().begin(), eoi = getEntries().end();
+      i != eoi && num > 0; ++i, --num) {
+    if((*i)->used) {
+      const SharedHandle<DHTNode>& node = (*i)->node;
       SharedHandle<DHTMessage> m = 
-        _factory->createAnnouncePeerMessage
+        getMessageFactory()->createAnnouncePeerMessage
         (node,
-         _targetID, // this is infoHash
-         _btRuntime->getListenPort(),
-         _tokenStorage[util::toHex(node->getID(), DHT_ID_LENGTH)]);
-      _dispatcher->addMessageToQueue(m);
+         getTargetID(), // this is infoHash
+         btRuntime_->getListenPort(),
+         tokenStorage_[util::toHex(node->getID(), DHT_ID_LENGTH)]);
+      getMessageDispatcher()->addMessageToQueue(m);
     }
   }
 }
 
 void DHTPeerLookupTask::setBtRuntime(const SharedHandle<BtRuntime>& btRuntime)
 {
-  _btRuntime = btRuntime;
+  btRuntime_ = btRuntime;
 }
 
 void DHTPeerLookupTask::setPeerStorage(const SharedHandle<PeerStorage>& ps)
 {
-  _peerStorage = ps;
+  peerStorage_ = ps;
 }
 
 } // namespace aria2
