@@ -50,11 +50,9 @@ public:
 
   virtual void doReceivedAction();
 
-  virtual BDE getArgument();
+  virtual SharedHandle<Dict> getArgument();
 
-  virtual std::string getMessageType() const;
-
-  virtual void validate() const;
+  virtual const std::string& getMessageType() const;
 
   static const std::string PING;
 };
