@@ -54,72 +54,80 @@
 #include "a2algo.h"
 #include "RequestGroupMan.h"
 #include "RequestGroup.h"
+#include "util.h"
 
 namespace aria2 {
 
 DefaultBtMessageDispatcher::DefaultBtMessageDispatcher():
   cuid(0),
-  requestTimeout(0),
-  logger(LogFactory::getInstance()) {}
+  requestTimeout_(0),
+  logger_(LogFactory::getInstance()) {}
 
 DefaultBtMessageDispatcher::~DefaultBtMessageDispatcher()
 {
-  logger->debug("DefaultBtMessageDispatcher::deleted");
+  if(logger_->debug()) {
+    logger_->debug("DefaultBtMessageDispatcher::deleted");
+  }
 }
 
-void DefaultBtMessageDispatcher::addMessageToQueue(const BtMessageHandle& btMessage)
+void DefaultBtMessageDispatcher::addMessageToQueue
+(const BtMessageHandle& btMessage)
 {
   btMessage->onQueued();
-  messageQueue.push_back(btMessage);
+  messageQueue_.push_back(btMessage);
 }
 
-void DefaultBtMessageDispatcher::addMessageToQueue(const BtMessages& btMessages)
+void DefaultBtMessageDispatcher::addMessageToQueue
+(const std::vector<SharedHandle<BtMessage> >& btMessages)
 {
-  for(BtMessages::const_iterator itr = btMessages.begin(); itr != btMessages.end(); itr++) {
+  for(std::vector<SharedHandle<BtMessage> >::const_iterator itr =
+        btMessages.begin(), eoi = btMessages.end(); itr != eoi; ++itr) {
     addMessageToQueue(*itr);
   }
 }
 
 void DefaultBtMessageDispatcher::sendMessages() {
-  BtMessages tempQueue;
-  while(!messageQueue.empty()) {
-    BtMessageHandle msg = messageQueue.front();
-    messageQueue.pop_front();
+  std::vector<SharedHandle<BtMessage> > tempQueue;
+  while(!messageQueue_.empty()) {
+    BtMessageHandle msg = messageQueue_.front();
+    messageQueue_.pop_front();
     if(msg->isUploading() && !msg->isSendingInProgress()) {
-      if(_requestGroupMan->doesOverallUploadSpeedExceed() ||
-         _downloadContext->getOwnerRequestGroup()->doesUploadSpeedExceed()) {
+      if(requestGroupMan_->doesOverallUploadSpeedExceed() ||
+         downloadContext_->getOwnerRequestGroup()->doesUploadSpeedExceed()) {
         tempQueue.push_back(msg);
         continue;
       }
     }
     msg->send();
     if(msg->isUploading()) {
-      _peerStorage->updateTransferStatFor(peer);
+      peerStorage_->updateTransferStatFor(peer_);
     }
     if(msg->isSendingInProgress()) {
-      messageQueue.push_front(msg);
+      messageQueue_.push_front(msg);
       break;
     }
   }
   if(!tempQueue.empty()) {
     // Insert pending message to the front, so that message is likely sent in
     // the same order as it is queued.
-    if(!messageQueue.empty() && messageQueue.front()->isSendingInProgress()) {
-      messageQueue.insert(messageQueue.begin()+1,
-                          tempQueue.begin(), tempQueue.end());
+    if(!messageQueue_.empty() && messageQueue_.front()->isSendingInProgress()) {
+      messageQueue_.insert(messageQueue_.begin()+1,
+                           tempQueue.begin(), tempQueue.end());
     } else {
-      messageQueue.insert(messageQueue.begin(),
-                          tempQueue.begin(), tempQueue.end());
+      messageQueue_.insert(messageQueue_.begin(),
+                           tempQueue.begin(), tempQueue.end());
     }
   }
 }
 
 // Cancel sending piece message to peer.
-void DefaultBtMessageDispatcher::doCancelSendingPieceAction(size_t index, uint32_t begin, size_t length)
+void DefaultBtMessageDispatcher::doCancelSendingPieceAction
+(size_t index, uint32_t begin, size_t length)
 {
   BtCancelSendingPieceEvent event(index, begin, length);
 
-  BtMessages tempQueue = messageQueue;
+  std::vector<SharedHandle<BtMessage> > tempQueue
+    (messageQueue_.begin(), messageQueue_.end());
 
   forEachMemFunSH(tempQueue.begin(), tempQueue.end(),
                   &BtMessage::onCancelSendingPieceEvent, event);
@@ -127,76 +135,83 @@ void DefaultBtMessageDispatcher::doCancelSendingPieceAction(size_t index, uint32
 
 // Cancel sending piece message to peer.
 // TODO Is this method really necessary?
-void DefaultBtMessageDispatcher::doCancelSendingPieceAction(const PieceHandle& piece)
+void DefaultBtMessageDispatcher::doCancelSendingPieceAction
+(const SharedHandle<Piece>& piece)
 {
 }
 
 class AbortOutstandingRequest {
 private:
-  SharedHandle<Piece> _piece;
-  int32_t _cuid;
-  Logger* _logger;
+  SharedHandle<Piece> piece_;
+  cuid_t cuid_;
+  Logger* logger_;
 public:
-  AbortOutstandingRequest(const SharedHandle<Piece>& piece, int32_t cuid):
-    _piece(piece),
-    _cuid(cuid),
-    _logger(LogFactory::getInstance()) {}
+  AbortOutstandingRequest(const SharedHandle<Piece>& piece, cuid_t cuid):
+    piece_(piece),
+    cuid_(cuid),
+    logger_(LogFactory::getInstance()) {}
 
   void operator()(const RequestSlot& slot) const
   {
-    _logger->debug(MSG_DELETING_REQUEST_SLOT,
-                   _cuid,
-                   slot.getIndex(),
-                   slot.getBlockIndex());
-    _logger->debug("index=%d, begin=%d", slot.getIndex(), slot.getBegin());
-    _piece->cancelBlock(slot.getBlockIndex());
+    if(logger_->debug()) {
+      logger_->debug(MSG_DELETING_REQUEST_SLOT,
+                     util::itos(cuid_).c_str(),
+                     slot.getIndex(),
+                     slot.getBlockIndex());
+      logger_->debug("index=%d, begin=%d", slot.getIndex(), slot.getBegin());
+    }
+    piece_->cancelBlock(slot.getBlockIndex());
   }
 };
 
 // localhost cancels outstanding download requests to the peer.
-void DefaultBtMessageDispatcher::doAbortOutstandingRequestAction(const PieceHandle& piece) {
+void DefaultBtMessageDispatcher::doAbortOutstandingRequestAction
+(const SharedHandle<Piece>& piece) {
   RequestSlot rs(piece->getIndex(), 0, 0, 0);
   std::deque<RequestSlot>::iterator first =
-    std::lower_bound(requestSlots.begin(), requestSlots.end(), rs);
+    std::lower_bound(requestSlots_.begin(), requestSlots_.end(), rs);
 
   rs.setIndex(piece->getIndex()+1);
   std::deque<RequestSlot>::iterator last =
-    std::lower_bound(requestSlots.begin(), requestSlots.end(), rs);
+    std::lower_bound(requestSlots_.begin(), requestSlots_.end(), rs);
 
   std::for_each(first, last, AbortOutstandingRequest(piece, cuid));
-  requestSlots.erase(first, last);
+  requestSlots_.erase(first, last);
 
   BtAbortOutstandingRequestEvent event(piece);
 
-  BtMessages tempQueue = messageQueue;
+  std::vector<SharedHandle<BtMessage> > tempQueue
+    (messageQueue_.begin(), messageQueue_.end());
   forEachMemFunSH(tempQueue.begin(), tempQueue.end(),
                   &BtMessage::onAbortOutstandingRequestEvent, event);
 }
 
 class ProcessChokedRequestSlot {
 private:
-  int32_t _cuid;
-  SharedHandle<Peer> _peer;
-  SharedHandle<PieceStorage> _pieceStorage;
-  Logger* _logger;
+  cuid_t cuid_;
+  SharedHandle<Peer> peer_;
+  SharedHandle<PieceStorage> pieceStorage_;
+  Logger* logger_;
 public:
-  ProcessChokedRequestSlot(int32_t cuid,
+  ProcessChokedRequestSlot(cuid_t cuid,
                            const SharedHandle<Peer>& peer,
                            const SharedHandle<PieceStorage>& pieceStorage):
-    _cuid(cuid),
-    _peer(peer),
-    _pieceStorage(pieceStorage),
-    _logger(LogFactory::getInstance()) {}
+    cuid_(cuid),
+    peer_(peer),
+    pieceStorage_(pieceStorage),
+    logger_(LogFactory::getInstance()) {}
   
   void operator()(const RequestSlot& slot) const
   {
-    if(!_peer->isInPeerAllowedIndexSet(slot.getIndex())) {
-      _logger->debug(MSG_DELETING_REQUEST_SLOT_CHOKED,
-                     _cuid,
-                     slot.getIndex(),
-                     slot.getBlockIndex());
-      _logger->debug("index=%d, begin=%d", slot.getIndex(), slot.getBegin());
-      SharedHandle<Piece> piece = _pieceStorage->getPiece(slot.getIndex());
+    if(!peer_->isInPeerAllowedIndexSet(slot.getIndex())) {
+      if(logger_->debug()) {
+        logger_->debug(MSG_DELETING_REQUEST_SLOT_CHOKED,
+                       util::itos(cuid_).c_str(),
+                       slot.getIndex(),
+                       slot.getBlockIndex());
+        logger_->debug("index=%d, begin=%d", slot.getIndex(), slot.getBegin());
+      }
+      SharedHandle<Piece> piece = pieceStorage_->getPiece(slot.getIndex());
       piece->cancelBlock(slot.getBlockIndex());
     }
   }
@@ -205,26 +220,26 @@ public:
 
 class FindChokedRequestSlot {
 private:
-  SharedHandle<Peer> _peer;
+  SharedHandle<Peer> peer_;
 public:
   FindChokedRequestSlot(const SharedHandle<Peer>& peer):
-    _peer(peer) {}
+    peer_(peer) {}
   
   bool operator()(const RequestSlot& slot) const
   {
-    return !_peer->isInPeerAllowedIndexSet(slot.getIndex());
+    return !peer_->isInPeerAllowedIndexSet(slot.getIndex());
   }
 };
 
 // localhost received choke message from the peer.
 void DefaultBtMessageDispatcher::doChokedAction()
 {
-  std::for_each(requestSlots.begin(), requestSlots.end(),
-                ProcessChokedRequestSlot(cuid, peer, _pieceStorage));
+  std::for_each(requestSlots_.begin(), requestSlots_.end(),
+                ProcessChokedRequestSlot(cuid, peer_, pieceStorage_));
 
-  requestSlots.erase(std::remove_if(requestSlots.begin(), requestSlots.end(),
-                                    FindChokedRequestSlot(peer)),
-                     requestSlots.end());
+  requestSlots_.erase(std::remove_if(requestSlots_.begin(), requestSlots_.end(),
+                                     FindChokedRequestSlot(peer_)),
+                      requestSlots_.end());
 }
 
 // localhost dispatched choke message to the peer.
@@ -232,53 +247,55 @@ void DefaultBtMessageDispatcher::doChokingAction()
 {
   BtChokingEvent event;
 
-  BtMessages tempQueue = messageQueue;
+  std::vector<SharedHandle<BtMessage> > tempQueue
+    (messageQueue_.begin(), messageQueue_.end());
   forEachMemFunSH(tempQueue.begin(), tempQueue.end(),
                   &BtMessage::onChokingEvent, event);
 }
 
 class ProcessStaleRequestSlot {
 private:
-  int32_t _cuid;
-  SharedHandle<Peer> _peer;
-  SharedHandle<PieceStorage> _pieceStorage;
-  BtMessageDispatcher* _messageDispatcher;
-  WeakHandle<BtMessageFactory> _messageFactory;
-  const struct timeval& _now;
-  time_t _requestTimeout;
-  Logger* _logger;
+  cuid_t cuid_;
+  SharedHandle<Peer> peer_;
+  SharedHandle<PieceStorage> pieceStorage_;
+  BtMessageDispatcher* messageDispatcher_;
+  WeakHandle<BtMessageFactory> messageFactory_;
+  time_t requestTimeout_;
+  Logger* logger_;
 public:
-  ProcessStaleRequestSlot(int32_t cuid, const SharedHandle<Peer>& peer,
+  ProcessStaleRequestSlot(cuid_t cuid, const SharedHandle<Peer>& peer,
                           const SharedHandle<PieceStorage>& pieceStorage,
                           BtMessageDispatcher* dispatcher,
                           const WeakHandle<BtMessageFactory>& factory,
-                          const struct timeval& now,
                           time_t requestTimeout):
-    _cuid(cuid),
-    _peer(peer),
-    _pieceStorage(pieceStorage),
-    _messageDispatcher(dispatcher),
-    _messageFactory(factory),
-    _now(now),
-    _requestTimeout(requestTimeout),
-    _logger(LogFactory::getInstance()) {}
+    cuid_(cuid),
+    peer_(peer),
+    pieceStorage_(pieceStorage),
+    messageDispatcher_(dispatcher),
+    messageFactory_(factory),
+    requestTimeout_(requestTimeout),
+    logger_(LogFactory::getInstance()) {}
 
   void operator()(const RequestSlot& slot)
   {
-    if(slot.isTimeout(_now, _requestTimeout)) {
-      _logger->debug(MSG_DELETING_REQUEST_SLOT_TIMEOUT,
-                     _cuid,
-                     slot.getBlockIndex());
-      _logger->debug("index=%d, begin=%d", slot.getIndex(), slot.getBegin());
+    if(slot.isTimeout(requestTimeout_)) {
+      if(logger_->debug()) {
+        logger_->debug(MSG_DELETING_REQUEST_SLOT_TIMEOUT,
+                       util::itos(cuid_).c_str(),
+                       slot.getBlockIndex());
+        logger_->debug("index=%d, begin=%d", slot.getIndex(), slot.getBegin());
+      }
       slot.getPiece()->cancelBlock(slot.getBlockIndex());
-      _peer->snubbing(true);
+      peer_->snubbing(true);
     } else if(slot.getPiece()->hasBlock(slot.getBlockIndex())) {
-      _logger->debug(MSG_DELETING_REQUEST_SLOT_ACQUIRED,
-                     _cuid,
-                     slot.getBlockIndex());
-      _logger->debug("index=%d, begin=%d", slot.getIndex(), slot.getBegin());
-      _messageDispatcher->addMessageToQueue
-        (_messageFactory->createCancelMessage(slot.getIndex(),
+      if(logger_->debug()) {
+        logger_->debug(MSG_DELETING_REQUEST_SLOT_ACQUIRED,
+                       util::itos(cuid_).c_str(),
+                       slot.getBlockIndex());
+        logger_->debug("index=%d, begin=%d", slot.getIndex(), slot.getBegin());
+      }
+      messageDispatcher_->addMessageToQueue
+        (messageFactory_->createCancelMessage(slot.getIndex(),
                                               slot.getBegin(),
                                               slot.getLength()));
     }
@@ -287,20 +304,17 @@ public:
 
 class FindStaleRequestSlot {
 private:
-  SharedHandle<PieceStorage> _pieceStorage;
-  const struct timeval& _now;
-  time_t _requestTimeout;
+  SharedHandle<PieceStorage> pieceStorage_;
+  time_t requestTimeout_;
 public:
   FindStaleRequestSlot(const SharedHandle<PieceStorage>& pieceStorage,
-                       const struct timeval& now,
                        time_t requestTimeout):
-    _pieceStorage(pieceStorage),
-    _now(now),
-    _requestTimeout(requestTimeout) {}
+    pieceStorage_(pieceStorage),
+    requestTimeout_(requestTimeout) {}
 
   bool operator()(const RequestSlot& slot)
   {
-    if(slot.isTimeout(_now, _requestTimeout)) {
+    if(slot.isTimeout(requestTimeout_)) {
       return true;
     } else {
       if(slot.getPiece()->hasBlock(slot.getBlockIndex())) {
@@ -314,38 +328,28 @@ public:
 
 void DefaultBtMessageDispatcher::checkRequestSlotAndDoNecessaryThing()
 {
-  struct timeval now;
-  gettimeofday(&now, 0);
-
-  std::for_each(requestSlots.begin(), requestSlots.end(),
+  std::for_each(requestSlots_.begin(), requestSlots_.end(),
                 ProcessStaleRequestSlot(cuid,
-                                        peer,
-                                        _pieceStorage,
+                                        peer_,
+                                        pieceStorage_,
                                         this,
-                                        messageFactory,
-                                        now,
-                                        requestTimeout));
-  requestSlots.erase(std::remove_if(requestSlots.begin(), requestSlots.end(),
-                                    FindStaleRequestSlot(_pieceStorage,
-                                                         now,
-                                                         requestTimeout)),
-                     requestSlots.end());
+                                        messageFactory_,
+                                        requestTimeout_));
+  requestSlots_.erase(std::remove_if(requestSlots_.begin(), requestSlots_.end(),
+                                     FindStaleRequestSlot(pieceStorage_,
+                                                          requestTimeout_)),
+                      requestSlots_.end());
 }
 
 bool DefaultBtMessageDispatcher::isSendingInProgress()
 {
-  if(messageQueue.size() > 0) {
-    return messageQueue.front()->isSendingInProgress();
-  } else {
+  if(messageQueue_.empty()) {
     return false;
+  } else {
+    return messageQueue_.front()->isSendingInProgress();
   }
 }
 
-size_t DefaultBtMessageDispatcher::countOutstandingRequest()
-{
-  return requestSlots.size();
-}
-
 class BlockIndexLess {
 public:
   bool operator()(const RequestSlot& lhs, const RequestSlot& rhs) const
@@ -358,23 +362,26 @@ public:
   }
 };
 
-bool DefaultBtMessageDispatcher::isOutstandingRequest(size_t index, size_t blockIndex) {
+bool DefaultBtMessageDispatcher::isOutstandingRequest
+(size_t index, size_t blockIndex) {
   RequestSlot rs(index, 0, 0, blockIndex);
 
   std::deque<RequestSlot>::iterator i =
-    std::lower_bound(requestSlots.begin(), requestSlots.end(), rs, BlockIndexLess());
-  return i != requestSlots.end() &&
+    std::lower_bound(requestSlots_.begin(), requestSlots_.end(),
+                     rs, BlockIndexLess());
+  return i != requestSlots_.end() &&
     (*i).getIndex() == index && (*i).getBlockIndex() == blockIndex;
 }
 
 RequestSlot
-DefaultBtMessageDispatcher::getOutstandingRequest(size_t index, uint32_t begin, size_t length)
+DefaultBtMessageDispatcher::getOutstandingRequest
+(size_t index, uint32_t begin, size_t length)
 {
   RequestSlot ret;
   RequestSlot rs(index, begin, length, 0);
   std::deque<RequestSlot>::iterator i =
-    std::lower_bound(requestSlots.begin(), requestSlots.end(), rs);
-  if(i != requestSlots.end() && (*i) == rs) {
+    std::lower_bound(requestSlots_.begin(), requestSlots_.end(), rs);
+  if(i != requestSlots_.end() && (*i) == rs) {
     ret = *i;
   } else {
     ret = RequestSlot::nullSlot;
@@ -382,63 +389,66 @@ DefaultBtMessageDispatcher::getOutstandingRequest(size_t index, uint32_t begin,
   return ret;
 }
 
-void DefaultBtMessageDispatcher::removeOutstandingRequest(const RequestSlot& slot)
+void DefaultBtMessageDispatcher::removeOutstandingRequest
+(const RequestSlot& slot)
 {
   std::deque<RequestSlot>::iterator i =
-    std::lower_bound(requestSlots.begin(), requestSlots.end(), slot);
-  if(i != requestSlots.end() && (*i) == slot) {
+    std::lower_bound(requestSlots_.begin(), requestSlots_.end(), slot);
+  if(i != requestSlots_.end() && (*i) == slot) {
     AbortOutstandingRequest(slot.getPiece(), cuid)(*i);
-    requestSlots.erase(i);
+    requestSlots_.erase(i);
   }
 }
 
-void DefaultBtMessageDispatcher::addOutstandingRequest(const RequestSlot& slot)
+void DefaultBtMessageDispatcher::addOutstandingRequest
+(const RequestSlot& slot)
 {
   std::deque<RequestSlot>::iterator i =
-    std::lower_bound(requestSlots.begin(), requestSlots.end(), slot);
-  if(i == requestSlots.end() || (*i) != slot) {
-    requestSlots.insert(i, slot);
+    std::lower_bound(requestSlots_.begin(), requestSlots_.end(), slot);
+  if(i == requestSlots_.end() || (*i) != slot) {
+    requestSlots_.insert(i, slot);
   }
 }
 
 size_t DefaultBtMessageDispatcher::countOutstandingUpload()
 {
-  return std::count_if(messageQueue.begin(), messageQueue.end(),
+  return std::count_if(messageQueue_.begin(), messageQueue_.end(),
                        mem_fun_sh(&BtMessage::isUploading));
 }
 
 void DefaultBtMessageDispatcher::setPeer(const SharedHandle<Peer>& peer)
 {
-  this->peer = peer;
+  peer_ = peer;
 }
 
 void DefaultBtMessageDispatcher::setDownloadContext
 (const SharedHandle<DownloadContext>& downloadContext)
 {
-  _downloadContext = downloadContext;
+  downloadContext_ = downloadContext;
 }
 
 void DefaultBtMessageDispatcher::setPieceStorage
 (const SharedHandle<PieceStorage>& pieceStorage)
 {
-  _pieceStorage = pieceStorage;
+  pieceStorage_ = pieceStorage;
 }
 
 void DefaultBtMessageDispatcher::setPeerStorage
 (const SharedHandle<PeerStorage>& peerStorage)
 {
-  _peerStorage = peerStorage;
+  peerStorage_ = peerStorage;
 }
 
-void DefaultBtMessageDispatcher::setBtMessageFactory(const WeakHandle<BtMessageFactory>& factory)
+void DefaultBtMessageDispatcher::setBtMessageFactory
+(const WeakHandle<BtMessageFactory>& factory)
 {
-  this->messageFactory = factory;
+  messageFactory_ = factory;
 }
 
 void DefaultBtMessageDispatcher::setRequestGroupMan
 (const WeakHandle<RequestGroupMan>& rgman)
 {
-  _requestGroupMan = rgman;
+  requestGroupMan_ = rgman;
 }
 
 } // namespace aria2
