@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,31 +37,39 @@
 
 #include "BtProgressInfoFile.h"
 
+namespace aria2 {
+
 class DownloadContext;
-typedef SharedHandle<DownloadContext> DownloadContextHandle;
 class PieceStorage;
-typedef SharedHandle<PieceStorage> PieceStorageHandle;
+class PeerStorage;
+class BtRuntime;
 class Logger;
 class Option;
 
 class DefaultBtProgressInfoFile : public BtProgressInfoFile {
 private:
-  DownloadContextHandle _dctx;
-  PieceStorageHandle _pieceStorage;
-  const Option* _option;
-  const Logger* _logger;
-  string _filename;
+  SharedHandle<DownloadContext> dctx_;
+  SharedHandle<PieceStorage> pieceStorage_;
+#ifdef ENABLE_BITTORRENT
+  SharedHandle<PeerStorage> peerStorage_;
+  SharedHandle<BtRuntime> btRuntime_;
+#endif // ENABLE_BITTORRENT
+  const Option* option_;
+  Logger* logger_;
+  std::string filename_;
 
   bool isTorrentDownload();
 
+  static const std::string V0000;
+  static const std::string V0001;
 public:
-  DefaultBtProgressInfoFile(const DownloadContextHandle& btContext,
-			    const PieceStorageHandle& pieceStorage,
-			    const Option* option);
+  DefaultBtProgressInfoFile(const SharedHandle<DownloadContext>& btContext,
+                            const SharedHandle<PieceStorage>& pieceStorage,
+                            const Option* option);
 
   virtual ~DefaultBtProgressInfoFile();
 
-  virtual string getFilename() { return _filename; }
+  virtual std::string getFilename() { return filename_; }
   
   virtual bool exists();
 
@@ -71,6 +79,23 @@ public:
 
   virtual void removeFile();
 
+  // re-set filename using current dctx_.
+  virtual void updateFilename();
+
+#ifdef ENABLE_BITTORRENT
+  // for torrents
+  void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage);
+
+  void setBtRuntime(const SharedHandle<BtRuntime>& btRuntime);
+#endif // ENABLE_BITTORRENT
+
+  static const std::string& getSuffix()
+  {
+    static std::string suffix = ".aria2";
+    return suffix;
+  }
 };
 
+} // namespace aria2
+
 #endif // _D_DEFAULT_BT_PROGRESS_INFO_FILE_H_
