@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,98 +36,74 @@
 #define _D_DEFAULT_BT_REQUEST_FACTORY_H_
 
 #include "BtRequestFactory.h"
-#include "BtContext.h"
-#include "PieceStorage.h"
-#include "Piece.h"
-#include "Peer.h"
-#include "BtMessageDispatcher.h"
-#include "BtRegistry.h"
-#include "LogFactory.h"
+
+#include <deque>
+
+#include "Command.h"
+
+namespace aria2 {
+
+class PieceStorage;
+class Peer;
+class BtMessageDispatcher;
+class BtMessageFactory;
+class Piece;
+class Logger;
 
 class DefaultBtRequestFactory : public BtRequestFactory {
 private:
-  int32_t cuid;
-  BtContextHandle btContext;
-  PieceStorageHandle pieceStorage;
-  PeerHandle peer;
-  BtMessageDispatcherWeakHandle dispatcher;
-  BtMessageFactoryWeakHandle messageFactory;
-  Pieces pieces;
+  SharedHandle<PieceStorage> pieceStorage_;
+  SharedHandle<Peer> peer_;
+  WeakHandle<BtMessageDispatcher> dispatcher_;
+  WeakHandle<BtMessageFactory> messageFactory_;
+  std::deque<SharedHandle<Piece> > pieces_;
+  Logger* logger_;
 public:
-  DefaultBtRequestFactory():
-    cuid(0),
-    btContext(0),
-    pieceStorage(0),
-    peer(0),
-    dispatcher(0)
-  {
-    LogFactory::getInstance()->debug("DefaultBtRequestFactory::instantiated");
-  }
+  DefaultBtRequestFactory();
 
-  virtual ~DefaultBtRequestFactory()
-  {
-    LogFactory::getInstance()->debug("DefaultBtRequestFactory::deleted");
-  }
+  virtual ~DefaultBtRequestFactory();
 
-  virtual void addTargetPiece(const PieceHandle& piece) {
-    pieces.push_back(piece);
-  }
+  virtual void addTargetPiece(const SharedHandle<Piece>& piece);
 
-  virtual void removeTargetPiece(const PieceHandle& piece);
+  virtual void removeTargetPiece(const SharedHandle<Piece>& piece);
 
   virtual void removeAllTargetPiece();
 
-  virtual int32_t countTargetPiece() {
-    return pieces.size();
+  virtual size_t countTargetPiece() {
+    return pieces_.size();
   }
 
+  virtual size_t countMissingBlock();
+
   virtual void removeCompletedPiece();
 
   virtual void doChokedAction();
 
-  virtual BtMessages createRequestMessages(int32_t max);
+  virtual void createRequestMessages
+  (std::vector<SharedHandle<BtMessage> >& requests, size_t max);
 
-  virtual BtMessages createRequestMessagesOnEndGame(int32_t max);
+  virtual void createRequestMessagesOnEndGame
+  (std::vector<SharedHandle<BtMessage> >& requests, size_t max);
 
-  Pieces& getTargetPieces() {
-    return pieces;
-  }
+  virtual void getTargetPieceIndexes(std::vector<size_t>& indexes) const;
 
-  void setCuid(int32_t cuid) {
-    this->cuid = cuid;
-  }
-
-  int32_t getCuid() const {
-    return cuid;
-  }
-
-  void setBtContext(const BtContextHandle& btContext) {
-    this->btContext = btContext;
-    this->pieceStorage = PIECE_STORAGE(btContext);
-  }
-
-  BtContextHandle getBtContext() const {
-    return btContext;
-  }
-
-  PeerHandle getPeer() const {
-    return peer;
-  }
-
-  void setPeer(const PeerHandle& peer) {
-    this->peer = peer;
-  }
-
-  void setBtMessageDispatcher(const BtMessageDispatcherWeakHandle& dispatcher)
+  std::deque<SharedHandle<Piece> >& getTargetPieces()
   {
-    this->dispatcher = dispatcher;
+    return pieces_;
   }
 
-  void setBtMessageFactory(const BtMessageFactoryWeakHandle& factory) {
-    this->messageFactory = factory;
-  }
+  void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage);
+
+  void setPeer(const SharedHandle<Peer>& peer);
+
+  void setBtMessageDispatcher
+  (const WeakHandle<BtMessageDispatcher>& dispatcher);
+
+  void setBtMessageFactory(const WeakHandle<BtMessageFactory>& factory);
 };
 
 typedef SharedHandle<DefaultBtRequestFactory> DefaultBtRequestFactoryHandle;
 
+} // namespace aria2
+
 #endif // _D_DEFAULT_BT_REQUEST_FACTORY_H_
