@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,18 +36,33 @@
 #define _D_DISK_ADAPTOR_H_
 
 #include "BinaryStream.h"
-#include "FileEntry.h"
-#include "Logger.h"
-#include "FileAllocationIterator.h"
+
+#include <string>
+#include <vector>
+
+#include "TimeA2.h"
+
+namespace aria2 {
+
+class FileEntry;
+class Logger;
+class FileAllocationIterator;
 
 class DiskAdaptor:public BinaryStream {
+private:
+  std::vector<SharedHandle<FileEntry> > fileEntries_;
+
+  bool fallocate_;
+
+  Logger* logger_;
 protected:
-  string storeDir;
-  FileEntries fileEntries;
-  const Logger* logger;
+  Logger* getLogger() const
+  {
+    return logger_;
+  }
 public:
   DiskAdaptor();
-  virtual ~DiskAdaptor();
+  virtual ~DiskAdaptor() {}
 
   virtual void openFile() = 0;
 
@@ -57,44 +72,62 @@ public:
 
   virtual void initAndOpenFile() = 0;
 
-  virtual void onDownloadComplete() = 0;  
-
   virtual bool fileExists() = 0;
 
-  virtual string getFilePath() = 0;
+  virtual uint64_t size() = 0;
 
-  virtual int64_t size() const = 0;
-
-  // optional behavior
-  virtual void truncate(int64_t length) {}
-
-  void setFileEntries(const FileEntries& fileEntries) {
-    this->fileEntries = fileEntries;
+  template<typename InputIterator>
+  void setFileEntries(InputIterator first, InputIterator last)
+  {
+    fileEntries_.assign(first, last);
   }
 
-  FileEntryHandle getFileEntryFromPath(const string& fileEntryPath) const;
+  const std::vector<SharedHandle<FileEntry> >& getFileEntries() const
+  {
+    return fileEntries_;
+  }
 
-  const FileEntries& getFileEntries() const { return fileEntries; }
-
-  bool addDownloadEntry(const string& fileEntryPath);
-
-  bool addDownloadEntry(int index);
-
-  void addAllDownloadEntry();
-
-  void removeAllDownloadEntry();
-
-  void setStoreDir(const string& storeDir) { this->storeDir = storeDir; }
-
-  const string& getStoreDir() const { return this->storeDir; }
-
-  virtual FileAllocationIteratorHandle fileAllocationIterator() = 0;
+  virtual SharedHandle<FileAllocationIterator> fileAllocationIterator() = 0;
 
   virtual void enableDirectIO() {}
 
   virtual void disableDirectIO() {}
+
+  virtual void enableReadOnly() {}
+
+  virtual void disableReadOnly() {}
+
+  virtual bool isReadOnlyEnabled() const { return false; }
+
+  // Assumed each file length is stored in fileEntries or DiskAdaptor knows it.
+  // If each actual file's length is larger than that, truncate file to that
+  // length.
+  // Call one of openFile/openExistingFile/initAndOpenFile before calling this
+  // function.
+  virtual void cutTrailingGarbage() = 0;
+
+  // Returns the number of files, the actime and modtime of which are
+  // successfully changed.
+  virtual size_t utime(const Time& actime, const Time& modtime) = 0;
+
+  void enableFallocate()
+  {
+    fallocate_ = true;
+  }
+
+  void disableFallocate()
+  {
+    fallocate_ = false;
+  }
+
+  bool doesFallocate() const
+  {
+    return fallocate_;
+  }
 };
 
 typedef SharedHandle<DiskAdaptor> DiskAdaptorHandle;
 
+} // namespace aria2
+
 #endif // _D_DISK_ADAPTOR_H_
