@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,26 +37,23 @@
 
 #include "BinaryStream.h"
 
+namespace aria2 {
+
 /**
  * Interface for writing to a binary stream of bytes.
  *
  */
 class DiskWriter:public BinaryStream {
-protected:
-  bool _directIOAllowed;
-
 public:
-  DiskWriter():_directIOAllowed(false) {}
+  DiskWriter() {}
 
   virtual ~DiskWriter() {}
   /**
-   * Creates a file output stream to write to the file with the specified name.
-   * If the file exists, then it is truncated to 0 length.
-   * @param filename the file name to be opened.
+   * Opens file. If the file exists, then it is truncated to 0 length.
    */
-  virtual void initAndOpenFile(const string& filename, int64_t totalLength = 0)  = 0;
+  virtual void initAndOpenFile(uint64_t totalLength = 0)  = 0;
   
-  virtual void openFile(const string& filename, int64_t totalLength = 0) = 0;
+  virtual void openFile(uint64_t totalLength = 0) = 0;
 
   /**
    * Closes this output stream.
@@ -65,33 +62,33 @@ public:
   virtual void closeFile() = 0;
 
   /**
-   * Opens a file output stream to write to the file with the specified name.
-   * If the file doesnot exists, an exception may be throwed.
-   *
-   * @param filename the file name to be opened.
+   * Opens a file.  If the file doesnot exists, an exception may be
+   * thrown.
    */
-  virtual void openExistingFile(const string& filename, int64_t totalLength = 0) = 0;
-
-  virtual void truncate(int64_t length) = 0;
+  virtual void openExistingFile(uint64_t totalLength = 0) = 0;
 
   // Returns file length
-  virtual int64_t size() const = 0;
+  virtual uint64_t size() = 0;
 
   virtual void enableDirectIO() = 0;
 
   virtual void disableDirectIO() = 0;
 
-  virtual bool directIOAllowed() const
-  {
-    return _directIOAllowed;
-  }
+  virtual void allowDirectIO() {}
 
-  void setDirectIOAllowed(bool f)
-  {
-    _directIOAllowed = f;
-  }
+  // Enables read-only mode. After this call, openExistingFile() opens
+  // file in read-only mode. This is an optional functionality. The
+  // default implementation is do nothing.
+  virtual void enableReadOnly() {}
+
+  // Disables read-only mode. After this call, openExistingFile()
+  // opens file in read/write mode. This is an optional
+  // functionality. The default implementation is do noting.
+  virtual void disableReadOnly() {}
 };
 
 typedef SharedHandle<DiskWriter> DiskWriterHandle;
 
+} // namespace aria2
+
 #endif // _D_DISK_WRITER_H_
