@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -40,10 +40,11 @@
 #include <string>
 #include <deque>
 #include <map>
+#include <vector>
 
 #include "SharedHandle.h"
 #include "a2netcompat.h"
-#include "TimeA2.h"
+#include "TimerA2.h"
 #include "a2io.h"
 #ifdef ENABLE_ASYNC_DNS
 # include "AsyncNameResolver.h"
@@ -51,6 +52,7 @@
 #include "CUIDCounter.h"
 #include "FileAllocationMan.h"
 #include "CheckIntegrityMan.h"
+#include "DNSCache.h"
 
 namespace aria2 {
 
@@ -60,7 +62,6 @@ class RequestGroupMan;
 class StatCalc;
 class SocketCore;
 class CookieStorage;
-class DNSCache;
 class AuthConfigFactory;
 class Request;
 class EventPoll;
@@ -73,27 +74,32 @@ class DownloadEngine {
 private:
   void waitData();
 
-  SharedHandle<EventPoll> _eventPoll;
+  std::string sessionId_;
 
-  Logger* logger;
+  SharedHandle<EventPoll> eventPoll_;
+
+  Logger* logger_;
   
-  SharedHandle<StatCalc> _statCalc;
+  SharedHandle<StatCalc> statCalc_;
 
-  bool _haltRequested;
+  bool haltRequested_;
 
   class SocketPoolEntry {
   private:
-    SharedHandle<SocketCore> _socket;
+    SharedHandle<SocketCore> socket_;
 
-    std::map<std::string, std::string> _options;
+    std::map<std::string, std::string> options_;
 
-    time_t _timeout;
+    time_t timeout_;
 
-    Time _registeredTime;
+    Timer registeredTime_;
   public:
     SocketPoolEntry(const SharedHandle<SocketCore>& socket,
-		    const std::map<std::string, std::string>& option,
-		    time_t timeout);
+                    const std::map<std::string, std::string>& option,
+                    time_t timeout);
+
+    SocketPoolEntry(const SharedHandle<SocketCore>& socket,
+                    time_t timeout);
 
     ~SocketPoolEntry();
 
@@ -101,39 +107,39 @@ private:
 
     const SharedHandle<SocketCore>& getSocket() const
     {
-      return _socket;
+      return socket_;
     }
 
     const std::map<std::string, std::string>& getOptions() const
     {
-      return _options;
+      return options_;
     }
   };
 
   // key = IP address:port, value = SocketPoolEntry
-  std::multimap<std::string, SocketPoolEntry> _socketPool;
+  std::multimap<std::string, SocketPoolEntry> socketPool_;
  
-  Time _lastSocketPoolScan;
+  Timer lastSocketPoolScan_;
 
-  bool _noWait;
+  bool noWait_;
 
   static const time_t DEFAULT_REFRESH_INTERVAL = 1;
 
-  time_t _refreshInterval;
+  time_t refreshInterval_;
 
-  std::deque<Command*> _routineCommands;
+  std::deque<Command*> routineCommands_;
 
-  SharedHandle<CookieStorage> _cookieStorage;
+  SharedHandle<CookieStorage> cookieStorage_;
 
 #ifdef ENABLE_BITTORRENT
-  SharedHandle<BtRegistry> _btRegistry;
+  SharedHandle<BtRegistry> btRegistry_;
 #endif // ENABLE_BITTORRENT
 
-  CUIDCounter _cuidCounter;
+  CUIDCounter cuidCounter_;
 
-  SharedHandle<DNSCache> _dnsCache;
+  SharedHandle<DNSCache> dnsCache_;
 
-  SharedHandle<AuthConfigFactory> _authConfigFactory;
+  SharedHandle<AuthConfigFactory> authConfigFactory_;
 
   /**
    * Delegates to StatCalc
@@ -144,105 +150,163 @@ private:
 
   void afterEachIteration();
   
-  void poolSocket(const std::string& ipaddr,
-		  uint16_t port,
-		  const SocketPoolEntry& entry);
+  void poolSocket(const std::string& key, const SocketPoolEntry& entry);
 
   std::multimap<std::string, SocketPoolEntry>::iterator
-  findSocketPoolEntry(const std::string& ipaddr, uint16_t port);
-public:
-  std::deque<Command*> commands;
-  SharedHandle<RequestGroupMan> _requestGroupMan;
-  SharedHandle<FileAllocationMan> _fileAllocationMan;
-  SharedHandle<CheckIntegrityMan> _checkIntegrityMan;
-  Option* option;
-  
+  findSocketPoolEntry(const std::string& key);
+
+  std::deque<Command*> commands_;
+  SharedHandle<RequestGroupMan> requestGroupMan_;
+  SharedHandle<FileAllocationMan> fileAllocationMan_;
+  SharedHandle<CheckIntegrityMan> checkIntegrityMan_;
+  Option* option_;
+public:  
   DownloadEngine(const SharedHandle<EventPoll>& eventPoll);
 
-  virtual ~DownloadEngine();
+  ~DownloadEngine();
 
   void run();
 
   void cleanQueue();
 
   bool addSocketForReadCheck(const SharedHandle<SocketCore>& socket,
-			     Command* command);
+                             Command* command);
   bool deleteSocketForReadCheck(const SharedHandle<SocketCore>& socket,
-				Command* command);
+                                Command* command);
   bool addSocketForWriteCheck(const SharedHandle<SocketCore>& socket,
-			      Command* command);
+                              Command* command);
   bool deleteSocketForWriteCheck(const SharedHandle<SocketCore>& socket,
-				 Command* command);
+                                 Command* command);
 
 #ifdef ENABLE_ASYNC_DNS
 
   bool addNameResolverCheck(const SharedHandle<AsyncNameResolver>& resolver,
-			    Command* command);
+                            Command* command);
   bool deleteNameResolverCheck(const SharedHandle<AsyncNameResolver>& resolver,
-			       Command* command);
+                               Command* command);
 #endif // ENABLE_ASYNC_DNS
 
-  void addCommand(const std::deque<Command*>& commands);
+  void addCommand(const std::vector<Command*>& commands)
+  {
+    commands_.insert(commands_.end(), commands.begin(), commands.end());
+  }
+
+  void addCommand(Command* command)
+  {
+    commands_.push_back(command);
+  }
+
+  const SharedHandle<RequestGroupMan>& getRequestGroupMan() const
+  {
+    return requestGroupMan_;
+  }
+
+  void setRequestGroupMan(const SharedHandle<RequestGroupMan>& rgman)
+  {
+    requestGroupMan_ = rgman;
+  }
+
+  const SharedHandle<FileAllocationMan>& getFileAllocationMan() const
+  {
+    return fileAllocationMan_;
+  }
+
+  void setFileAllocationMan(const SharedHandle<FileAllocationMan>& faman)
+  {
+    fileAllocationMan_ = faman;
+  }
+
+  const SharedHandle<CheckIntegrityMan>& getCheckIntegrityMan() const
+  {
+    return checkIntegrityMan_;
+  }
+
+  void setCheckIntegrityMan(const SharedHandle<CheckIntegrityMan>& ciman)
+  {
+    checkIntegrityMan_ = ciman;
+  }
+
+  Option* getOption() const
+  {
+    return option_;
+  }
+
+  void setOption(Option* op)
+  {
+    option_ = op;
+  }
 
   void setStatCalc(const SharedHandle<StatCalc>& statCalc);
 
   bool isHaltRequested() const
   {
-    return _haltRequested;
+    return haltRequested_;
   }
 
   void requestHalt();
 
+  void requestForceHalt();
+
   void setNoWait(bool b);
 
   void addRoutineCommand(Command* command);
 
   void poolSocket(const std::string& ipaddr, uint16_t port,
-		  const SharedHandle<SocketCore>& sock,
-		  const std::map<std::string, std::string>& options,
-		  time_t timeout = 15);
+                  const std::string& username,
+                  const std::string& proxyhost, uint16_t proxyport,
+                  const SharedHandle<SocketCore>& sock,
+                  const std::map<std::string, std::string>& options,
+                  time_t timeout);
 
-  void poolSocket(const std::string& ipaddr, uint16_t port,
-		  const SharedHandle<SocketCore>& sock,
-		  time_t timeout = 15);
-  
   void poolSocket(const SharedHandle<Request>& request,
-		  bool proxyDefined,
-		  const SharedHandle<SocketCore>& socket,
-		  const std::map<std::string, std::string>& options,
-		  time_t timeout = 15);
+                  const std::string& username,
+                  const SharedHandle<Request>& proxyRequest,
+                  const SharedHandle<SocketCore>& socket,
+                  const std::map<std::string, std::string>& options,
+                  time_t timeout = 15);
     
-  void poolSocket(const SharedHandle<Request>& request,
-		  bool proxyDefined,
-		  const SharedHandle<SocketCore>& socket,
-		  time_t timeout = 15);
+  void poolSocket(const std::string& ipaddr, uint16_t port,
+                  const std::string& proxyhost, uint16_t proxyport,
+                  const SharedHandle<SocketCore>& sock,
+                  time_t timeout);
 
-  SharedHandle<SocketCore> popPooledSocket(const std::string& ipaddr,
-					   uint16_t port);
+  void poolSocket(const SharedHandle<Request>& request,
+                  const SharedHandle<Request>& proxyRequest,
+                  const SharedHandle<SocketCore>& socket,
+                  time_t timeout = 15);
+
+  SharedHandle<SocketCore> popPooledSocket
+  (const std::string& ipaddr,
+   uint16_t port,
+   const std::string& proxyhost, uint16_t proxyport);
 
   SharedHandle<SocketCore> popPooledSocket
   (std::map<std::string, std::string>& options,
    const std::string& ipaddr,
-   uint16_t port);
+   uint16_t port,
+   const std::string& username,
+   const std::string& proxyhost, uint16_t proxyport);
 
   SharedHandle<SocketCore>
-  popPooledSocket(const std::deque<std::string>& ipaddrs, uint16_t port);
+  popPooledSocket
+  (const std::vector<std::string>& ipaddrs, uint16_t port);
 
   SharedHandle<SocketCore>
   popPooledSocket
   (std::map<std::string, std::string>& options,
-   const std::deque<std::string>& ipaddrs,
-   uint16_t port);
+   const std::vector<std::string>& ipaddrs,
+   uint16_t port,
+   const std::string& username);
 
   const SharedHandle<CookieStorage>& getCookieStorage() const
   {
-    return _cookieStorage;
+    return cookieStorage_;
   }
 
 #ifdef ENABLE_BITTORRENT
   const SharedHandle<BtRegistry>& getBtRegistry() const
   {
-    return _btRegistry;
+    return btRegistry_;
   }
 #endif // ENABLE_BITTORRENT
 
@@ -251,6 +315,13 @@ public:
   const std::string& findCachedIPAddress
   (const std::string& hostname, uint16_t port) const;
 
+  template<typename OutputIterator>
+  void findAllCachedIPAddresses
+  (OutputIterator out, const std::string& hostname, uint16_t port) const
+  {
+    dnsCache_->findAll(out, hostname, port);
+  }
+
   void cacheIPAddress
   (const std::string& hostname, const std::string& ipaddr, uint16_t port);
 
@@ -263,10 +334,15 @@ public:
 
   const SharedHandle<AuthConfigFactory>& getAuthConfigFactory() const
   {
-    return _authConfigFactory;
+    return authConfigFactory_;
   }
 
   void setRefreshInterval(time_t interval);
+
+  const std::string getSessionId() const
+  {
+    return sessionId_;
+  }
 };
 
 typedef SharedHandle<DownloadEngine> DownloadEngineHandle;
