@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -43,9 +43,9 @@
 #include "DownloadEngine.h"
 #include "RequestGroupMan.h"
 #include "FileAllocationMan.h"
+#include "CheckIntegrityMan.h"
+#include "CheckIntegrityEntry.h"
 #ifdef ENABLE_MESSAGE_DIGEST
-# include "CheckIntegrityMan.h"
-# include "CheckIntegrityEntry.h"
 # include "CheckIntegrityDispatcherCommand.h"
 #endif // ENABLE_MESSAGE_DIGEST
 #include "prefs.h"
@@ -61,6 +61,15 @@
 #ifdef HAVE_EPOLL
 # include "EpollEventPoll.h"
 #endif // HAVE_EPOLL
+#ifdef HAVE_PORT_ASSOCIATE
+# include "PortEventPoll.h"
+#endif // HAVE_PORT_ASSOCIATE
+#ifdef HAVE_KQUEUE
+# include "KqueueEventPoll.h"
+#endif // HAVE_KQUEUE
+#ifdef HAVE_POLL
+# include "PollEventPoll.h"
+#endif // HAVE_POLL
 #include "SelectEventPoll.h"
 #include "DlAbortEx.h"
 #include "FileAllocationEntry.h"
@@ -71,61 +80,91 @@
 namespace aria2 {
 
 DownloadEngineFactory::DownloadEngineFactory():
-  _logger(LogFactory::getInstance()) {}
+  logger_(LogFactory::getInstance()) {}
 
 DownloadEngineHandle
 DownloadEngineFactory::newDownloadEngine
-(Option* op, const RequestGroups& requestGroups)
+(Option* op, const std::vector<SharedHandle<RequestGroup> >& requestGroups)
 {
   const size_t MAX_CONCURRENT_DOWNLOADS =
     op->getAsInt(PREF_MAX_CONCURRENT_DOWNLOADS);
   SharedHandle<EventPoll> eventPoll;
+  const std::string& pollMethod = op->get(PREF_EVENT_POLL);
 #ifdef HAVE_EPOLL
-  if(op->get(PREF_EVENT_POLL) == V_EPOLL) {
+  if(pollMethod == V_EPOLL) {
     SharedHandle<EpollEventPoll> ep(new EpollEventPoll());
     if(ep->good()) {
       eventPoll = ep;
     } else {
       throw DL_ABORT_EX("Initializing EpollEventPoll failed."
-			" Try --event-poll=select");
+                        " Try --event-poll=select");
     }
   } else
 #endif // HAVE_EPLL
-    if(op->get(PREF_EVENT_POLL) == V_SELECT) {
-      eventPoll.reset(new SelectEventPoll());
-    } else {
-      abort();
-    }
+#ifdef HAVE_KQUEUE
+    if(pollMethod == V_KQUEUE) {
+      SharedHandle<KqueueEventPoll> kp(new KqueueEventPoll());
+      if(kp->good()) {
+        eventPoll = kp;
+      } else {
+        throw DL_ABORT_EX("Initializing KqueueEventPoll failed."
+                          " Try --event-poll=select");
+      }
+    } else
+#endif // HAVE_KQUEUE
+#ifdef HAVE_PORT_ASSOCIATE
+      if(pollMethod == V_PORT) {
+        SharedHandle<PortEventPoll> pp(new PortEventPoll());
+        if(pp->good()) {
+          eventPoll = pp;
+        } else {
+          throw DL_ABORT_EX("Initializing PortEventPoll failed."
+                            " Try --event-poll=select");
+        }
+      } else
+#endif // HAVE_PORT_ASSOCIATE
+#ifdef HAVE_POLL
+        if(pollMethod == V_POLL) {
+          eventPoll.reset(new PollEventPoll());
+        } else
+#endif // HAVE_POLL
+          if(pollMethod == V_SELECT) {
+            eventPoll.reset(new SelectEventPoll());
+          } else {
+            abort();
+          }
   DownloadEngineHandle e(new DownloadEngine(eventPoll));
-  e->option = op;
+  e->setOption(op);
 
   RequestGroupManHandle
     requestGroupMan(new RequestGroupMan(requestGroups, MAX_CONCURRENT_DOWNLOADS,
-					op));
-  e->_requestGroupMan = requestGroupMan;
-  e->_fileAllocationMan.reset(new FileAllocationMan());
+                                        op));
+  e->setRequestGroupMan(requestGroupMan);
+  e->setFileAllocationMan
+    (SharedHandle<FileAllocationMan>(new FileAllocationMan()));
 #ifdef ENABLE_MESSAGE_DIGEST
-  e->_checkIntegrityMan.reset(new CheckIntegrityMan());
+  e->setCheckIntegrityMan
+    (SharedHandle<CheckIntegrityMan>(new CheckIntegrityMan()));
 #endif // ENABLE_MESSAGE_DIGEST
-  e->addRoutineCommand(new FillRequestGroupCommand(e->newCUID(), e.get(), 1));
+  e->addRoutineCommand(new FillRequestGroupCommand(e->newCUID(), e.get()));
   e->addRoutineCommand(new FileAllocationDispatcherCommand
-		       (e->newCUID(), e->_fileAllocationMan, e.get()));
+                       (e->newCUID(), e->getFileAllocationMan(), e.get()));
 #ifdef ENABLE_MESSAGE_DIGEST
   e->addRoutineCommand(new CheckIntegrityDispatcherCommand
-		       (e->newCUID(), e->_checkIntegrityMan, e.get()));
+                       (e->newCUID(), e->getCheckIntegrityMan(), e.get()));
 #endif // ENABLE_MESSAGE_DIGEST
 
   if(op->getAsInt(PREF_AUTO_SAVE_INTERVAL) > 0) {
     e->addRoutineCommand
       (new AutoSaveCommand(e->newCUID(), e.get(),
-			   op->getAsInt(PREF_AUTO_SAVE_INTERVAL)));
+                           op->getAsInt(PREF_AUTO_SAVE_INTERVAL)));
   }
   e->addRoutineCommand(new HaveEraseCommand(e->newCUID(), e.get(), 10));
   {
     time_t stopSec = op->getAsInt(PREF_STOP);
     if(stopSec > 0) {
       e->addRoutineCommand(new TimedHaltCommand(e->newCUID(), e.get(),
-						stopSec));
+                                                stopSec));
     }
   }
 #ifdef ENABLE_XML_RPC
