@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -49,7 +49,7 @@ namespace aria2 {
  */
 class File {
 private:
-  std::string name;
+  std::string name_;
   
   /**
    * Returns the return value of stat(...)
@@ -99,7 +99,7 @@ public:
 
   const std::string& getPath() const
   {
-    return name;
+    return name_;
   }
 
   static bool isDir(const std::string& filename);
