@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,24 +36,29 @@
 #define _D_FILE_ALLOCATION_COMMAND_H_
 
 #include "RealtimeCommand.h"
-#include "TimeA2.h"
+#include "SharedHandle.h"
+#include "TimerA2.h"
+
+namespace aria2 {
 
 class FileAllocationEntry;
-typedef SharedHandle<FileAllocationEntry> FileAllocationEntryHandle;
-class Exception;
 
 class FileAllocationCommand : public RealtimeCommand {
 private:
-  FileAllocationEntryHandle _fileAllocationEntry;
-  Time _timer;
+  SharedHandle<FileAllocationEntry> fileAllocationEntry_;
+  Timer timer_;
 public:
-  FileAllocationCommand(int cuid, RequestGroup* requestGroup, DownloadEngine* e, const FileAllocationEntryHandle& fileAllocationEntry);
+  FileAllocationCommand(cuid_t cuid, RequestGroup* requestGroup,
+                        DownloadEngine* e,
+                        const SharedHandle<FileAllocationEntry>& fileAllocationEntry);
 
   virtual ~FileAllocationCommand();
 
   virtual bool executeInternal();
 
-  virtual bool handleException(Exception* e);
+  virtual bool handleException(Exception& e);
 };
 
+} // namespace aria2
+
 #endif // _D_FILE_ALLOCATION_COMMAND_H_
