@@ -38,11 +38,14 @@
 #include "message.h"
 #include "Logger.h"
 #include "DownloadContext.h"
+#include "util.h"
+#include "ServerStatMan.h"
+#include "CheckIntegrityEntry.h"
 
 namespace aria2 {
 
 FileAllocationDispatcherCommand::FileAllocationDispatcherCommand
-(int32_t cuid,
+(cuid_t cuid,
  const SharedHandle<FileAllocationMan>& fileAllocMan,
  DownloadEngine* e):SequentialDispatcherCommand<FileAllocationEntry>
                     (cuid, fileAllocMan, e) {}
@@ -50,10 +53,14 @@ FileAllocationDispatcherCommand::FileAllocationDispatcherCommand
 Command* FileAllocationDispatcherCommand::createCommand
 (const SharedHandle<FileAllocationEntry>& entry)
 {
-  int32_t newCUID = _e->newCUID();
-  logger->info(MSG_FILE_ALLOCATION_DISPATCH, newCUID);
+  cuid_t newCUID = getDownloadEngine()->newCUID();
+  if(getLogger()->info()) {
+    getLogger()->info(MSG_FILE_ALLOCATION_DISPATCH,
+                      util::itos(newCUID).c_str());
+  }
   FileAllocationCommand* command =
-    new FileAllocationCommand(newCUID, entry->getRequestGroup(), _e, entry);
+    new FileAllocationCommand(newCUID, entry->getRequestGroup(),
+                              getDownloadEngine(), entry);
   return command;
 }
 
