@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,30 +36,25 @@
 #define _D_FILL_REQUEST_GROUP_COMMAND_H_
 
 #include "Command.h"
-#include "TimeA2.h"
+#include "SharedHandle.h"
+#include "a2time.h"
+
+namespace aria2 {
 
 class RequestGroup;
-typedef SharedHandle<RequestGroup> RequestGroupHandle;
-typedef deque<RequestGroupHandle> RequestGroups;
 class DownloadEngine;
 
 class FillRequestGroupCommand : public Command {
 private:
-  RequestGroups _reservedRequestGroups;
-  DownloadEngine* _e;
-  int32_t _interval;
-  Time _checkPoint;
+  DownloadEngine* e_;
 public:
-  FillRequestGroupCommand(int32_t cuid, DownloadEngine* e, int32_t interval);
+  FillRequestGroupCommand(cuid_t cuid, DownloadEngine* e);
 
   virtual ~FillRequestGroupCommand();
 
   virtual bool execute();
-
-  void setInterval(int32_t interval)
-  {
-    _interval = interval;
-  }
 };
 
+} // namespace aria2
+
 #endif // _D_FILL_REQUEST_GROUP_COMMAND_H_
