@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,23 +36,23 @@
 #define _D_FIXED_WIDTH_NUMBER_DECORATOR_H_
 
 #include "NumberDecorator.h"
-#include "Util.h"
+#include "util.h"
 
 namespace aria2 {
 
 class FixedWidthNumberDecorator : public NumberDecorator
 {
 private:
-  size_t _width;
+  size_t width_;
 public:
-  FixedWidthNumberDecorator(size_t width):_width(width) {}
+  FixedWidthNumberDecorator(size_t width):width_(width) {}
 
   virtual ~FixedWidthNumberDecorator() {}
 
   virtual std::string decorate(unsigned int number)
   {
-    std::string s = Util::uitos(number);
-    while(s.size() < _width) {
+    std::string s = util::uitos(number);
+    while(s.size() < width_) {
       s.insert(0, "0");
     }
     return s;
