@@ -56,20 +56,20 @@ class AuthConfig;
 
 class FtpConnection {
 private:
-  cuid_t cuid;
-  SharedHandle<SocketCore> socket;
-  SharedHandle<Request> req;
+  cuid_t cuid_;
+  SharedHandle<SocketCore> socket_;
+  SharedHandle<Request> req_;
 
-  SharedHandle<AuthConfig> _authConfig;
+  SharedHandle<AuthConfig> authConfig_;
 
-  const Option* option;
-  Logger* logger;
+  const Option* option_;
+  Logger* logger_;
 
-  std::string strbuf;
+  std::string strbuf_;
 
-  SocketBuffer _socketBuffer;
+  SocketBuffer socketBuffer_;
 
-  std::string _baseWorkingDir;
+  std::string baseWorkingDir_;
 
   unsigned int getStatus(const std::string& response) const;
   std::string::size_type findEndOfResponse(unsigned int status,
@@ -92,7 +92,7 @@ public:
   bool sendPass();
   bool sendType();
   bool sendPwd();
-  bool sendCwd();
+  bool sendCwd(const std::string& dir);
   bool sendMdtm();
   bool sendSize();
   bool sendPasv();
@@ -117,8 +117,10 @@ public:
 
   const std::string& getBaseWorkingDir() const
   {
-    return _baseWorkingDir;
+    return baseWorkingDir_;
   }
+
+  const std::string& getUser() const;
 };
 
 } // namespace aria2
