@@ -43,21 +43,19 @@ class FtpConnection;
 
 class FtpFinishDownloadCommand : public AbstractCommand {
 private:
-  SharedHandle<FtpConnection> _ftpConnection;
+  SharedHandle<FtpConnection> ftpConnection_;
 protected:
   virtual bool execute();
 
   virtual bool executeInternal();
 public:
-  FtpFinishDownloadCommand(int cuid,
+  FtpFinishDownloadCommand(cuid_t cuid,
                            const SharedHandle<Request>& req,
                            const SharedHandle<FileEntry>& fileEntry,
                            RequestGroup* requestGroup,
                            const SharedHandle<FtpConnection>& ftpConnection,
                            DownloadEngine* e,
                            const SharedHandle<SocketCore>& socket);
-
-  virtual ~FtpFinishDownloadCommand();
 };
 
 } // namespace aria2
