@@ -40,7 +40,7 @@
 #include "Logger.h"
 #include "message.h"
 #include "StringFormat.h"
-#include "bencode.h"
+#include "bencode2.h"
 #include "DownloadContext.h"
 #include "bittorrent_helper.h"
 #include "RequestGroup.h"
@@ -51,48 +51,48 @@ namespace aria2 {
 const std::string HandshakeExtensionMessage::EXTENSION_NAME = "handshake";
 
 HandshakeExtensionMessage::HandshakeExtensionMessage():
-  _tcpPort(0),
-  _metadataSize(0),
-  _logger(LogFactory::getInstance()) {}
+  tcpPort_(0),
+  metadataSize_(0),
+  logger_(LogFactory::getInstance()) {}
 
 HandshakeExtensionMessage::~HandshakeExtensionMessage() {}
 
 std::string HandshakeExtensionMessage::getPayload()
 {
-  BDE dict = BDE::dict();
-  if(!_clientVersion.empty()) {
-    dict["v"] = _clientVersion;
+  Dict dict;
+  if(!clientVersion_.empty()) {
+    dict.put("v", clientVersion_);
   }
-  if(_tcpPort > 0) {
-    dict["p"] = _tcpPort;
+  if(tcpPort_ > 0) {
+    dict.put("p", Integer::g(tcpPort_));
   }
-  BDE extDict = BDE::dict();
-  for(std::map<std::string, uint8_t>::const_iterator itr = _extensions.begin(),
-        eoi = _extensions.end(); itr != eoi; ++itr) {
+  SharedHandle<Dict> extDict = Dict::g();
+  for(std::map<std::string, uint8_t>::const_iterator itr = extensions_.begin(),
+        eoi = extensions_.end(); itr != eoi; ++itr) {
     const std::map<std::string, uint8_t>::value_type& vt = *itr;
-    extDict[vt.first] = vt.second;
+    extDict->put(vt.first, Integer::g(vt.second));
   }
-  dict["m"] = extDict;
-  if(_metadataSize) {
-    dict["metadata_size"] = _metadataSize;
+  dict.put("m", extDict);
+  if(metadataSize_) {
+    dict.put("metadata_size", Integer::g(metadataSize_));
   }
-  return bencode::encode(dict);
+  return bencode2::encode(&dict);
 }
 
 std::string HandshakeExtensionMessage::toString() const
 {
   std::string s = getExtensionName();
-  if(!_clientVersion.empty()) {
-    strappend(s, " client=", util::percentEncode(_clientVersion));
+  if(!clientVersion_.empty()) {
+    strappend(s, " client=", util::percentEncode(clientVersion_));
   }
-  if(_tcpPort > 0) {
-    strappend(s, ", tcpPort=", util::uitos(_tcpPort));
+  if(tcpPort_ > 0) {
+    strappend(s, ", tcpPort=", util::uitos(tcpPort_));
   }
-  if(_metadataSize) {
-    strappend(s, ", metadataSize=", util::uitos(_metadataSize));
+  if(metadataSize_) {
+    strappend(s, ", metadataSize=", util::uitos(metadataSize_));
   }
-  for(std::map<std::string, uint8_t>::const_iterator itr = _extensions.begin(),
-        eoi = _extensions.end(); itr != eoi; ++itr) {
+  for(std::map<std::string, uint8_t>::const_iterator itr = extensions_.begin(),
+        eoi = extensions_.end(); itr != eoi; ++itr) {
     const std::map<std::string, uint8_t>::value_type& vt = *itr;
     strappend(s, ", ", vt.first, "=", util::uitos(vt.second));
   }
@@ -101,39 +101,46 @@ std::string HandshakeExtensionMessage::toString() const
 
 void HandshakeExtensionMessage::doReceivedAction()
 {
-  if(_tcpPort > 0) {
-    _peer->port = _tcpPort;
-    _peer->setIncomingPeer(false);
+  if(tcpPort_ > 0) {
+    peer_->setPort(tcpPort_);
+    peer_->setIncomingPeer(false);
   }
-  for(std::map<std::string, uint8_t>::const_iterator itr = _extensions.begin(),
-        eoi = _extensions.end(); itr != eoi; ++itr) {
+  for(std::map<std::string, uint8_t>::const_iterator itr = extensions_.begin(),
+        eoi = extensions_.end(); itr != eoi; ++itr) {
     const std::map<std::string, uint8_t>::value_type& vt = *itr;
-    _peer->setExtension(vt.first, vt.second);
+    peer_->setExtension(vt.first, vt.second);
   }
-  BDE& attrs = _dctx->getAttribute(bittorrent::BITTORRENT);
-  if(!attrs.containsKey(bittorrent::METADATA) &&
-     !_peer->getExtensionMessageID("ut_metadata")) {
+  SharedHandle<TorrentAttribute> attrs =
+    bittorrent::getTorrentAttrs(dctx_);
+  if(attrs->metadata.empty() && !peer_->getExtensionMessageID("ut_metadata")) {
     // TODO In metadataGetMode, if peer don't support metadata
     // transfer, should we drop connection? There is a possibility
     // that peer can still tell us peers using PEX.
     throw DL_ABORT_EX("Peer doesn't support ut_metadata extension. Goodbye.");
   }
-  if(_metadataSize > 0) {
-    if(attrs.containsKey(bittorrent::METADATA_SIZE)) {
-      if(_metadataSize != (size_t)attrs[bittorrent::METADATA_SIZE].i()) {
+  if(metadataSize_ > 0) {
+    if(attrs->metadataSize) {
+      if(metadataSize_ != attrs->metadataSize) {
         throw DL_ABORT_EX("Wrong metadata_size. Which one is correct!?");
       }
+      if(!peer_->isSeeder()) {
+        peer_->reconfigureSessionResource(dctx_->getPieceLength(),
+                                          dctx_->getTotalLength());
+        peer_->setAllBitfield();
+      }
     } else {
-      attrs[bittorrent::METADATA_SIZE] = _metadataSize;
-      _dctx->getFirstFileEntry()->setLength(_metadataSize);
-      _dctx->markTotalLengthIsKnown();
-      _dctx->getOwnerRequestGroup()->initPieceStorage();
+      attrs->metadataSize = metadataSize_;
+      dctx_->getFirstFileEntry()->setLength(metadataSize_);
+      dctx_->markTotalLengthIsKnown();
+      dctx_->getOwnerRequestGroup()->initPieceStorage();
       
       SharedHandle<PieceStorage> pieceStorage =
-        _dctx->getOwnerRequestGroup()->getPieceStorage();
-      pieceStorage->setEndGamePieceNum(0);
+        dctx_->getOwnerRequestGroup()->getPieceStorage();
+      peer_->reconfigureSessionResource(dctx_->getPieceLength(),
+                                        dctx_->getTotalLength());
+      peer_->setAllBitfield();
     }
-  } else if(!attrs.containsKey(bittorrent::METADATA)) {
+  } else if(attrs->metadata.empty()) {
     throw DL_ABORT_EX("Peer didn't provide metadata_size."
                       " It seems that it doesn't have whole metadata.");
   }
@@ -141,13 +148,13 @@ void HandshakeExtensionMessage::doReceivedAction()
 
 void HandshakeExtensionMessage::setPeer(const SharedHandle<Peer>& peer)
 {
-  _peer = peer;
+  peer_ = peer;
 }
 
 uint8_t HandshakeExtensionMessage::getExtensionMessageID(const std::string& name) const
 {
-  std::map<std::string, uint8_t>::const_iterator i = _extensions.find(name);
-  if(i == _extensions.end()) {
+  std::map<std::string, uint8_t>::const_iterator i = extensions_.find(name);
+  if(i == extensions_.end()) {
     return 0;
   } else {
     return (*i).second;
@@ -168,31 +175,34 @@ HandshakeExtensionMessage::create(const unsigned char* data, size_t length)
       ("Creating HandshakeExtensionMessage from %s",
        util::percentEncode(data, length).c_str());
   }
-  const BDE dict = bencode::decode(data+1, length-1);
-  if(!dict.isDict()) {
-    throw DL_ABORT_EX("Unexpected payload format for extended message handshake");
+  SharedHandle<ValueBase> decoded = bencode2::decode(data+1, length-1);
+  const Dict* dict = asDict(decoded);
+  if(!dict) {
+    throw DL_ABORT_EX
+      ("Unexpected payload format for extended message handshake");
   }
-  const BDE& port = dict["p"];
-  if(port.isInteger() && 0 < port.i() && port.i() < 65536) {
-    msg->_tcpPort = port.i();
+  const Integer* port = asInteger(dict->get("p"));
+  if(port && 0 < port->i() && port->i() < 65536) {
+    msg->tcpPort_ = port->i();
   }
-  const BDE& version = dict["v"];
-  if(version.isString()) {
-    msg->_clientVersion = version.s();
+  const String* version = asString(dict->get("v"));
+  if(version) {
+    msg->clientVersion_ = version->s();
   }
-  const BDE& extDict = dict["m"];
-  if(extDict.isDict()) {
-    for(BDE::Dict::const_iterator i = extDict.dictBegin(),
-          eoi = extDict.dictEnd(); i != eoi; ++i) {
-      if((*i).second.isInteger()) {
-        msg->_extensions[(*i).first] = (*i).second.i();
+  const Dict* extDict = asDict(dict->get("m"));
+  if(extDict) {
+    for(Dict::ValueType::const_iterator i = extDict->begin(),
+          eoi = extDict->end(); i != eoi; ++i) {
+      const Integer* extId = asInteger((*i).second);
+      if(extId) {
+        msg->extensions_[(*i).first] = extId->i();
       }
     }
   }
-  const BDE& metadataSize = dict["metadata_size"];
+  const Integer* metadataSize = asInteger(dict->get("metadata_size"));
   // Only accept metadata smaller than 1MiB
-  if(metadataSize.isInteger() && metadataSize.i() <= 1024*1024) {
-    msg->_metadataSize = metadataSize.i();
+  if(metadataSize && metadataSize->i() <= 1024*1024) {
+    msg->metadataSize_ = metadataSize->i();
   }
   return msg;
 }
