@@ -42,6 +42,7 @@
 
 #include "SharedHandle.h"
 #include "SocketBuffer.h"
+#include "Command.h"
 
 namespace aria2 {
 
@@ -55,8 +56,8 @@ class SocketCore;
 
 class HttpRequestEntry {
 private:
-  SharedHandle<HttpRequest> _httpRequest;
-  SharedHandle<HttpHeaderProcessor> _proc;
+  SharedHandle<HttpRequest> httpRequest_;
+  SharedHandle<HttpHeaderProcessor> proc_;
 public:
   HttpRequestEntry(const SharedHandle<HttpRequest>& httpRequest);
 
@@ -64,12 +65,12 @@ public:
 
   const SharedHandle<HttpRequest>& getHttpRequest() const
   {
-    return _httpRequest;
+    return httpRequest_;
   }
 
   const SharedHandle<HttpHeaderProcessor>& getHttpHeaderProcessor() const
   {
-    return _proc;
+    return proc_;
   }
 };
 
@@ -78,19 +79,17 @@ typedef std::deque<HttpRequestEntryHandle> HttpRequestEntries;
 
 class HttpConnection {
 private:
-  int32_t cuid;
-  SharedHandle<SocketCore> socket;
-  SocketBuffer _socketBuffer;
-  const Option* option;
-  Logger* logger;
+  cuid_t cuid_;
+  SharedHandle<SocketCore> socket_;
+  SocketBuffer socketBuffer_;
+  const Option* option_;
+  Logger* logger_;
 
-  HttpRequestEntries outstandingHttpRequests;
+  HttpRequestEntries outstandingHttpRequests_;
 
   std::string eraseConfidentialInfo(const std::string& request);
 public:
-  HttpConnection(int32_t cuid,
-                 const SharedHandle<SocketCore>& socket,
-                 const Option* op);
+  HttpConnection(cuid_t cuid, const SharedHandle<SocketCore>& socket);
 
   /**
    * Sends Http request.
