@@ -44,12 +44,13 @@ class HttpConnection;
 
 class HttpDownloadCommand : public DownloadCommand {
 private:
-  SharedHandle<HttpResponse> _httpResponse;
-  SharedHandle<HttpConnection> _httpConnection;
+  SharedHandle<HttpResponse> httpResponse_;
+  SharedHandle<HttpConnection> httpConnection_;
 protected:
   virtual bool prepareForNextSegment();
+  virtual off_t getRequestEndOffset() const;
 public:
-  HttpDownloadCommand(int cuid,
+  HttpDownloadCommand(cuid_t cuid,
                       const SharedHandle<Request>& req,
                       const SharedHandle<FileEntry>& fileEntry,
                       RequestGroup* requestGroup,
