@@ -78,8 +78,20 @@ const std::string HttpHeader::HTTP_1_1("HTTP/1.1");
 
 const std::string HttpHeader::S200("200");
 
+const std::string HttpHeader::S206("206");
+
 const std::string HttpHeader::S300("300");
 
+const std::string HttpHeader::S301("301");
+
+const std::string HttpHeader::S302("302");
+
+const std::string HttpHeader::S303("303");
+
+const std::string HttpHeader::S304("304");
+
+const std::string HttpHeader::S307("307");
+
 const std::string HttpHeader::S400("400");
 
 const std::string HttpHeader::S401("401");
@@ -87,34 +99,34 @@ const std::string HttpHeader::S401("401");
 const std::string HttpHeader::S404("404");
 
 void HttpHeader::put(const std::string& name, const std::string& value) {
-  std::multimap<std::string, std::string>::value_type vt(util::toLower(name), value);
-  table.insert(vt);
+  std::multimap<std::string, std::string>::value_type vt
+    (util::toLower(name), value);
+  table_.insert(vt);
 }
 
 bool HttpHeader::defined(const std::string& name) const {
-  return table.count(util::toLower(name)) >= 1;
+  return table_.count(util::toLower(name)) >= 1;
 }
 
 const std::string& HttpHeader::getFirst(const std::string& name) const {
-  std::multimap<std::string, std::string>::const_iterator itr = table.find(util::toLower(name));
-  if(itr == table.end()) {
+  std::multimap<std::string, std::string>::const_iterator itr =
+    table_.find(util::toLower(name));
+  if(itr == table_.end()) {
     return A2STR::NIL;
   } else {
     return (*itr).second;
   }
 }
 
-std::deque<std::string> HttpHeader::get(const std::string& name) const {
-  std::deque<std::string> v;
-
+std::vector<std::string> HttpHeader::get(const std::string& name) const
+{
+  std::vector<std::string> v;
   std::string n(util::toLower(name));
-
-  std::multimap<std::string, std::string>::const_iterator first =
-    table.lower_bound(n);
-  std::multimap<std::string, std::string>::const_iterator last =
-    table.upper_bound(n);
-
-  while(first != last) {
+  std::pair<std::multimap<std::string, std::string>::const_iterator,
+    std::multimap<std::string, std::string>::const_iterator> itrpair =
+    table_.equal_range(n);
+  std::multimap<std::string, std::string>::const_iterator first = itrpair.first;
+  while(first != itrpair.second) {
     v.push_back((*first).second);
     ++first;
   }
@@ -146,7 +158,8 @@ RangeHandle HttpHeader::getRange() const
       if(contentLength == 0) {
         return SharedHandle<Range>(new Range());
       } else {
-        return SharedHandle<Range>(new Range(0, contentLength-1, contentLength));
+        return SharedHandle<Range>
+          (new Range(0, contentLength-1, contentLength));
       }
     }
   }
@@ -179,22 +192,22 @@ RangeHandle HttpHeader::getRange() const
 
 void HttpHeader::setResponseStatus(const std::string& responseStatus)
 {
-  _responseStatus = responseStatus;
+  responseStatus_ = responseStatus;
 }
 
 void HttpHeader::setVersion(const std::string& version)
 {
-  _version = version;
+  version_ = version;
 }
 
 void HttpHeader::setMethod(const std::string& method)
 {
-  _method = method;
+  method_ = method;
 }
 
 void HttpHeader::setRequestPath(const std::string& requestPath)
 {
-  _requestPath = requestPath;
+  requestPath_ = requestPath;
 }
 
 void HttpHeader::fill(std::istream& in)
@@ -213,7 +226,7 @@ void HttpHeader::fill(std::istream& in)
 
 void HttpHeader::clearField()
 {
-  table.clear();
+  table_.clear();
 }
 
 } // namespace aria2
