@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -46,8 +46,8 @@ class HttpHeader;
 
 class HttpHeaderProcessor {
 private:
-  std::string _buf;
-  size_t _limit;
+  std::string buf_;
+  size_t limit_;
 
   void checkHeaderLimit(size_t incomingLength);
 
@@ -84,7 +84,7 @@ public:
 
   void setHeaderLimit(size_t limit)
   {
-    _limit = limit;
+    limit_ = limit;
   }
 };
 
