@@ -44,73 +44,84 @@
 #include "FileEntry.h"
 #include "prefs.h"
 #include "Option.h"
+#include "util.h"
+#include "ServerStatMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
 
 namespace aria2 {
 
-HttpListenCommand::HttpListenCommand(int32_t cuid, DownloadEngine* e):
-  Command(cuid),_e(e) {}
+HttpListenCommand::HttpListenCommand(cuid_t cuid, DownloadEngine* e):
+  Command(cuid),e_(e) {}
 
 HttpListenCommand::~HttpListenCommand()
 {
-  if(!_serverSocket.isNull()) {
-    _e->deleteSocketForReadCheck(_serverSocket, this);
+  if(!serverSocket_.isNull()) {
+    e_->deleteSocketForReadCheck(serverSocket_, this);
   }
 }
 
 bool HttpListenCommand::execute()
 {
-  if(_e->_requestGroupMan->downloadFinished() || _e->isHaltRequested()) {
+  if(e_->getRequestGroupMan()->downloadFinished() || e_->isHaltRequested()) {
     return true;
   }
   try {
-    if(_serverSocket->isReadable(0)) {
-      SharedHandle<SocketCore> socket(_serverSocket->acceptConnection());
+    if(serverSocket_->isReadable(0)) {
+      SharedHandle<SocketCore> socket(serverSocket_->acceptConnection());
       socket->setNonBlockingMode();
 
       std::pair<std::string, uint16_t> peerInfo;
       socket->getPeerInfo(peerInfo);
 
-      logger->info("XML-RPC: Accepted the connection from %s:%u.",
-                   peerInfo.first.c_str(), peerInfo.second);
+      getLogger()->info("XML-RPC: Accepted the connection from %s:%u.",
+                        peerInfo.first.c_str(), peerInfo.second);
 
       HttpServerCommand* c =
-        new HttpServerCommand(_e->newCUID(), _e, socket);
-      _e->setNoWait(true);
-      _e->commands.push_back(c);
+        new HttpServerCommand(e_->newCUID(), e_, socket);
+      e_->setNoWait(true);
+      e_->addCommand(c);
     }
   } catch(RecoverableException& e) {
-    if(logger->debug()) {
-      logger->debug(MSG_ACCEPT_FAILURE, _e, cuid);
+    if(getLogger()->debug()) {
+      getLogger()->debug(MSG_ACCEPT_FAILURE, e, util::itos(getCuid()).c_str());
     }
   }
-  _e->commands.push_back(this);
+  e_->addCommand(this);
   return false;
 }
 
 bool HttpListenCommand::bindPort(uint16_t port)
 {
-  if(!_serverSocket.isNull()) {
-    _e->deleteSocketForReadCheck(_serverSocket, this);
+  if(!serverSocket_.isNull()) {
+    e_->deleteSocketForReadCheck(serverSocket_, this);
+  }
+  serverSocket_.reset(new SocketCore());
+  if(getLogger()->info()) {
+    getLogger()->info("CUID#%s - Setting up HttpListenCommand",
+                      util::itos(getCuid()).c_str());
   }
-  _serverSocket.reset(new SocketCore());
-  logger->info("CUID#%d - Setting up HttpListenCommand", cuid);
   try {
     int flags = 0;
-    if(_e->option->getAsBool(PREF_XML_RPC_LISTEN_ALL)) {
+    if(e_->getOption()->getAsBool(PREF_XML_RPC_LISTEN_ALL)) {
       flags = AI_PASSIVE;
     }
-    _serverSocket->bind(port, flags);
-    _serverSocket->beginListen();
-    _serverSocket->setNonBlockingMode();
-    logger->info(MSG_LISTENING_PORT, cuid, port);
-    _e->addSocketForReadCheck(_serverSocket, this);
+    serverSocket_->bind(port, flags);
+    serverSocket_->beginListen();
+    serverSocket_->setNonBlockingMode();
+    if(getLogger()->info()) {
+      getLogger()->info(MSG_LISTENING_PORT,
+                        util::itos(getCuid()).c_str(), port);
+    }
+    e_->addSocketForReadCheck(serverSocket_, this);
     return true;
   } catch(RecoverableException& e) {
-    logger->error(MSG_BIND_FAILURE, e, cuid, port);
-    if(!_serverSocket.isNull()) {
-      _e->deleteSocketForReadCheck(_serverSocket, this);
+    getLogger()->error(MSG_BIND_FAILURE, e,
+                       util::itos(getCuid()).c_str(), port);
+    if(!serverSocket_.isNull()) {
+      e_->deleteSocketForReadCheck(serverSocket_, this);
     }
-    _serverSocket->closeConnection();
+    serverSocket_->closeConnection();
   }
   return false;
 }
