@@ -45,10 +45,10 @@ class SocketCore;
 
 class HttpListenCommand : public Command {
 private:
-  DownloadEngine* _e;
-  SharedHandle<SocketCore> _serverSocket;
+  DownloadEngine* e_;
+  SharedHandle<SocketCore> serverSocket_;
 public:
-  HttpListenCommand(int32_t cuid, DownloadEngine* e);
+  HttpListenCommand(cuid_t cuid, DownloadEngine* e);
 
   virtual ~HttpListenCommand();
   
