@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -44,23 +44,23 @@ class SocketCore;
 
 class HttpRequestCommand:public AbstractCommand {
 private:
-  SharedHandle<Request> _proxyRequest;
+  SharedHandle<Request> proxyRequest_;
 
-  SharedHandle<HttpConnection> _httpConnection;
+  SharedHandle<HttpConnection> httpConnection_;
 
-  std::string _connectedHostname;
-  std::string _connectedAddr;
-  uint16_t _connectedPort;
+  std::string connectedHostname_;
+  std::string connectedAddr_;
+  uint16_t connectedPort_;
 protected:
   virtual bool executeInternal();
 public:
-  HttpRequestCommand(int cuid,
-		     const SharedHandle<Request>& req,
-		     const SharedHandle<FileEntry>& fileEntry,
-		     RequestGroup* requestGroup,
-		     const SharedHandle<HttpConnection>& httpConnection,
-		     DownloadEngine* e,
-		     const SharedHandle<SocketCore>& s);
+  HttpRequestCommand(cuid_t cuid,
+                     const SharedHandle<Request>& req,
+                     const SharedHandle<FileEntry>& fileEntry,
+                     RequestGroup* requestGroup,
+                     const SharedHandle<HttpConnection>& httpConnection,
+                     DownloadEngine* e,
+                     const SharedHandle<SocketCore>& s);
   virtual ~HttpRequestCommand();
 
   void setProxyRequest(const SharedHandle<Request>& proxyRequest);
@@ -68,9 +68,9 @@ public:
   void setConnectedAddr
   (const std::string& hostname, const std::string& addr, uint16_t port)
   {
-    _connectedHostname = hostname;
-    _connectedAddr = addr;
-    _connectedPort = port;
+    connectedHostname_ = hostname;
+    connectedAddr_ = addr;
+    connectedPort_ = port;
   }
 };
 
