@@ -41,6 +41,7 @@
 
 #include "SharedHandle.h"
 #include "TimeA2.h"
+#include "Command.h"
 
 namespace aria2 {
 
@@ -51,10 +52,10 @@ class Decoder;
 
 class HttpResponse {
 private:
-  int32_t cuid;
-  SharedHandle<HttpRequest> httpRequest;
-  SharedHandle<HttpHeader> httpHeader;
-  Logger* logger;
+  cuid_t cuid_;
+  SharedHandle<HttpRequest> httpRequest_;
+  SharedHandle<HttpHeader> httpHeader_;
+  Logger* logger_;
 public:
   HttpResponse();
   
@@ -104,7 +105,7 @@ public:
 
   const SharedHandle<HttpHeader>& getHttpHeader() const
   {
-    return httpHeader;
+    return httpHeader_;
   }
 
   const std::string& getResponseStatus() const;
@@ -113,12 +114,12 @@ public:
 
   const SharedHandle<HttpRequest>& getHttpRequest() const
   {
-    return httpRequest;
+    return httpRequest_;
   }
 
-  void setCuid(int32_t cuid)
+  void setCuid(cuid_t cuid)
   {
-    this->cuid = cuid;
+    cuid_ = cuid;
   }
 
   bool hasRetryAfter() const;
@@ -130,8 +131,6 @@ public:
   bool supportsPersistentConnection() const;
 };
 
-typedef SharedHandle<HttpResponse> HttpResponseHandle;
-
 } // namespace aria2
 
 #endif // _D_HTTP_RESPONSE_H_
