@@ -44,7 +44,9 @@ public:
 
   virtual ~InOrderURISelector();
 
-  virtual std::string select(FileEntry* fileEntry);
+  virtual std::string select
+  (FileEntry* fileEntry,
+   const std::vector<std::pair<size_t, std::string> >& usedHosts);
 };
 
 } // namespace aria2
