@@ -40,7 +40,6 @@
 #include "message.h"
 #include "prefs.h"
 #include "NameResolver.h"
-#include "DNSCache.h"
 #include "SocketCore.h"
 #include "FileEntry.h"
 #include "RequestGroup.h"
@@ -48,12 +47,18 @@
 #include "Segment.h"
 #include "a2functional.h"
 #include "InitiateConnectionCommandFactory.h"
+#include "util.h"
+#include "RequestGroupMan.h"
+#include "ServerStatMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
+#include "RecoverableException.h"
 
 namespace aria2 {
 
 InitiateConnectionCommand::InitiateConnectionCommand
-(int cuid,
- const RequestHandle& req,
+(cuid_t cuid,
+ const SharedHandle<Request>& req,
  const SharedHandle<FileEntry>& fileEntry,
  RequestGroup* requestGroup,
  DownloadEngine* e):
@@ -73,72 +78,44 @@ bool InitiateConnectionCommand::executeInternal() {
   uint16_t port;
   SharedHandle<Request> proxyRequest = createProxyRequest();
   if(proxyRequest.isNull()) {
-    hostname = req->getHost();
-    port = req->getPort();
+    hostname = getRequest()->getHost();
+    port = getRequest()->getPort();
   } else {
     hostname = proxyRequest->getHost();
     port = proxyRequest->getPort();
   }
-  std::deque<std::string> addrs;
-  e->findAllCachedIPAddresses(std::back_inserter(addrs), hostname, port);
-  std::string ipaddr;
-  if(addrs.empty()) {
-#ifdef ENABLE_ASYNC_DNS
-    if(getOption()->getAsBool(PREF_ASYNC_DNS)) {
-      if(!isAsyncNameResolverInitialized()) {
-        initAsyncNameResolver(hostname);
-      }
-      if(asyncResolveHostname()) {
-        addrs = getResolvedAddresses();
-      } else {
-        e->commands.push_back(this);
-        return false;
-      }
-    } else
-#endif // ENABLE_ASYNC_DNS
-      {
-        NameResolver res;
-        res.setSocktype(SOCK_STREAM);
-        if(e->option->getAsBool(PREF_DISABLE_IPV6)) {
-          res.setFamily(AF_INET);
-        }
-        res.resolve(addrs, hostname);
-      }
-    logger->info(MSG_NAME_RESOLUTION_COMPLETE, cuid,
-                 hostname.c_str(),
-                 strjoin(addrs.begin(), addrs.end(), ", ").c_str());
-    for(std::deque<std::string>::const_iterator i = addrs.begin();
-        i != addrs.end(); ++i) {
-      e->cacheIPAddress(hostname, *i, port);
-    }
-    ipaddr = e->findCachedIPAddress(hostname, port);
-  } else {
-    ipaddr = addrs.front();
-    logger->info(MSG_DNS_CACHE_HIT, cuid, hostname.c_str(),
-                 strjoin(addrs.begin(), addrs.end(), ", ").c_str());
+  std::vector<std::string> addrs;
+  std::string ipaddr = resolveHostname(addrs, hostname, port);
+  if(ipaddr.empty()) {
+    getDownloadEngine()->addCommand(this);
+    return false;
   }
   try {
     Command* command = createNextCommand(hostname, ipaddr, port,
                                          addrs, proxyRequest);
-    e->commands.push_back(command);
+    getDownloadEngine()->addCommand(command);
     return true;
   } catch(RecoverableException& ex) {
     // Catch exception and retry another address.
     // See also AbstractCommand::checkIfConnectionEstablished
 
     // TODO ipaddr might not be used if pooled sockt was found.
-    e->markBadIPAddress(hostname, ipaddr, port);
-    if(!e->findCachedIPAddress(hostname, port).empty()) {
-      logger->info(EX_EXCEPTION_CAUGHT, ex);
-      logger->info(MSG_CONNECT_FAILED_AND_RETRY, cuid, ipaddr.c_str(), port);
+    getDownloadEngine()->markBadIPAddress(hostname, ipaddr, port);
+    if(!getDownloadEngine()->findCachedIPAddress(hostname, port).empty()) {
+      if(getLogger()->info()) {
+        getLogger()->info(EX_EXCEPTION_CAUGHT, ex);
+        getLogger()->info(MSG_CONNECT_FAILED_AND_RETRY,
+                          util::itos(getCuid()).c_str(), ipaddr.c_str(), port);
+      }
       Command* command =
         InitiateConnectionCommandFactory::createInitiateConnectionCommand
-        (cuid, req, _fileEntry, _requestGroup, e);
-      e->setNoWait(true);
-      e->commands.push_back(command);
+        (getCuid(), getRequest(), getFileEntry(), getRequestGroup(),
+         getDownloadEngine());
+      getDownloadEngine()->setNoWait(true);
+      getDownloadEngine()->addCommand(command);
       return true;
     }
-    e->removeCachedIPAddress(hostname, port);
+    getDownloadEngine()->removeCachedIPAddress(hostname, port);
     throw;
   }
 }
