@@ -44,12 +44,16 @@
 #include "prefs.h"
 #include "SocketCore.h"
 #include "DownloadContext.h"
+#include "RequestGroupMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
+#include "ServerStatMan.h"
 
 namespace aria2 {
 
 Command*
 InitiateConnectionCommandFactory::createInitiateConnectionCommand
-(int32_t cuid,
+(cuid_t cuid,
  const SharedHandle<Request>& req,
  const SharedHandle<FileEntry>& fileEntry,
  RequestGroup* requestGroup,
