@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,32 +37,31 @@
 
 #include "IteratableValidator.h"
 
-class SingleFileDownloadContext;
-typedef SharedHandle<SingleFileDownloadContext> SingleFileDownloadContextHandle;
+namespace aria2 {
+
+class DownloadContext;
 class PieceStorage;
-typedef SharedHandle<PieceStorage> PieceStorageHandle;
 class Logger;
 class MessageDigestContext;
-typedef SharedHandle<MessageDigestContext> MessageDigestContextHandle;
 
 class IteratableChecksumValidator:public IteratableValidator
 {
 private:
-  SingleFileDownloadContextHandle _dctx;
+  SharedHandle<DownloadContext> dctx_;
 
-  PieceStorageHandle _pieceStorage;
+  SharedHandle<PieceStorage> pieceStorage_;
 
-  int64_t _currentOffset;
+  off_t currentOffset_;
 
-  MessageDigestContextHandle _ctx;
+  SharedHandle<MessageDigestContext> ctx_;
 
-  const Logger* _logger;
+  Logger* logger_;
 
-  unsigned char* _buffer;
+  unsigned char* buffer_;
 
 public:
-  IteratableChecksumValidator(const SingleFileDownloadContextHandle& dctx,
-			      const PieceStorageHandle& pieceStorage);
+  IteratableChecksumValidator(const SharedHandle<DownloadContext>& dctx,
+                              const SharedHandle<PieceStorage>& pieceStorage);
 
   virtual ~IteratableChecksumValidator();
 
@@ -72,14 +71,16 @@ public:
 
   virtual bool finished() const;
 
-  virtual int64_t getCurrentOffset() const
+  virtual off_t getCurrentOffset() const
   {
-    return _currentOffset;
+    return currentOffset_;
   }
 
-  virtual int64_t getTotalLength() const;
+  virtual uint64_t getTotalLength() const;
 };
 
 typedef SharedHandle<IteratableChecksumValidator> IteratableChecksumValidatorHandle;
 
+} // namespace aria2
+
 #endif // _D_ITERATABLE_CHECKSUM_VALIDATOR_H_
