@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,33 +37,32 @@
 
 #include "IteratableValidator.h"
 
+namespace aria2 {
+
 class DownloadContext;
-typedef SharedHandle<DownloadContext> DownloadContextHandle;
 class PieceStorage;
-typedef SharedHandle<PieceStorage> PieceStorageHandle;
 class BitfieldMan;
 class Logger;
 class MessageDigestContext;
-typedef SharedHandle<MessageDigestContext> MessageDigestContextHandle;
 
 class IteratableChunkChecksumValidator:public IteratableValidator
 {
 private:
-  DownloadContextHandle _dctx;
-  PieceStorageHandle _pieceStorage;
-  BitfieldMan* _bitfield;
-  uint32_t _currentIndex;
-  const Logger* _logger;
-  MessageDigestContextHandle _ctx;
-  unsigned char* _buffer;
+  SharedHandle<DownloadContext> dctx_;
+  SharedHandle<PieceStorage> pieceStorage_;
+  SharedHandle<BitfieldMan> bitfield_;
+  size_t currentIndex_;
+  Logger* logger_;
+  SharedHandle<MessageDigestContext> ctx_;
+  unsigned char* buffer_;
 
-  string calculateActualChecksum();
+  std::string calculateActualChecksum();
 
-  string digest(int64_t offset, int32_t length);
+  std::string digest(off_t offset, size_t length);
 
 public:
-  IteratableChunkChecksumValidator(const DownloadContextHandle& dctx,
-				   const PieceStorageHandle& pieceStorage);
+  IteratableChunkChecksumValidator(const SharedHandle<DownloadContext>& dctx,
+                                   const SharedHandle<PieceStorage>& pieceStorage);
 
   virtual ~IteratableChunkChecksumValidator();
 
@@ -73,11 +72,13 @@ public:
 
   virtual bool finished() const;
 
-  virtual int64_t getCurrentOffset() const;
+  virtual off_t getCurrentOffset() const;
 
-  virtual int64_t getTotalLength() const;
+  virtual uint64_t getTotalLength() const;
 };
 
 typedef SharedHandle<IteratableChunkChecksumValidator> IteratableChunkChecksumValidatorHandle;
 
+} // namespace aria2
+
 #endif // _D_ITERATABLE_CHUNK_CHECKSUM_VALIDATOR_H_
