@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -45,10 +45,12 @@ namespace aria2 {
 
 class LogFactory {
 private:
-  static std::string filename;
-  static Logger* logger;
-  static bool _consoleOutput;
-  static Logger::LEVEL _logLevel;
+  static std::string filename_;
+  static Logger* logger_;
+  static bool consoleOutput_;
+  static Logger::LEVEL logLevel_;
+
+  static void openLogger(Logger* logger);
 public:
   /**
    * Get logger instance. Returned logger is singleton.
@@ -57,21 +59,19 @@ public:
   static Logger* getInstance();
 
   /**
-   * Set a filename to write log.
+   * Set a filename to write log. If name is "-", log is written to
+   * stdout. If name is "", log is not written to file.
    */
-  static void setLogFile(const std::string& name) {
-    filename = name;
-  }
+  static void setLogFile(const std::string& name);
 
   /**
    * Set flag whether the log is printed in console.
    * If f is false, log is not printed in console.
    */
   static void setConsoleOutput(bool f) {
-    _consoleOutput = f;
+    consoleOutput_ = f;
   }
 
-
   /**
    * Set log level to output.
    */
@@ -87,6 +87,8 @@ public:
    * Releases used resources
    */
   static void release();
+
+  static void reconfigure();
 };
 
 } // namespace aria2
