@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,11 +37,12 @@
 
 #include "common.h"
 
-#include <deque>
+#include <vector>
 
 #include "SharedHandle.h"
 #include "BtConstants.h"
 #include "SocketBuffer.h"
+#include "Command.h"
 
 namespace aria2 {
 
@@ -51,7 +52,7 @@ class SocketCore;
 class DHKeyExchange;
 class ARC4Encryptor;
 class ARC4Decryptor;
-class BtContext;
+class DownloadContext;
 
 class MSEHandshake {
 public:
@@ -80,28 +81,28 @@ private:
 
   static const size_t MAX_BUFFER_LENGTH = 6*1024;
 
-  int32_t _cuid;
-  SharedHandle<SocketCore> _socket;
-  const Option* _option;
-  Logger* _logger;
+  cuid_t cuid_;
+  SharedHandle<SocketCore> socket_;
+  const Option* option_;
+  Logger* logger_;
 
-  unsigned char _rbuf[MAX_BUFFER_LENGTH];
-  size_t _rbufLength;
+  unsigned char rbuf_[MAX_BUFFER_LENGTH];
+  size_t rbufLength_;
 
-  SocketBuffer _socketBuffer;
+  SocketBuffer socketBuffer_;
 
-  CRYPTO_TYPE _negotiatedCryptoType;
-  DHKeyExchange* _dh;
-  SharedHandle<ARC4Encryptor> _encryptor;
-  SharedHandle<ARC4Decryptor> _decryptor;
-  unsigned char _infoHash[INFO_HASH_LENGTH];
-  unsigned char _secret[KEY_LENGTH];
-  bool _initiator;
-  unsigned char _initiatorVCMarker[VC_LENGTH];
-  size_t _markerIndex;
-  uint16_t _padLength;
-  uint16_t _iaLength;
-  unsigned char* _ia;
+  CRYPTO_TYPE negotiatedCryptoType_;
+  DHKeyExchange* dh_;
+  SharedHandle<ARC4Encryptor> encryptor_;
+  SharedHandle<ARC4Decryptor> decryptor_;
+  unsigned char infoHash_[INFO_HASH_LENGTH];
+  unsigned char secret_[KEY_LENGTH];
+  bool initiator_;
+  unsigned char initiatorVCMarker_[VC_LENGTH];
+  size_t markerIndex_;
+  uint16_t padLength_;
+  uint16_t iaLength_;
+  unsigned char* ia_;
 
   static const unsigned char* PRIME;
 
@@ -123,7 +124,7 @@ private:
   }
 
   uint16_t verifyPadLength(const unsigned char* padlenbuf,
-			   const char* padName);
+                           const char* padName);
 
   void verifyVC(const unsigned char* vcbuf);
 
@@ -132,8 +133,8 @@ private:
   size_t receiveNBytes(size_t bytes);
 
 public:
-  MSEHandshake(int32_t cuid, const SharedHandle<SocketCore>& socket,
-	       const Option* op);
+  MSEHandshake(cuid_t cuid, const SharedHandle<SocketCore>& socket,
+               const Option* op);
 
   ~MSEHandshake();
   
@@ -158,7 +159,7 @@ public:
   bool findReceiverHashMarker();
 
   bool receiveReceiverHashAndPadCLength
-  (const std::deque<SharedHandle<BtContext> >& btContexts);
+  (const std::vector<SharedHandle<DownloadContext> >& downloadContexts);
 
   bool receiveReceiverIALength();
 
@@ -169,42 +170,42 @@ public:
   // returns plain text IA
   const unsigned char* getIA() const
   {
-    return _ia;
+    return ia_;
   }
 
   size_t getIALength() const
   {
-    return _iaLength;
+    return iaLength_;
   }
 
   const unsigned char* getInfoHash() const
   {
-    return _infoHash;
+    return infoHash_;
   }
 
   CRYPTO_TYPE getNegotiatedCryptoType() const
   {
-    return _negotiatedCryptoType;
+    return negotiatedCryptoType_;
   }
 
   const SharedHandle<ARC4Encryptor>& getEncryptor() const
   {
-    return _encryptor;
+    return encryptor_;
   }
 
   const SharedHandle<ARC4Decryptor>& getDecryptor() const
   {
-    return _decryptor;
+    return decryptor_;
   }
 
   const unsigned char* getBuffer() const
   {
-    return _rbuf;
+    return rbuf_;
   }
 
   size_t getBufferLength() const
   {
-    return _rbufLength;
+    return rbufLength_;
   }
 
 };
