@@ -37,6 +37,7 @@
 #include <algorithm>
 
 #include "MetalinkResource.h"
+#include "MetalinkMetaurl.h"
 #include "FileEntry.h"
 #include "util.h"
 #include "a2functional.h"
@@ -50,27 +51,28 @@
 namespace aria2 {
 
 MetalinkEntry::MetalinkEntry():
-  file(0),
+  sizeKnown(false),
   maxConnections(-1)
 {}
 
 MetalinkEntry::~MetalinkEntry() {}
 
-class AddLocationPreference {
+class AddLocationPriority {
 private:
-  std::deque<std::string> _locations;
-  int _preferenceToAdd;
+  std::vector<std::string> locations_;
+  int priorityToAdd_;
 public:
-  AddLocationPreference(const std::deque<std::string>& locations, int preferenceToAdd):
-    _locations(locations), _preferenceToAdd(preferenceToAdd)
+  AddLocationPriority
+  (const std::vector<std::string>& locations, int priorityToAdd):
+    locations_(locations), priorityToAdd_(priorityToAdd)
   {
-    std::transform(_locations.begin(), _locations.end(), _locations.begin(), util::toUpper);
-    std::sort(_locations.begin(), _locations.end());
+    std::sort(locations_.begin(), locations_.end());
   }
 
   void operator()(SharedHandle<MetalinkResource>& res) {
-    if(std::binary_search(_locations.begin(), _locations.end(), res->location)) {
-      res->preference += _preferenceToAdd;
+    if(std::binary_search
+       (locations_.begin(), locations_.end(), res->location)) {
+      res->priority += priorityToAdd_;
     }
   }
 };
@@ -80,19 +82,19 @@ MetalinkEntry& MetalinkEntry::operator=(const MetalinkEntry& metalinkEntry)
   if(this != &metalinkEntry) {
     this->file = metalinkEntry.file;
     this->version = metalinkEntry.version;
-    this->language = metalinkEntry.language;
-    this->os = metalinkEntry.os;
+    this->languages = metalinkEntry.languages;
+    this->oses = metalinkEntry.oses;
     this->maxConnections = metalinkEntry.maxConnections;
 #ifdef ENABLE_MESSAGE_DIGEST
     this->checksum = metalinkEntry.checksum;
     this->chunkChecksum = metalinkEntry.chunkChecksum;
 #endif // ENABLE_MESSAGE_DIGEST
-    this->_signature = metalinkEntry._signature;
+    this->signature_ = metalinkEntry.signature_;
   }
   return *this;
 }
 
-std::string MetalinkEntry::getPath() const
+const std::string& MetalinkEntry::getPath() const
 {
   return file->getPath();
 }
@@ -102,48 +104,56 @@ uint64_t MetalinkEntry::getLength() const
   return file->getLength();
 }
 
-void MetalinkEntry::setLocationPreference(const std::deque<std::string>& locations,
-                                          int preferenceToAdd)
+void MetalinkEntry::setLocationPriority
+(const std::vector<std::string>& locations, int priorityToAdd)
 {
   std::for_each(resources.begin(), resources.end(),
-                AddLocationPreference(locations, preferenceToAdd));
+                AddLocationPriority(locations, priorityToAdd));
 }
 
-class AddProtocolPreference {
+class AddProtocolPriority {
 private:
-  std::string _protocol;
-  int _preferenceToAdd;
+  std::string protocol_;
+  int priorityToAdd_;
 public:
-  AddProtocolPreference(const std::string& protocol, int prefToAdd):
-    _protocol(protocol), _preferenceToAdd(prefToAdd) {}
+  AddProtocolPriority(const std::string& protocol, int prefToAdd):
+    protocol_(protocol), priorityToAdd_(prefToAdd) {}
 
   void operator()(const SharedHandle<MetalinkResource>& res) const
   {
-    if(_protocol == MetalinkResource::getTypeString(res->type)) {
-      res->preference += _preferenceToAdd;
+    if(protocol_ == MetalinkResource::getTypeString(res->type)) {
+      res->priority += priorityToAdd_;
     }
   }
 };
 
-void MetalinkEntry::setProtocolPreference(const std::string& protocol,
-                                          int preferenceToAdd)
+void MetalinkEntry::setProtocolPriority(const std::string& protocol,
+                                          int priorityToAdd)
 {
   std::for_each(resources.begin(), resources.end(),
-                AddProtocolPreference(protocol, preferenceToAdd));
+                AddProtocolPriority(protocol, priorityToAdd));
 }
 
-class PrefOrder {
+template<typename T>
+class PriorityHigher {
 public:
-  bool operator()(const SharedHandle<MetalinkResource>& res1,
-                  const SharedHandle<MetalinkResource>& res2) {
-    return res1->preference > res2->preference;
+  bool operator()(const SharedHandle<T>& res1,
+                  const SharedHandle<T>& res2)
+  {
+    return res1->priority < res2->priority;
   }
 };
 
-void MetalinkEntry::reorderResourcesByPreference() {
+void MetalinkEntry::reorderResourcesByPriority() {
   std::random_shuffle(resources.begin(), resources.end(),
                       *(SimpleRandomizer::getInstance().get()));
-  std::sort(resources.begin(), resources.end(), PrefOrder());
+  std::sort(resources.begin(), resources.end(),
+            PriorityHigher<MetalinkResource>());
+}
+
+void MetalinkEntry::reorderMetaurlsByPriority()
+{
+  std::sort(metaurls.begin(), metaurls.end(),PriorityHigher<MetalinkMetaurl>());
 }
 
 class Supported:public std::unary_function<SharedHandle<MetalinkResource>, bool> {
@@ -173,8 +183,8 @@ void MetalinkEntry::dropUnsupportedResource() {
 }
 
 void MetalinkEntry::toFileEntry
-(std::deque<SharedHandle<FileEntry> >& fileEntries,
- const std::deque<SharedHandle<MetalinkEntry> >& metalinkEntries)
+(std::vector<SharedHandle<FileEntry> >& fileEntries,
+ const std::vector<SharedHandle<MetalinkEntry> >& metalinkEntries)
 {
   std::transform(metalinkEntries.begin(), metalinkEntries.end(),
                  std::back_inserter(fileEntries),
@@ -183,7 +193,7 @@ void MetalinkEntry::toFileEntry
 
 void MetalinkEntry::setSignature(const SharedHandle<Signature>& signature)
 {
-  _signature = signature;
+  signature_ = signature;
 }
 
 } // namespace aria2
