@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,13 +38,15 @@
 #include "common.h"
 
 #include <string>
-#include <deque>
+#include <vector>
+#include <algorithm>
 
 #include "SharedHandle.h"
 
 namespace aria2 {
 
 class MetalinkResource;
+class MetalinkMetaurl;
 class FileEntry;
 #ifdef ENABLE_MESSAGE_DIGEST
 class Checksum;
@@ -56,16 +58,19 @@ class MetalinkEntry {
 public:
   SharedHandle<FileEntry> file;
   std::string version;
-  std::string language;
-  std::string os;
-  std::deque<SharedHandle<MetalinkResource> > resources;
-  int maxConnections;
+  std::vector<std::string> languages;
+  std::vector<std::string> oses;
+  // True if size is specified in Metalink document.
+  bool sizeKnown;
+  std::vector<SharedHandle<MetalinkResource> > resources;
+  std::vector<SharedHandle<MetalinkMetaurl> > metaurls;
+  int maxConnections; // Metalink3Spec
 #ifdef ENABLE_MESSAGE_DIGEST
   SharedHandle<Checksum> checksum;
   SharedHandle<ChunkChecksum> chunkChecksum;
 #endif // ENABLE_MESSAGE_DIGEST
 private:
-  SharedHandle<Signature> _signature;
+  SharedHandle<Signature> signature_;
 public:
   MetalinkEntry();
 
@@ -73,7 +78,7 @@ public:
 
   MetalinkEntry& operator=(const MetalinkEntry& metalinkEntry);
 
-  std::string getPath() const;
+  const std::string& getPath() const;
 
   uint64_t getLength() const;
 
@@ -84,22 +89,36 @@ public:
 
   void dropUnsupportedResource();
 
-  void reorderResourcesByPreference();
+  void reorderResourcesByPriority();
+
+  void reorderMetaurlsByPriority();
   
-  void setLocationPreference(const std::deque<std::string>& locations, int preferenceToAdd);
-  void setProtocolPreference(const std::string& protocol, int preferenceToAdd);
+  bool containsLanguage(const std::string& lang) const
+  {
+    return
+      std::find(languages.begin(), languages.end(), lang) != languages.end();
+  }
+
+  bool containsOS(const std::string& os) const
+  {
+    return std::find(oses.begin(), oses.end(), os) != oses.end();
+  }
+
+  void setLocationPriority
+  (const std::vector<std::string>& locations, int priorityToAdd);
+
+  void setProtocolPriority(const std::string& protocol, int priorityToAdd);
 
   static void toFileEntry
-  (std::deque<SharedHandle<FileEntry> >& fileEntries,
-   const std::deque<SharedHandle<MetalinkEntry> >& metalinkEntries);
+  (std::vector<SharedHandle<FileEntry> >& fileEntries,
+   const std::vector<SharedHandle<MetalinkEntry> >& metalinkEntries);
 
   void setSignature(const SharedHandle<Signature>& signature);
 
   const SharedHandle<Signature>& getSignature() const
   {
-    return _signature;
+    return signature_;
   }
-
 };
 
 } // namespace aria2
