@@ -44,6 +44,7 @@
 #include "prefs.h"
 #include "Option.h"
 #include "DownloadContext.h"
+#include "download_helper.h"
 
 namespace aria2 {
 
@@ -61,20 +62,27 @@ MetalinkPostDownloadHandler::MetalinkPostDownloadHandler()
 MetalinkPostDownloadHandler::~MetalinkPostDownloadHandler() {}
 
 void MetalinkPostDownloadHandler::getNextRequestGroups
-(std::deque<SharedHandle<RequestGroup> >& groups,
+(std::vector<SharedHandle<RequestGroup> >& groups,
  RequestGroup* requestGroup)
 {
-  _logger->debug("Generating RequestGroups for Metalink file %s",
-                 requestGroup->getFirstFilePath().c_str());
+  if(getLogger()->debug()) {
+    getLogger()->debug("Generating RequestGroups for Metalink file %s",
+                       requestGroup->getFirstFilePath().c_str());
+  }
   SharedHandle<DiskAdaptor> diskAdaptor =
     requestGroup->getPieceStorage()->getDiskAdaptor();
   try {
     diskAdaptor->openExistingFile();
     //requestOption.put(PREF_DIR, requestGroup->getDownloadContext()->getDir());
-    std::deque<SharedHandle<RequestGroup> > newRgs;
+    std::vector<SharedHandle<RequestGroup> > newRgs;
     Metalink2RequestGroup().generate(newRgs, diskAdaptor,
                                      requestGroup->getOption());
     requestGroup->followedBy(newRgs.begin(), newRgs.end());
+    SharedHandle<MetadataInfo> mi =
+      createMetadataInfoFromFirstFileEntry(requestGroup->getDownloadContext());
+    if(!mi.isNull()) {
+      setMetadataInfo(newRgs.begin(), newRgs.end(), mi);
+    }
     groups.insert(groups.end(), newRgs.begin(), newRgs.end());
     diskAdaptor->closeFile();
   } catch(Exception& e) {
