@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -35,19 +35,12 @@
 #ifndef _D_METALINK_PROCESSOR_H_
 #define _D_METALINK_PROCESSOR_H_
 
-#include "Metalinker.h"
 #include "common.h"
 
-class BinaryStream;
-typedef SharedHandle<BinaryStream> BinaryStreamHandle;
-
-class MetalinkProcessor {
-public:
-  virtual ~MetalinkProcessor() {}
-
-  virtual MetalinkerHandle parseFile(const string& filename) = 0;
-
-  virtual MetalinkerHandle parseFromBinaryStream(const BinaryStreamHandle& binaryStream) = 0;
-};
+#ifdef HAVE_LIBXML2
+# include "XML2SAXMetalinkProcessor.h"
+#elif HAVE_LIBEXPAT
+# include "ExpatMetalinkProcessor.h"
+#endif
 
 #endif // _D_METALINK_PROCESSOR_H_
