@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -34,8 +34,28 @@
 /* copyright --> */
 #include "MetalinkResource.h"
 
+namespace aria2 {
+
+std::string MetalinkResource::type2String[] = {
+  "ftp", "http", "https", "bittorrent", "not_supported", "unknown"
+};
+
+const std::string MetalinkResource::HTTP("http");
+
+const std::string MetalinkResource::HTTPS("https");
+
+const std::string MetalinkResource::FTP("ftp");
+
+const std::string MetalinkResource::BITTORRENT("bittorrent");
+
+const std::string MetalinkResource::TORRENT("torrent");
+
 MetalinkResource::MetalinkResource():
+  type(TYPE_UNKNOWN),
+  priority(getLowestPriority()),
   maxConnections(-1)
 {}
 
 MetalinkResource::~MetalinkResource() {}
+
+} // namespace aria2
