@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,22 +36,39 @@
 #define _D_METALINK_RESOURCE_H_
 
 #include "common.h"
+#include <string>
+
+namespace aria2 {
 
 class MetalinkResource {
 public:
   enum TYPE {
-    TYPE_FTP,
+    TYPE_FTP = 0,
     TYPE_HTTP,
     TYPE_HTTPS,
     TYPE_BITTORRENT,
-    TYPE_NOT_SUPPORTED
+    TYPE_NOT_SUPPORTED,
+    TYPE_UNKNOWN
   };
+
+  static std::string type2String[];
+
+  static const std::string HTTP;
+
+  static const std::string HTTPS;
+
+  static const std::string FTP;
+
+  static const std::string BITTORRENT;
+
+  static const std::string TORRENT; // Metalink4Spec
+
 public:
-  string url;
+  std::string url;
   TYPE type;
-  string location;
-  int32_t preference;
-  int32_t maxConnections;
+  std::string location;
+  int priority;
+  int maxConnections; // Metalink3Spec
 public:
   MetalinkResource();
   ~MetalinkResource();
@@ -61,14 +78,23 @@ public:
       this->url = metalinkResource.url;
       this->type = metalinkResource.type;
       this->location = metalinkResource.location;
-      this->preference = metalinkResource.preference;
+      this->priority = metalinkResource.priority;
       this->maxConnections = metalinkResource.maxConnections;
     }
     return *this;
   }
+
+  static const std::string& getTypeString(TYPE type)
+  {
+    return type2String[type];
+  }
+
+  static int getLowestPriority()
+  {
+    return 999999;
+  }
 };
 
-typedef SharedHandle<MetalinkResource> MetalinkResourceHandle;
-typedef deque<MetalinkResourceHandle> MetalinkResources;
+} // namespace aria2
 
 #endif // _D_METALINK_RESOURCE_H_
