@@ -42,7 +42,8 @@ Metalinker::Metalinker() {}
 
 Metalinker::~Metalinker() {}
 
-class EntryQuery:public std::unary_function<SharedHandle<MetalinkEntry>, bool> {
+class EntryQuery:
+    public std::unary_function<SharedHandle<MetalinkEntry>, bool> {
 private:
   std::string version;
   std::string language;
@@ -62,12 +63,12 @@ public:
       }
     }
     if(!language.empty()) {
-      if(language != entry->language) {
+      if(!entry->containsLanguage(language)) {
         return false;
       }
     }
     if(!os.empty()) {
-      if(os != entry->os) {
+      if(!entry->containsOS(os)) {
         return false;
       }
     }
@@ -76,12 +77,12 @@ public:
 };
 
 void Metalinker::queryEntry
-(std::deque<SharedHandle<MetalinkEntry> >& queryResult,
+(std::vector<SharedHandle<MetalinkEntry> >& queryResult,
  const std::string& version,
  const std::string& language,
  const std::string& os) const
 {
-  std::remove_copy_if(entries.begin(), entries.end(),
+  std::remove_copy_if(entries_.begin(), entries_.end(),
                       std::back_inserter(queryResult),
                       std::not1(EntryQuery(version, language, os)));
 }
