@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -43,21 +43,24 @@ class Netrc;
 
 class NetrcAuthResolver : public AbstractAuthResolver {
 private:
-  SharedHandle<Netrc> _netrc;
+  SharedHandle<Netrc> netrc_;
 
-  bool _ignoreDefault;
+  bool ignoreDefault_;
 
-  SharedHandle<AuthConfig> findNetrcAuthenticator(const std::string& hostname) const;
+  SharedHandle<AuthConfig> findNetrcAuthenticator
+  (const std::string& hostname) const;
 public:
   NetrcAuthResolver();
 
-  virtual ~NetrcAuthResolver() {}
-
-  virtual SharedHandle<AuthConfig> resolveAuthConfig(const std::string& hostname);
+  virtual SharedHandle<AuthConfig> resolveAuthConfig
+  (const std::string& hostname);
 
   void setNetrc(const SharedHandle<Netrc>& netrc);
 
-  SharedHandle<Netrc> getNetrc() const;
+  const SharedHandle<Netrc>& getNetrc() const
+  {
+    return netrc_;
+  }
 
   // Ignores default token of netrc
   void ignoreDefault();
