@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,11 +38,11 @@
 namespace aria2 {
 
 PStringSegment::PStringSegment(const std::string& value,
-			       const SharedHandle<PStringDatum>& next):
-  _value(value), _next(next) {}
+                               const SharedHandle<PStringDatum>& next):
+  value_(value), next_(next) {}
 
 PStringSegment::PStringSegment(const std::string& value):
-  _value(value) {}
+  value_(value) {}
 
 PStringSegment::~PStringSegment() {}
 
@@ -53,17 +53,17 @@ void PStringSegment::accept(PStringVisitor& visitor)
 
 const std::string& PStringSegment::getValue() const
 {
-  return _value;
+  return value_;
 }
 
 bool PStringSegment::hasNext() const
 {
-  return !_next.isNull();
+  return !next_.isNull();
 }
 
 SharedHandle<PStringDatum> PStringSegment::getNext() const
 {
-  return _next;
+  return next_;
 }
 
 } // namespace aria2
