@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,32 +37,30 @@
 #include <cstring>
 #include <cassert>
 
-#include "Util.h"
+#include "util.h"
+#include "a2functional.h"
 #include "PeerSessionResource.h"
-#ifdef ENABLE_MESSAGE_DIGEST
-# include "MessageDigestHelper.h"
-#endif // ENABLE_MESSAGE_DIGEST
 #include "BtMessageDispatcher.h"
+#include "wallclock.h"
 
 namespace aria2 {
 
 #define BAD_CONDITION_INTERVAL 10
 
 Peer::Peer(std::string ipaddr, uint16_t port, bool incoming):
-  ipaddr(ipaddr),
-  port(port),
-  _badConditionStartTime(0),
-  _seeder(false),
-  _res(0),
-  _incoming(incoming)
+  ipaddr_(ipaddr),
+  port_(port),
+  firstContactTime_(global::wallclock),
+  badConditionStartTime_(0),
+  seeder_(false),
+  res_(0),
+  incoming_(incoming),
+  localPeer_(false)
 {
+  memset(peerId_, 0, PEER_ID_LENGTH);
   resetStatus();
-  std::string idSeed = ipaddr+":"+Util::uitos(port);
-#ifdef ENABLE_MESSAGE_DIGEST
-  id = MessageDigestHelper::digestString(MessageDigestContext::SHA1, idSeed);
-#else
-  id = idSeed;
-#endif // ENABLE_MESSAGE_DIGEST
+  id_ = ipaddr_;
+  strappend(id_, A2STR::COLON_C, util::uitos(port_));
 }
 
 Peer::~Peer()
@@ -70,425 +68,351 @@ Peer::~Peer()
   releaseSessionResource();
 }
 
-bool Peer::operator==(const Peer& p)
+void Peer::usedBy(cuid_t cuid)
 {
-  return id == p.id;
-}
-  
-bool Peer::operator!=(const Peer& p)
-{
-  return !(*this == p);
-}
-
-const std::string& Peer::getID() const
-{
-  return id;
-}
-
-void Peer::usedBy(int32_t cuid)
-{
-  _cuid = cuid;
-}
-
-int32_t Peer::usedBy() const
-{
-  return _cuid;
-}
-
-bool Peer::unused() const
-{
-  return _cuid == 0;
+  cuid_ = cuid;
 }
 
 void Peer::allocateSessionResource(size_t pieceLength, uint64_t totalLength)
 {
-  delete _res;
-  _res = new PeerSessionResource(pieceLength, totalLength);
-  _res->getPeerStat().downloadStart();
+  delete res_;
+  res_ = new PeerSessionResource(pieceLength, totalLength);
+  res_->getPeerStat().downloadStart();
+}
+
+void Peer::reconfigureSessionResource(size_t pieceLength, uint64_t totalLength)
+{
+  assert(res_);
+  res_->reconfigure(pieceLength, totalLength);
 }
 
 void Peer::releaseSessionResource()
 {
-  delete _res;
-  _res = 0;
-}
-
-bool Peer::isActive() const
-{
-  return _res != 0;
+  delete res_;
+  res_ = 0;
 }
 
 void Peer::setPeerId(const unsigned char* peerId)
 {
-  memcpy(_peerId, peerId, PEER_ID_LENGTH);
-}
-
-const unsigned char* Peer::getPeerId() const
-{
-  return _peerId;
+  memcpy(peerId_, peerId, PEER_ID_LENGTH);
 }
 
 void Peer::resetStatus() {
-  _cuid = 0;
+  cuid_ = 0;
 }
 
 bool Peer::amChoking() const
 {
-  assert(_res);
-  return _res->amChoking();
+  assert(res_);
+  return res_->amChoking();
 }
 
 void Peer::amChoking(bool b) const
 {
-  assert(_res);
-  _res->amChoking(b);
+  assert(res_);
+  res_->amChoking(b);
 }
 
 // localhost is interested in this peer
 bool Peer::amInterested() const
 {
-  assert(_res);
-  return _res->amInterested();
+  assert(res_);
+  return res_->amInterested();
 }
 
 void Peer::amInterested(bool b) const
 {
-  assert(_res);
-  _res->amInterested(b);
+  assert(res_);
+  res_->amInterested(b);
 }
 
 // this peer is choking localhost
 bool Peer::peerChoking() const
 {
-  assert(_res);
-  return _res->peerChoking();
+  assert(res_);
+  return res_->peerChoking();
 }
 
 void Peer::peerChoking(bool b) const
 {
-  assert(_res);
-  _res->peerChoking(b);
+  assert(res_);
+  res_->peerChoking(b);
 }
 
 // this peer is interested in localhost
 bool Peer::peerInterested() const
 {
-  assert(_res);
-  return _res->peerInterested();
+  assert(res_);
+  return res_->peerInterested();
 }
 
 void Peer::peerInterested(bool b)
 {
-  assert(_res);
-  _res->peerInterested(b);
+  assert(res_);
+  res_->peerInterested(b);
 }
   
-  // this peer should be choked
+// this peer should be choked
 bool Peer::chokingRequired() const
 {
-  assert(_res);
-  return _res->chokingRequired();
+  assert(res_);
+  return res_->chokingRequired();
 }
 
 void Peer::chokingRequired(bool b)
 {
-  assert(_res);
-  _res->chokingRequired(b);
+  assert(res_);
+  res_->chokingRequired(b);
 }
 
 // this peer is eligible for unchoking optionally.
 bool Peer::optUnchoking() const
 {
-  assert(_res);
-  return _res->optUnchoking();
+  assert(res_);
+  return res_->optUnchoking();
 }
 
 void Peer::optUnchoking(bool b)
 {
-  assert(_res);
-  _res->optUnchoking(b);
+  assert(res_);
+  res_->optUnchoking(b);
 }
 
 // this peer is snubbing.
 bool Peer::snubbing() const
 {
-  assert(_res);
-  return _res->snubbing();
+  assert(res_);
+  return res_->snubbing();
 }
 
 void Peer::snubbing(bool b)
 {
-  assert(_res);
-  _res->snubbing(b);
+  assert(res_);
+  res_->snubbing(b);
 }
 
 void Peer::updateUploadLength(size_t bytes)
 {
-  assert(_res);
-  _res->updateUploadLength(bytes);
+  assert(res_);
+  res_->updateUploadLength(bytes);
 }
 
 void Peer::updateDownloadLength(size_t bytes)
 {
-  assert(_res);
-  _res->updateDownloadLength(bytes);
+  assert(res_);
+  res_->updateDownloadLength(bytes);
 }
 
 void Peer::updateSeeder()
 {
-  assert(_res);
-  if(_res->hasAllPieces()) {
-    _seeder = true;
-  }  
+  assert(res_);
+  seeder_ = res_->hasAllPieces();
 }
 
 void Peer::updateBitfield(size_t index, int operation) {
-  assert(_res);
-  _res->updateBitfield(index, operation);
+  assert(res_);
+  res_->updateBitfield(index, operation);
   updateSeeder();
 }
 
 unsigned int Peer::calculateUploadSpeed()
 {
-  assert(_res);
-  return _res->getPeerStat().calculateUploadSpeed();
-}
-
-unsigned int Peer::calculateUploadSpeed(const struct timeval& now)
-{
-  assert(_res);
-  return _res->getPeerStat().calculateUploadSpeed(now);
+  assert(res_);
+  return res_->getPeerStat().calculateUploadSpeed();
 }
 
 unsigned int Peer::calculateDownloadSpeed()
 {
-  assert(_res);
-  return _res->getPeerStat().calculateDownloadSpeed();
-}
-
-unsigned int Peer::calculateDownloadSpeed(const struct timeval& now)
-{
-  assert(_res);
-  return _res->getPeerStat().calculateDownloadSpeed(now);
+  assert(res_);
+  return res_->getPeerStat().calculateDownloadSpeed();
 }
 
 uint64_t Peer::getSessionUploadLength() const
 {
-  assert(_res);
-  return _res->uploadLength();
+  assert(res_);
+  return res_->uploadLength();
 }
 
 uint64_t Peer::getSessionDownloadLength() const
 {
-  assert(_res);
-  return _res->downloadLength();
+  assert(res_);
+  return res_->downloadLength();
 }
 
 void Peer::setBitfield(const unsigned char* bitfield, size_t bitfieldLength)
 {
-  assert(_res);
-  _res->setBitfield(bitfield, bitfieldLength);
+  assert(res_);
+  res_->setBitfield(bitfield, bitfieldLength);
   updateSeeder();
 }
 
 const unsigned char* Peer::getBitfield() const
 {
-  assert(_res);
-  return _res->getBitfield();
+  assert(res_);
+  return res_->getBitfield();
 }
 
 size_t Peer::getBitfieldLength() const
 {
-  assert(_res);
-  return _res->getBitfieldLength();
+  assert(res_);
+  return res_->getBitfieldLength();
 }
 
 bool Peer::shouldBeChoking() const {
-  assert(_res);
-  return _res->shouldBeChoking();
+  assert(res_);
+  return res_->shouldBeChoking();
 }
 
 bool Peer::hasPiece(size_t index) const {
-  assert(_res);
-  return _res->hasPiece(index);
+  assert(res_);
+  return res_->hasPiece(index);
 }
 
 void Peer::setFastExtensionEnabled(bool enabled)
 {
-  assert(_res);
-  return _res->fastExtensionEnabled(enabled);
+  assert(res_);
+  return res_->fastExtensionEnabled(enabled);
 }
 
 bool Peer::isFastExtensionEnabled() const
 {
-  assert(_res);
-  return _res->fastExtensionEnabled();
+  assert(res_);
+  return res_->fastExtensionEnabled();
 }
 
 size_t Peer::countPeerAllowedIndexSet() const
 {
-  assert(_res);
-  return _res->peerAllowedIndexSet().size();
+  assert(res_);
+  return res_->peerAllowedIndexSet().size();
 }
 
-const std::deque<size_t>& Peer::getPeerAllowedIndexSet() const
+const std::vector<size_t>& Peer::getPeerAllowedIndexSet() const
 {
-  assert(_res);
-  return _res->peerAllowedIndexSet();
+  assert(res_);
+  return res_->peerAllowedIndexSet();
 }
 
 bool Peer::isInPeerAllowedIndexSet(size_t index) const
 {
-  assert(_res);
-  return _res->peerAllowedIndexSetContains(index);
+  assert(res_);
+  return res_->peerAllowedIndexSetContains(index);
 }
 
 void Peer::addPeerAllowedIndex(size_t index)
 {
-  assert(_res);
-  _res->addPeerAllowedIndex(index);
+  assert(res_);
+  res_->addPeerAllowedIndex(index);
 }
 
 bool Peer::isInAmAllowedIndexSet(size_t index) const
 {
-  assert(_res);
-  return _res->amAllowedIndexSetContains(index);
+  assert(res_);
+  return res_->amAllowedIndexSetContains(index);
 }
 
 void Peer::addAmAllowedIndex(size_t index)
 {
-  assert(_res);
-  _res->addAmAllowedIndex(index);
+  assert(res_);
+  res_->addAmAllowedIndex(index);
 }
 
 void Peer::setAllBitfield() {
-  assert(_res);
-  _res->markSeeder();
-  _seeder = true;
-}
-
-void Peer::updateLatency(unsigned int latency)
-{
-  assert(_res);
-  _res->updateLatency(latency);
-}
-
-unsigned int Peer::getLatency() const
-{
-  assert(_res);
-  return _res->latency();
+  assert(res_);
+  res_->markSeeder();
+  updateSeeder();
 }
 
 void Peer::startBadCondition()
 {
-  _badConditionStartTime.reset();
+  badConditionStartTime_ = global::wallclock;
 }
 
 bool Peer::isGood() const
 {
-  return _badConditionStartTime.elapsed(BAD_CONDITION_INTERVAL);
+  return badConditionStartTime_.
+    difference(global::wallclock) >= BAD_CONDITION_INTERVAL;
 }
 
 uint8_t Peer::getExtensionMessageID(const std::string& name) const
 {
-  assert(_res);
-  return _res->getExtensionMessageID(name);
+  assert(res_);
+  return res_->getExtensionMessageID(name);
 }
 
 std::string Peer::getExtensionName(uint8_t id) const
 {
-  assert(_res);
-  return _res->getExtensionName(id);
+  assert(res_);
+  return res_->getExtensionName(id);
 }
 
 void Peer::setExtension(const std::string& name, uint8_t id)
 {
-  assert(_res);
-  _res->addExtension(name, id);
+  assert(res_);
+  res_->addExtension(name, id);
 }
 
 void Peer::setExtendedMessagingEnabled(bool enabled)
 {
-  assert(_res);
-  _res->extendedMessagingEnabled(enabled);
+  assert(res_);
+  res_->extendedMessagingEnabled(enabled);
 }
 
 bool Peer::isExtendedMessagingEnabled() const
 {
-  assert(_res);
-  return _res->extendedMessagingEnabled();
+  assert(res_);
+  return res_->extendedMessagingEnabled();
 }
 
 void Peer::setDHTEnabled(bool enabled)
 {
-  assert(_res);
-  _res->dhtEnabled(enabled);
+  assert(res_);
+  res_->dhtEnabled(enabled);
 }
 
 bool Peer::isDHTEnabled() const
 {
-  assert(_res);
-  return _res->dhtEnabled();
+  assert(res_);
+  return res_->dhtEnabled();
 }
 
-bool Peer::isSeeder() const
+const Timer& Peer::getLastDownloadUpdate() const
 {
-  return _seeder;
+  assert(res_);
+  return res_->getLastDownloadUpdate();
 }
 
-const Time& Peer::getFirstContactTime() const
+const Timer& Peer::getLastAmUnchoking() const
 {
-  return _firstContactTime;
-}
-
-const Time& Peer::getBadConditionStartTime() const
-{
-  return _badConditionStartTime;
-}
-
-const Time& Peer::getLastDownloadUpdate() const
-{
-  assert(_res);
-  return _res->getLastDownloadUpdate();
-}
-
-const Time& Peer::getLastAmUnchoking() const
-{
-  assert(_res);
-  return _res->getLastAmUnchoking();
+  assert(res_);
+  return res_->getLastAmUnchoking();
 }
 
 uint64_t Peer::getCompletedLength() const
 {
-  assert(_res);
-  return _res->getCompletedLength();
-}
-
-bool Peer::isIncomingPeer() const
-{
-  return _incoming;
+  assert(res_);
+  return res_->getCompletedLength();
 }
 
 void Peer::setIncomingPeer(bool incoming)
 {
-  _incoming = incoming;
+  incoming_ = incoming;
 }
 
-void Peer::setFirstContactTime(const Time& time)
+void Peer::setFirstContactTime(const Timer& time)
 {
-  _firstContactTime = time;
+  firstContactTime_ = time;
 }
 
 void Peer::setBtMessageDispatcher(const WeakHandle<BtMessageDispatcher>& dpt)
 {
-  assert(_res);
-  _res->setBtMessageDispatcher(dpt);
+  assert(res_);
+  res_->setBtMessageDispatcher(dpt);
 }
 
 size_t Peer::countOutstandingUpload() const
 {
-  assert(_res);
-  return _res->countOutstandingUpload();
+  assert(res_);
+  return res_->countOutstandingUpload();
 }
 
 } // namespace aria2
