@@ -49,6 +49,10 @@
 #include "RequestGroup.h"
 #include "DownloadContext.h"
 #include "util.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
+#include "RequestGroupMan.h"
+#include "ServerStatMan.h"
 
 namespace aria2 {
 
@@ -61,79 +65,83 @@ PeerInitiateConnectionCommand::PeerInitiateConnectionCommand
  bool mseHandshakeEnabled)
   :
   PeerAbstractCommand(cuid, peer, e),
-  _requestGroup(requestGroup),
-  _btRuntime(btRuntime),
-  _mseHandshakeEnabled(mseHandshakeEnabled)
+  requestGroup_(requestGroup),
+  btRuntime_(btRuntime),
+  mseHandshakeEnabled_(mseHandshakeEnabled)
 {
-  _btRuntime->increaseConnections();
-  _requestGroup->increaseNumCommand();
+  btRuntime_->increaseConnections();
+  requestGroup_->increaseNumCommand();
 }
 
 PeerInitiateConnectionCommand::~PeerInitiateConnectionCommand()
 {
-  _requestGroup->decreaseNumCommand();
-  _btRuntime->decreaseConnections();
+  requestGroup_->decreaseNumCommand();
+  btRuntime_->decreaseConnections();
 }
 
 bool PeerInitiateConnectionCommand::executeInternal() {
-  if(logger->info()) {
-    logger->info(MSG_CONNECTING_TO_SERVER,
-                 util::itos(cuid).c_str(), peer->ipaddr.c_str(),
-                 peer->port);
+  if(getLogger()->info()) {
+    getLogger()->info(MSG_CONNECTING_TO_SERVER,
+                      util::itos(getCuid()).c_str(),
+                      getPeer()->getIPAddress().c_str(),
+                      getPeer()->getPort());
   }
-  socket.reset(new SocketCore());
-  socket->establishConnection(peer->ipaddr, peer->port);
-  if(_mseHandshakeEnabled) {
+  createSocket();
+  getSocket()->establishConnection(getPeer()->getIPAddress(),
+                                   getPeer()->getPort());
+  if(mseHandshakeEnabled_) {
     InitiatorMSEHandshakeCommand* c =
-      new InitiatorMSEHandshakeCommand(cuid, _requestGroup, peer, e,
-                                       _btRuntime, socket);
-    c->setPeerStorage(_peerStorage);
-    c->setPieceStorage(_pieceStorage);
-    e->commands.push_back(c);
+      new InitiatorMSEHandshakeCommand(getCuid(), requestGroup_, getPeer(),
+                                       getDownloadEngine(),
+                                       btRuntime_, getSocket());
+    c->setPeerStorage(peerStorage_);
+    c->setPieceStorage(pieceStorage_);
+    getDownloadEngine()->addCommand(c);
   } else {
     PeerInteractionCommand* command =
       new PeerInteractionCommand
-      (cuid, _requestGroup, peer, e, _btRuntime, _pieceStorage, _peerStorage,
-       socket, PeerInteractionCommand::INITIATOR_SEND_HANDSHAKE);
-    e->commands.push_back(command);
+      (getCuid(), requestGroup_, getPeer(), getDownloadEngine(),
+       btRuntime_, pieceStorage_, peerStorage_,
+       getSocket(), PeerInteractionCommand::INITIATOR_SEND_HANDSHAKE);
+    getDownloadEngine()->addCommand(command);
   }
   return true;
 }
 
 // TODO this method removed when PeerBalancerCommand is implemented
 bool PeerInitiateConnectionCommand::prepareForNextPeer(time_t wait) {
-  if(_peerStorage->isPeerAvailable() && _btRuntime->lessThanEqMinPeers()) {
-    SharedHandle<Peer> peer = _peerStorage->getUnusedPeer();
-    peer->usedBy(e->newCUID());
+  if(peerStorage_->isPeerAvailable() && btRuntime_->lessThanEqMinPeers()) {
+    SharedHandle<Peer> peer = peerStorage_->getUnusedPeer();
+    peer->usedBy(getDownloadEngine()->newCUID());
     PeerInitiateConnectionCommand* command =
-      new PeerInitiateConnectionCommand(peer->usedBy(), _requestGroup, peer, e,
-                                        _btRuntime);
-    command->setPeerStorage(_peerStorage);
-    command->setPieceStorage(_pieceStorage);
-    e->commands.push_back(command);
+      new PeerInitiateConnectionCommand(peer->usedBy(), requestGroup_, peer,
+                                        getDownloadEngine(), btRuntime_);
+    command->setPeerStorage(peerStorage_);
+    command->setPieceStorage(pieceStorage_);
+    getDownloadEngine()->addCommand(command);
   }
   return true;
 }
 
 void PeerInitiateConnectionCommand::onAbort() {
-  _peerStorage->returnPeer(peer);
+  peerStorage_->returnPeer(getPeer());
 }
 
 bool PeerInitiateConnectionCommand::exitBeforeExecute()
 {
-  return _btRuntime->isHalt();
+  return btRuntime_->isHalt();
 }
 
 void PeerInitiateConnectionCommand::setPeerStorage
 (const SharedHandle<PeerStorage>& peerStorage)
 {
-  _peerStorage = peerStorage;
+  peerStorage_ = peerStorage;
 }
 
 void PeerInitiateConnectionCommand::setPieceStorage
 (const SharedHandle<PieceStorage>& pieceStorage)
 {
-  _pieceStorage = pieceStorage;
+  pieceStorage_ = pieceStorage;
 }
 
 } // namespace aria2
