@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -35,6 +35,7 @@
 #include "PeerListenCommand.h"
 
 #include <utility>
+#include <algorithm>
 
 #include "DownloadEngine.h"
 #include "Peer.h"
@@ -44,85 +45,111 @@
 #include "ReceiverMSEHandshakeCommand.h"
 #include "Logger.h"
 #include "Socket.h"
+#include "SimpleRandomizer.h"
+#include "FileEntry.h"
+#include "util.h"
+#include "ServerStatMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
 
 namespace aria2 {
 
-unsigned int PeerListenCommand::__numInstance = 0;
+unsigned int PeerListenCommand::numInstance_ = 0;
 
-PeerListenCommand* PeerListenCommand::__instance = 0;
+PeerListenCommand* PeerListenCommand::instance_ = 0;
 
-PeerListenCommand::PeerListenCommand(int32_t cuid, DownloadEngine* e):
+PeerListenCommand::PeerListenCommand(cuid_t cuid, DownloadEngine* e):
   Command(cuid),
-  e(e),
-  _lowestSpeedLimit(20*1024)
+  e_(e),
+  lowestSpeedLimit_(20*1024)
 {
-  ++__numInstance;
+  ++numInstance_;
 }
 
 PeerListenCommand::~PeerListenCommand()
 {
-  --__numInstance;
+  --numInstance_;
 }
 
 bool PeerListenCommand::bindPort(uint16_t& port, IntSequence& seq)
 {
-  socket.reset(new SocketCore());
-  while(seq.hasNext()) {
-    int sport = seq.next();
-    if(!(0 < sport && sport <= UINT16_MAX)) {
+  socket_.reset(new SocketCore());
+
+  std::vector<int32_t> randPorts = seq.flush();
+  std::random_shuffle(randPorts.begin(), randPorts.end(),
+                      *SimpleRandomizer::getInstance().get());
+  
+  for(std::vector<int32_t>::const_iterator portItr = randPorts.begin(),
+        eoi = randPorts.end(); portItr != eoi; ++portItr) {
+    if(!(0 < (*portItr) && (*portItr) <= 65535)) {
       continue;
     }
-    port = sport;
+    port = (*portItr);
     try {
-      socket->bind(port);
-      socket->beginListen();
-      socket->setNonBlockingMode();
-      logger->info(MSG_LISTENING_PORT, cuid, port);
+      socket_->bind(port);
+      socket_->beginListen();
+      socket_->setNonBlockingMode();
+      getLogger()->notice("BitTorrent: listening to port %d", port);
       return true;
     } catch(RecoverableException& ex) {
-      logger->error(MSG_BIND_FAILURE, ex, cuid, port);
-      socket->closeConnection();
+      getLogger()->error(MSG_BIND_FAILURE, ex,
+                         util::itos(getCuid()).c_str(), port);
+      socket_->closeConnection();
     }
   }
   return false;
 }
 
+uint16_t PeerListenCommand::getPort() const
+{
+  if(socket_.isNull()) {
+    return 0;
+  } else {
+    std::pair<std::string, uint16_t> addr;
+    socket_->getAddrInfo(addr);
+    return addr.second;
+  }
+}
+
 bool PeerListenCommand::execute() {
-  if(e->isHaltRequested() || e->_requestGroupMan->downloadFinished()) {
+  if(e_->isHaltRequested() || e_->getRequestGroupMan()->downloadFinished()) {
     return true;
   }
-  for(int i = 0; i < 3 && socket->isReadable(0); i++) {
+  for(int i = 0; i < 3 && socket_->isReadable(0); ++i) {
     SocketHandle peerSocket;
     try {
-      peerSocket.reset(socket->acceptConnection());
+      peerSocket.reset(socket_->acceptConnection());
       std::pair<std::string, uint16_t> peerInfo;
       peerSocket->getPeerInfo(peerInfo);
 
       peerSocket->setNonBlockingMode();
 
-      PeerHandle peer(new Peer(peerInfo.first, peerInfo.second, true));
-      int32_t cuid = e->newCUID();
+      SharedHandle<Peer> peer(new Peer(peerInfo.first, peerInfo.second, true));
+      cuid_t cuid = e_->newCUID();
       Command* command =
-	new ReceiverMSEHandshakeCommand(cuid, peer, e, peerSocket);
-      e->commands.push_back(command);
-      logger->debug("Accepted the connection from %s:%u.",
-		    peer->ipaddr.c_str(),
-		    peer->port);
-      logger->debug("Added CUID#%d to receive BitTorrent/MSE handshake.", cuid);
+        new ReceiverMSEHandshakeCommand(cuid, peer, e_, peerSocket);
+      e_->addCommand(command);
+      if(getLogger()->debug()) {
+        getLogger()->debug("Accepted the connection from %s:%u.",
+                           peer->getIPAddress().c_str(),
+                           peer->getPort());
+        getLogger()->debug("Added CUID#%s to receive BitTorrent/MSE handshake.",
+                           util::itos(cuid).c_str());
+      }
     } catch(RecoverableException& ex) {
-      logger->debug(MSG_ACCEPT_FAILURE, ex, cuid);
-    }		    
+      getLogger()->debug(MSG_ACCEPT_FAILURE, ex, util::itos(getCuid()).c_str());
+    }               
   }
-  e->commands.push_back(this);
+  e_->addCommand(this);
   return false;
 }
 
 PeerListenCommand* PeerListenCommand::getInstance(DownloadEngine* e)
 {
-  if(__numInstance == 0) {
-    __instance = new PeerListenCommand(e->newCUID(), e);
+  if(numInstance_ == 0) {
+    instance_ = new PeerListenCommand(e->newCUID(), e);
   }
-  return __instance;
+  return instance_;
 }
 
 } // namespace aria2
