@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -46,16 +46,13 @@ class Peer;
 class PeerReceiveHandshakeCommand:public PeerAbstractCommand
 {
 private:
-  SharedHandle<PeerConnection> _peerConnection;
-
-  unsigned int _thresholdSpeed;
-
+  SharedHandle<PeerConnection> peerConnection_;
 protected:
   virtual bool executeInternal();
   virtual bool exitBeforeExecute();
 public:
   PeerReceiveHandshakeCommand
-  (int32_t cuid,
+  (cuid_t cuid,
    const SharedHandle<Peer>& peer,
    DownloadEngine* e,
    const SharedHandle<SocketCore>& s,
