@@ -41,7 +41,8 @@
 #include <vector>
 
 #include "SharedHandle.h"
-#include "TimeA2.h"
+#include "TimerA2.h"
+#include "Command.h"
 
 namespace aria2 {
 
@@ -107,7 +108,7 @@ public:
    * If ignoreBitfield is set, indexes of true bit are excluded.
    */
   virtual SharedHandle<Piece> getSparseMissingUnusedPiece
-  (const unsigned char* ignoreBitfield, size_t length) = 0;
+  (size_t minSplitSize, const unsigned char* ignoreBitfield, size_t length) = 0;
 
   /**
    * Returns a missing piece whose index is index.
@@ -198,15 +199,15 @@ public:
    * Adds piece index to advertise to other commands. They send have message
    * based on this information.
    */
-  virtual void advertisePiece(int32_t cuid, size_t index) = 0;
+  virtual void advertisePiece(cuid_t cuid, size_t index) = 0;
 
   /**
    * indexes is filled with piece index which is not advertised by the caller
    * command and newer than lastCheckTime.
    */
   virtual void getAdvertisedPieceIndexes(std::vector<size_t>& indexes,
-                                         int32_t myCuid,
-                                         const Time& lastCheckTime) = 0;
+                                         cuid_t myCuid,
+                                         const Timer& lastCheckTime) = 0;
 
   /**
    * Removes have entry if specified seconds have elapsed since its
@@ -243,6 +244,10 @@ public:
                                 size_t newBitfieldLength,
                                 const unsigned char* oldBitfield) = 0;
 
+  // Returns index x where all pieces in [index+1, x-1], inclusive,
+  // are not used and not completed. If all pieces after index+1 are
+  // used or completed, returns the number of pieces.
+  virtual size_t getNextUsedIndex(size_t index) = 0;
 };
 
 typedef SharedHandle<PieceStorage> PieceStorageHandle;
