@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -35,29 +35,40 @@
 #ifndef _D_REALTIME_COMMAND_H_
 #define _D_REALTIME_COMMAND_H_
 
-#include "common.h"
-#include "RequestGroup.h"
-#include "DownloadEngine.h"
-#include "Exception.h"
-#include "RequestGroupAware.h"
+#include "Command.h"
 
-class RealtimeCommand : public Command, public RequestGroupAware {
+namespace aria2 {
+
+class RequestGroup;
+class DownloadEngine;
+class Exception;
+
+class RealtimeCommand : public Command {
+private:
+  RequestGroup* requestGroup_;
+  DownloadEngine* e_;
 protected:
-  DownloadEngine* _e;
-public:
-  RealtimeCommand(int cuid, RequestGroup* requestGroup, DownloadEngine* e):
-    Command(cuid),
-    RequestGroupAware(requestGroup),
-    _e(e)
-  {}
+  DownloadEngine* getDownloadEngine() const
+  {
+    return e_;
+  }
 
-  virtual ~RealtimeCommand() {}
+  RequestGroup* getRequestGroup() const
+  {
+    return requestGroup_;
+  }
+public:
+  RealtimeCommand(cuid_t cuid, RequestGroup* requestGroup, DownloadEngine* e);
+
+  virtual ~RealtimeCommand();
 
   virtual bool execute();
 
   virtual bool executeInternal() = 0;
 
-  virtual bool handleException(Exception* e) = 0;
+  virtual bool handleException(Exception& e) = 0;
 };
 
+} // namespace aria2
+
 #endif // _D_REALTIME_COMMAND_H_
