@@ -55,24 +55,25 @@ const std::string Request::PROTO_HTTPS("https");
 const std::string Request::PROTO_FTP("ftp");
 
 Request::Request():
-  _port(0), _tryCount(0),
-  _redirectCount(0),
-  _supportsPersistentConnection(true),
-  _keepAliveHint(false),
-  _pipeliningHint(false),
-  _maxPipelinedRequest(1),
-  _method(METHOD_GET),
-  _hasPassword(false),
-  _ipv6LiteralAddress(false)
+  port_(0), tryCount_(0),
+  redirectCount_(0),
+  supportsPersistentConnection_(true),
+  keepAliveHint_(false),
+  pipeliningHint_(false),
+  maxPipelinedRequest_(1),
+  method_(METHOD_GET),
+  hasPassword_(false),
+  ipv6LiteralAddress_(false),
+  removalRequested_(false)
 {}
 
-static std::string removeFragment(const std::string& url)
+static std::string removeFragment(const std::string& uri)
 {
-  std::string::size_type sharpIndex = url.find("#");
+  std::string::size_type sharpIndex = uri.find("#");
   if(sharpIndex == std::string::npos) {
-    return url;
+    return uri;
   } else {
-    return url.substr(0, sharpIndex);
+    return uri.substr(0, sharpIndex);
   }
 }
 
@@ -82,7 +83,7 @@ static bool isHexNumber(const char c)
     ('a' <= c && c <= 'f');
 }
 
-static std::string urlencode(const std::string& src)
+static std::string percentEncode(const std::string& src)
 {
   std::string result = src;
   if(src.empty()) {
@@ -91,7 +92,7 @@ static std::string urlencode(const std::string& src)
   result += "  ";
   for(int index = src.size()-1; index >= 0; --index) {
     const unsigned char c = result[index];
-    // '/' is not urlencoded because src is expected to be a path.
+    // '/' is not percent encoded because src is expected to be a path.
     if(!util::inRFC3986ReservedChars(c) && !util::inRFC3986UnreservedChars(c)) {
       if(c == '%') {
         if(!isHexNumber(result[index+1]) || !isHexNumber(result[index+2])) {
@@ -106,53 +107,55 @@ static std::string urlencode(const std::string& src)
   return result;
 }
 
-bool Request::setUrl(const std::string& url) {
-  _supportsPersistentConnection = true;
-  _url = url;
-  return parseUrl(urlencode(removeFragment(_url)));
+bool Request::setUri(const std::string& uri) {
+  supportsPersistentConnection_ = true;
+  uri_ = uri;
+  return parseUri(uri_);
 }
 
-bool Request::resetUrl() {
-  _previousUrl = _referer;
-  _supportsPersistentConnection = true;
-  return parseUrl(urlencode(removeFragment(_url)));
+bool Request::resetUri() {
+  previousUri_ = referer_;
+  supportsPersistentConnection_ = true;
+  return parseUri(uri_);
 }
 
-void Request::setReferer(const std::string& url)
+void Request::setReferer(const std::string& uri)
 {
-  _referer = _previousUrl = urlencode(removeFragment(url));
+  referer_ = previousUri_ = percentEncode(removeFragment(uri));
 }
 
-bool Request::redirectUrl(const std::string& url) {
-  _previousUrl = A2STR::NIL;
-  _supportsPersistentConnection = true;
-  ++_redirectCount;
-  if(url.find("://") == std::string::npos) {
+bool Request::redirectUri(const std::string& uri) {
+  supportsPersistentConnection_ = true;
+  ++redirectCount_;
+  std::string redirectedUri;
+  if(uri.find("://") == std::string::npos) {
     // rfc2616 requires absolute URI should be provided by Location header
     // field, but some servers don't obey this rule.
-    if(util::startsWith(url, "/")) {
+    if(util::startsWith(uri, "/")) {
       // abosulute path
-      return parseUrl(strconcat(_protocol, "://", _host, url));
+      redirectedUri = strconcat(protocol_, "://", host_, uri);
     } else {
       // relative path
-      return parseUrl(strconcat(_protocol, "://", _host, _dir, "/", url));
+      redirectedUri = strconcat(protocol_, "://", host_, dir_, "/", uri);
     }
   } else {
-    return parseUrl(url);
+    redirectedUri = uri;
   }
+  return parseUri(redirectedUri);
 }
 
-bool Request::parseUrl(const std::string& url) {
-  _currentUrl = url;
-  _host = A2STR::NIL;
-  _port = 0;
-  _dir = A2STR::NIL;
-  _file = A2STR::NIL;
-  _query = A2STR::NIL;
-  _username = A2STR::NIL;
-  _password = A2STR::NIL;
-  _hasPassword = false;
-  _ipv6LiteralAddress = false;
+bool Request::parseUri(const std::string& srcUri) {
+  const std::string uri = percentEncode(removeFragment(srcUri));
+  currentUri_ = uri;
+  host_ = A2STR::NIL;
+  port_ = 0;
+  dir_ = A2STR::NIL;
+  file_ = A2STR::NIL;
+  query_ = A2STR::NIL;
+  username_ = A2STR::NIL;
+  password_ = A2STR::NIL;
+  hasPassword_ = false;
+  ipv6LiteralAddress_ = false;
 
   // http://user:password@aria2.sourceforge.net:80/dir/file?query
   //        |            ||                    || |   |    |
@@ -169,21 +172,21 @@ bool Request::parseUrl(const std::string& url) {
   //                                                queryFirst
 
   // find query part
-  std::string::const_iterator queryFirst = url.begin();
-  for(; queryFirst != url.end(); ++queryFirst) {
+  std::string::const_iterator queryFirst = uri.begin();
+  for(; queryFirst != uri.end(); ++queryFirst) {
     if(*queryFirst == '?') break;
   }
-  _query = std::string(queryFirst, url.end());
+  query_ = std::string(queryFirst, uri.end());
   // find protocol
-  std::string::size_type protocolOffset = url.find("://");
+  std::string::size_type protocolOffset = uri.find("://");
   if(protocolOffset == std::string::npos) return false;
-  _protocol = std::string(url.begin(), url.begin()+protocolOffset);
+  protocol_ = std::string(uri.begin(), uri.begin()+protocolOffset);
   uint16_t defPort;
-  if((defPort = FeatureConfig::getInstance()->getDefaultPort(_protocol)) == 0) {
+  if((defPort = FeatureConfig::getInstance()->getDefaultPort(protocol_)) == 0) {
     return false;
   }
   // find authority
-  std::string::const_iterator authorityFirst = url.begin()+protocolOffset+3;
+  std::string::const_iterator authorityFirst = uri.begin()+protocolOffset+3;
   std::string::const_iterator authorityLast = authorityFirst;
   for(; authorityLast != queryFirst; ++authorityLast) {
     if(*authorityLast == '/') break;
@@ -202,12 +205,12 @@ bool Request::parseUrl(const std::string& url) {
       std::string::const_iterator userLast = authorityFirst;
       for(; userLast != userInfoLast; ++userLast) {
         if(*userLast == ':') {
-          _password = util::urldecode(std::string(userLast+1, userInfoLast));
-          _hasPassword = true;
+          password_ = util::percentDecode(std::string(userLast+1,userInfoLast));
+          hasPassword_ = true;
           break;
         }
       }
-      _username = util::urldecode(std::string(authorityFirst, userLast));
+      username_ = util::percentDecode(std::string(authorityFirst, userLast));
       break;
     }
   }
@@ -219,18 +222,18 @@ bool Request::parseUrl(const std::string& url) {
       if(*hostLast == ']') {
         ++hostLast;
         if(hostLast == authorityLast) {
-          _ipv6LiteralAddress = true;
+          ipv6LiteralAddress_ = true;
         } else {
           if(*hostLast == ':') {
             portFirst = hostLast;
             ++portFirst;
-            _ipv6LiteralAddress = true;
+            ipv6LiteralAddress_ = true;
           }
         }
         break;
       }
     }
-    if(!_ipv6LiteralAddress) {
+    if(!ipv6LiteralAddress_) {
       return false;
     }
   } else {
@@ -249,22 +252,22 @@ bool Request::parseUrl(const std::string& url) {
   if(portFirst == authorityLast) {
     // If port is not specified, then we set it to default port of
     // its protocol..
-    _port = defPort;
+    port_ = defPort;
   } else {
     uint32_t tempPort;
     if(util::parseUIntNoThrow(tempPort, std::string(portFirst, authorityLast))){
       if(65535 < tempPort) {
         return false;
       }
-      _port = tempPort;      
+      port_ = tempPort;      
     } else {
       return false;
     }
   }
-  if(_ipv6LiteralAddress) {
-    _host = std::string(hostPortFirst+1, hostLast-1);
+  if(ipv6LiteralAddress_) {
+    host_ = std::string(hostPortFirst+1, hostLast-1);
   } else {
-    _host = std::string(hostPortFirst, hostLast);
+    host_ = std::string(hostPortFirst, hostLast);
   }
   // find directory and file part
   std::string::const_iterator dirLast = authorityLast;
@@ -275,7 +278,7 @@ bool Request::parseUrl(const std::string& url) {
     }
   }
   if(dirLast != queryFirst) {
-    _file = std::string(dirLast+1, queryFirst);
+    file_ = std::string(dirLast+1, queryFirst);
   }
   // Erase duplicated slashes.
   std::string::const_iterator dirFirst = authorityLast;
@@ -292,21 +295,21 @@ bool Request::parseUrl(const std::string& url) {
     }
   }
   if(dirFirst == dirLast) {
-    _dir = A2STR::SLASH_C;
+    dir_ = A2STR::SLASH_C;
   } else {
-    _dir = std::string(dirFirst, dirLast);
+    dir_ = std::string(dirFirst, dirLast);
   }
   return true;
 }
 
 void Request::resetRedirectCount()
 {
-  _redirectCount = 0;
+  redirectCount_ = 0;
 }
   
 void Request::setMaxPipelinedRequest(unsigned int num)
 {
-  _maxPipelinedRequest = num;
+  maxPipelinedRequest_ = num;
 }
 
 const SharedHandle<PeerStat>& Request::initPeerStat()
@@ -314,9 +317,9 @@ const SharedHandle<PeerStat>& Request::initPeerStat()
   // Use host and protocol in original URI, because URI selector
   // selects URI based on original URI, not redirected one.
   Request origReq;
-  origReq.setUrl(_url);
-  _peerStat.reset(new PeerStat(0, origReq.getHost(), origReq.getProtocol()));
-  return _peerStat;
+  origReq.setUri(uri_);
+  peerStat_.reset(new PeerStat(0, origReq.getHost(), origReq.getProtocol()));
+  return peerStat_;
 }
 
 } // namespace aria2
