@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -35,24 +35,29 @@
 #include "RequestGroupEntry.h"
 #include "RequestGroup.h"
 #include "Command.h"
+#include "DownloadContext.h"
+
+namespace aria2 {
 
 RequestGroupEntry::RequestGroupEntry(RequestGroup* requestGroup,
-				     Command* nextCommand):
-  _requestGroup(requestGroup),
-  _nextCommand(nextCommand)
+                                     Command* nextCommand):
+  requestGroup_(requestGroup),
+  nextCommand_(nextCommand)
 {
-  _requestGroup->increaseNumCommand();
+  requestGroup_->increaseNumCommand();
 }
 
 RequestGroupEntry::~RequestGroupEntry()
 {
-  _requestGroup->decreaseNumCommand();
-  delete _nextCommand;
+  requestGroup_->decreaseNumCommand();
+  delete nextCommand_;
 }
 
 Command* RequestGroupEntry::popNextCommand()
 {
-  Command* temp = _nextCommand;
-  _nextCommand = 0;
+  Command* temp = nextCommand_;
+  nextCommand_ = 0;
   return temp;
 }
+
+} // namespace aria2
