@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -44,23 +44,23 @@ class RequestGroup;
 class Command;
 
 class RequestGroupEntry {
-protected:
-  RequestGroup* _requestGroup;
-  Command* _nextCommand;
+private:
+  RequestGroup* requestGroup_;
+  Command* nextCommand_;
 public:
   RequestGroupEntry(RequestGroup* requestGroup,
-		    Command* nextCommand = 0);
+                    Command* nextCommand = 0);
 
   virtual ~RequestGroupEntry();
 
   RequestGroup* getRequestGroup() const
   {
-    return _requestGroup;
+    return requestGroup_;
   }
 
   Command* getNextCommand() const
   {
-    return _nextCommand;
+    return nextCommand_;
   }
 
   Command* popNextCommand();
