@@ -67,80 +67,100 @@
 #include "Command.h"
 #include "FileEntry.h"
 #include "StringFormat.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
+#include "Segment.h"
+#include "DlAbortEx.h"
 
 namespace aria2 {
 
-RequestGroupMan::RequestGroupMan(const RequestGroups& requestGroups,
-                                 unsigned int maxSimultaneousDownloads,
-                                 const Option* option):
-  _reservedGroups(requestGroups),
-  _logger(LogFactory::getInstance()),
-  _maxSimultaneousDownloads(maxSimultaneousDownloads),
-  _gidCounter(0),
-  _option(option),
-  _serverStatMan(new ServerStatMan()),
-  _maxOverallDownloadSpeedLimit
+RequestGroupMan::RequestGroupMan
+(const std::vector<SharedHandle<RequestGroup> >& requestGroups,
+ unsigned int maxSimultaneousDownloads,
+ const Option* option):
+  reservedGroups_(requestGroups.begin(), requestGroups.end()),
+  logger_(LogFactory::getInstance()),
+  maxSimultaneousDownloads_(maxSimultaneousDownloads),
+  option_(option),
+  serverStatMan_(new ServerStatMan()),
+  maxOverallDownloadSpeedLimit_
   (option->getAsInt(PREF_MAX_OVERALL_DOWNLOAD_LIMIT)),
-  _maxOverallUploadSpeedLimit(option->getAsInt(PREF_MAX_OVERALL_UPLOAD_LIMIT)),
-  _xmlRpc(option->getAsBool(PREF_ENABLE_XML_RPC))
+  maxOverallUploadSpeedLimit_(option->getAsInt(PREF_MAX_OVERALL_UPLOAD_LIMIT)),
+  xmlRpc_(option->getAsBool(PREF_ENABLE_XML_RPC)),
+  queueCheck_(true)
 {}
 
 bool RequestGroupMan::downloadFinished()
 {
 #ifdef ENABLE_XML_RPC
-  if(_xmlRpc) {
+  if(xmlRpc_) {
     return false;
   }
 #endif // ENABLE_XML_RPC
-  return _requestGroups.empty() && _reservedGroups.empty();
+  return requestGroups_.empty() && reservedGroups_.empty();
 }
 
-void RequestGroupMan::addRequestGroup(const RequestGroupHandle& group)
+void RequestGroupMan::addRequestGroup
+(const SharedHandle<RequestGroup>& group)
 {
-  _requestGroups.push_back(group);
+  requestGroups_.push_back(group);
 }
 
-void RequestGroupMan::addReservedGroup(const RequestGroups& groups)
+void RequestGroupMan::addReservedGroup
+(const std::vector<SharedHandle<RequestGroup> >& groups)
 {
-  _reservedGroups.insert(_reservedGroups.end(), groups.begin(), groups.end());
+  if(reservedGroups_.empty()) {
+    requestQueueCheck();
+  }
+  reservedGroups_.insert(reservedGroups_.end(), groups.begin(), groups.end());
 }
 
-void RequestGroupMan::addReservedGroup(const SharedHandle<RequestGroup>& group)
+void RequestGroupMan::addReservedGroup
+(const SharedHandle<RequestGroup>& group)
 {
-  _reservedGroups.push_back(group);
+  if(reservedGroups_.empty()) {
+    requestQueueCheck();
+  }
+  reservedGroups_.push_back(group);
 }
 
 void RequestGroupMan::insertReservedGroup
-(size_t pos, const std::deque<SharedHandle<RequestGroup> >& groups)
+(size_t pos, const std::vector<SharedHandle<RequestGroup> >& groups)
 {
-  _reservedGroups.insert
-    (_reservedGroups.begin()+std::min(_reservedGroups.size(), pos),
+  if(reservedGroups_.empty()) {
+    requestQueueCheck();
+  }
+  reservedGroups_.insert
+    (reservedGroups_.begin()+std::min(reservedGroups_.size(), pos),
      groups.begin(), groups.end());
 }
 
 void RequestGroupMan::insertReservedGroup
 (size_t pos, const SharedHandle<RequestGroup>& group)
 {
-  _reservedGroups.insert
-    (_reservedGroups.begin()+std::min(_reservedGroups.size(), pos), group);
+  if(reservedGroups_.empty()) {
+    requestQueueCheck();
+  }
+  reservedGroups_.insert
+    (reservedGroups_.begin()+std::min(reservedGroups_.size(), pos), group);
 }
 
 size_t RequestGroupMan::countRequestGroup() const
 {
-  return _requestGroups.size();
+  return requestGroups_.size();
 }
 
-RequestGroupHandle RequestGroupMan::getRequestGroup(size_t index) const
+SharedHandle<RequestGroup> RequestGroupMan::getRequestGroup(size_t index) const
 {
-  if(index < _requestGroups.size()) {
-    return _requestGroups[index];
+  if(index < requestGroups_.size()) {
+    return requestGroups_[index];
   } else {
     return SharedHandle<RequestGroup>();
   }
 }
 
 template<typename Iterator>
-static Iterator findByGID(Iterator first, Iterator last, int32_t gid)
+static Iterator findByGID(Iterator first, Iterator last, gid_t gid)
 {
   for(; first != last; ++first) {
     if((*first)->getGID() == gid) {
@@ -151,11 +171,11 @@ static Iterator findByGID(Iterator first, Iterator last, int32_t gid)
 }
 
 SharedHandle<RequestGroup>
-RequestGroupMan::findRequestGroup(int32_t gid) const
+RequestGroupMan::findRequestGroup(gid_t gid) const
 {
   std::deque<SharedHandle<RequestGroup> >::const_iterator i =
-    findByGID(_requestGroups.begin(), _requestGroups.end(), gid);
-  if(i == _requestGroups.end()) {
+    findByGID(requestGroups_.begin(), requestGroups_.end(), gid);
+  if(i == requestGroups_.end()) {
     return SharedHandle<RequestGroup>();
   } else {
     return *i;
@@ -163,11 +183,11 @@ RequestGroupMan::findRequestGroup(int32_t gid) const
 }
 
 SharedHandle<RequestGroup>
-RequestGroupMan::findReservedGroup(int32_t gid) const
+RequestGroupMan::findReservedGroup(gid_t gid) const
 {
   std::deque<SharedHandle<RequestGroup> >::const_iterator i =
-    findByGID(_reservedGroups.begin(), _reservedGroups.end(), gid);
-  if(i == _reservedGroups.end()) {
+    findByGID(reservedGroups_.begin(), reservedGroups_.end(), gid);
+  if(i == reservedGroups_.end()) {
     return SharedHandle<RequestGroup>();
   } else {
     return *i;
@@ -175,16 +195,17 @@ RequestGroupMan::findReservedGroup(int32_t gid) const
 }
 
 size_t RequestGroupMan::changeReservedGroupPosition
-(int32_t gid, int pos, HOW how)
+(gid_t gid, int pos, HOW how)
 {
   std::deque<SharedHandle<RequestGroup> >::iterator i =
-    findByGID(_reservedGroups.begin(), _reservedGroups.end(), gid);
-  if(i == _reservedGroups.end()) {
+    findByGID(reservedGroups_.begin(), reservedGroups_.end(), gid);
+  if(i == reservedGroups_.end()) {
     throw DL_ABORT_EX
-      (StringFormat("GID#%d not found in the waiting queue.", gid).str());
+      (StringFormat("GID#%s not found in the waiting queue.",
+                    util::itos(gid).c_str()).str());
   }
   SharedHandle<RequestGroup> rg = *i;
-  const size_t maxPos = _reservedGroups.size()-1;
+  const size_t maxPos = reservedGroups_.size()-1;
   if(how == POS_SET) {
     if(pos < 0) {
       pos = 0;
@@ -192,12 +213,12 @@ size_t RequestGroupMan::changeReservedGroupPosition
       pos = std::min(maxPos, (size_t)pos);
     }
   } else if(how == POS_CUR) {
-    size_t abspos = std::distance(_reservedGroups.begin(), i);
+    size_t abspos = std::distance(reservedGroups_.begin(), i);
     if(pos < 0) {
-      int dist = -std::distance(_reservedGroups.begin(), i);
+      int dist = -std::distance(reservedGroups_.begin(), i);
       pos = abspos+std::max(pos, dist);
     } else if(pos > 0) {
-      int dist = std::distance(i, _reservedGroups.end())-1;
+      int dist = std::distance(i, reservedGroups_.end())-1;
       pos = abspos+std::min(pos, dist);
     } else {
       pos = abspos;
@@ -209,99 +230,46 @@ size_t RequestGroupMan::changeReservedGroupPosition
       pos = maxPos-std::min(maxPos, (size_t)-pos);
     }
   }
-  if(std::distance(_reservedGroups.begin(), i) < pos) {
-    std::rotate(i, i+1, _reservedGroups.begin()+pos+1);
+  if(std::distance(reservedGroups_.begin(), i) < pos) {
+    std::rotate(i, i+1, reservedGroups_.begin()+pos+1);
   } else {
-    std::rotate(_reservedGroups.begin()+pos, i, i+1);
+    std::rotate(reservedGroups_.begin()+pos, i, i+1);
   }
   return pos;
 }
 
-bool RequestGroupMan::removeReservedGroup(int32_t gid)
+bool RequestGroupMan::removeReservedGroup(gid_t gid)
 {
   std::deque<SharedHandle<RequestGroup> >::iterator i =
-    findByGID(_reservedGroups.begin(), _reservedGroups.end(), gid);
-  if(i == _reservedGroups.end()) {
+    findByGID(reservedGroups_.begin(), reservedGroups_.end(), gid);
+  if(i == reservedGroups_.end()) {
     return false;
   } else {
-    _reservedGroups.erase(i);
+    reservedGroups_.erase(i);
     return true;
   }
 }
 
-static void executeHook(const std::string& command, int gid)
-{
-  LogFactory::getInstance()->info("Executing user command: %s %d",
-                                  command.c_str(), gid);
-#ifndef __MINGW32__
-  pid_t cpid = fork();
-  if(cpid == -1) {
-    LogFactory::getInstance()->error("fork() failed."
-                                     " Cannot execute user command.");
-  } else if(cpid == 0) {
-    execl(command.c_str(), command.c_str(), util::itos(gid).c_str(),
-          reinterpret_cast<char*>(0));
-    perror(("Could not execute user command: "+command).c_str());
-    exit(EXIT_FAILURE);
-  }
-#else
-  PROCESS_INFORMATION pi;
-  STARTUPINFO si;
-
-  memset(&si, 0, sizeof (si));
-  si.cb = sizeof(STARTUPINFO);
-
-  memset(&pi, 0, sizeof (pi));
-
-  std::string cmdline = command;
-  strappend(cmdline, " ", util::itos(gid));
-
-  DWORD rc = CreateProcess(
-                           NULL,
-                           (LPSTR)cmdline.c_str(),
-                           NULL,
-                           NULL,
-                           true,
-                           NULL,
-                           NULL,
-                           0,
-                           &si,
-                           &pi);
-
-  if(!rc)
-    LogFactory::getInstance()->error("CreateProcess() failed."
-                                     " Cannot execute user command.");
-#endif 
-}
-
-static void executeStartHook
-(const SharedHandle<RequestGroup>& group, const Option* option)
-{
-  if(!option->blank(PREF_ON_DOWNLOAD_START)) {
-    executeHook(option->get(PREF_ON_DOWNLOAD_START), group->getGID());
-  }
-}
-
 static void executeStopHook
 (const SharedHandle<DownloadResult>& result, const Option* option)
 {
   if(result->result == downloadresultcode::FINISHED &&
      !option->blank(PREF_ON_DOWNLOAD_COMPLETE)) {
-    executeHook(option->get(PREF_ON_DOWNLOAD_COMPLETE), result->gid);
+    util::executeHook(option->get(PREF_ON_DOWNLOAD_COMPLETE), result->gid);
   } else if(result->result != downloadresultcode::IN_PROGRESS &&
             !option->blank(PREF_ON_DOWNLOAD_ERROR)) {
-    executeHook(option->get(PREF_ON_DOWNLOAD_ERROR), result->gid);
+    util::executeHook(option->get(PREF_ON_DOWNLOAD_ERROR), result->gid);
   } else if(!option->blank(PREF_ON_DOWNLOAD_STOP)) {
-    executeHook(option->get(PREF_ON_DOWNLOAD_STOP), result->gid);
+    util::executeHook(option->get(PREF_ON_DOWNLOAD_STOP), result->gid);
   }
 }
 
 class ProcessStoppedRequestGroup {
 private:
-  DownloadEngine* _e;
-  std::deque<SharedHandle<RequestGroup> >& _reservedGroups;
-  std::deque<SharedHandle<DownloadResult> >& _downloadResults;
-  Logger* _logger;
+  DownloadEngine* e_;
+  std::deque<SharedHandle<DownloadResult> >& downloadResults_;
+  std::deque<SharedHandle<RequestGroup> >& reservedGroups_;
+  Logger* logger_;
 
   void saveSignature(const SharedHandle<RequestGroup>& group)
   {
@@ -312,28 +280,40 @@ private:
       // ".sig".
       std::string signatureFile = group->getFirstFilePath()+".sig";
       if(sig->save(signatureFile)) {
-        _logger->notice(MSG_SIGNATURE_SAVED, signatureFile.c_str());
+        logger_->notice(MSG_SIGNATURE_SAVED, signatureFile.c_str());
       } else {
-        _logger->notice(MSG_SIGNATURE_NOT_SAVED, signatureFile.c_str());
+        logger_->notice(MSG_SIGNATURE_NOT_SAVED, signatureFile.c_str());
       }
     }
   }
 public:
   ProcessStoppedRequestGroup
   (DownloadEngine* e,
-   std::deque<SharedHandle<RequestGroup> >& reservedGroups,
-   std::deque<SharedHandle<DownloadResult> >& downloadResults):
-    _e(e),
-    _reservedGroups(reservedGroups),
-    _downloadResults(downloadResults),
-    _logger(LogFactory::getInstance()) {}
+   std::deque<SharedHandle<DownloadResult> >& downloadResults,
+   std::deque<SharedHandle<RequestGroup> >& reservedGroups):
+    e_(e),
+    downloadResults_(downloadResults),
+    reservedGroups_(reservedGroups),
+    logger_(LogFactory::getInstance()) {}
 
   void operator()(const SharedHandle<RequestGroup>& group)
   {
     if(group->getNumCommand() == 0) {
+      const SharedHandle<DownloadContext>& dctx = group->getDownloadContext();
+      // DownloadContext::resetDownloadStopTime() is only called when
+      // download completed. If
+      // DownloadContext::getDownloadStopTime().isZero() is true, then
+      // there is a possibility that the download is error or
+      // in-progress and resetDownloadStopTime() is not called. So
+      // call it here.
+      if(dctx->getDownloadStopTime().isZero()) {
+        dctx->resetDownloadStopTime();
+      }
       try {
         group->closeFile();
-        if(group->downloadFinished()) {
+        if(group->downloadFinished() &&
+           !group->getDownloadContext()->isChecksumVerificationNeeded()) {
+          group->setPauseRequested(false);
           group->applyLastModifiedTimeToLocalFiles();
           group->reportDownloadFinished();
           if(group->allDownloadFinished()) {
@@ -342,37 +322,47 @@ public:
           } else {
             group->saveControlFile();
           }
-          RequestGroups nextGroups;
+          std::vector<SharedHandle<RequestGroup> > nextGroups;
           group->postDownloadProcessing(nextGroups);
           if(!nextGroups.empty()) {
-            if(_logger->debug()) {
-              _logger->debug
+            if(logger_->debug()) {
+              logger_->debug
                 ("Adding %lu RequestGroups as a result of PostDownloadHandler.",
                  static_cast<unsigned long>(nextGroups.size()));
             }
-            _reservedGroups.insert(_reservedGroups.begin(),
-                                   nextGroups.begin(), nextGroups.end());
+            e_->getRequestGroupMan()->insertReservedGroup(0, nextGroups);
           }
         } else {
           group->saveControlFile();
         }
       } catch(RecoverableException& ex) {
-        _logger->error(EX_EXCEPTION_CAUGHT, ex);
+        logger_->error(EX_EXCEPTION_CAUGHT, ex);
+      }
+      if(group->isPauseRequested()) {
+        reservedGroups_.push_front(group);
+      } else {
+        downloadResults_.push_back(group->createDownloadResult());
+      }
+      group->releaseRuntimeResource(e_);
+      if(group->isPauseRequested()) {
+        group->setForceHaltRequested(false);
+        util::executeHookByOptName
+          (group, e_->getOption(), PREF_ON_DOWNLOAD_PAUSE);
+        // TODO Should we have to prepend spend uris to remaining uris
+        // in case PREF_REUSE_URI is disabed?
+      } else {
+        executeStopHook(downloadResults_.back(), e_->getOption());
       }
-      group->releaseRuntimeResource(_e);
-      _downloadResults.push_back(group->createDownloadResult());
-
-      executeStopHook(_downloadResults.back(), _e->option);
     }
   }
 };
 
 class CollectServerStat {
 private:
-  RequestGroupMan* _requestGroupMan;
+  RequestGroupMan* requestGroupMan_;
 public:
   CollectServerStat(RequestGroupMan* requestGroupMan):
-    _requestGroupMan(requestGroupMan) {}
+    requestGroupMan_(requestGroupMan) {}
 
   void operator()(const SharedHandle<RequestGroup>& group)
   {
@@ -382,10 +372,10 @@ public:
       if(!group->getSegmentMan().isNull()) {
         bool singleConnection =
           group->getSegmentMan()->getPeerStats().size() == 1;
-        const std::deque<SharedHandle<PeerStat> >& peerStats =
+        const std::vector<SharedHandle<PeerStat> >& peerStats =
           group->getSegmentMan()->getFastestPeerStats();
-        for(std::deque<SharedHandle<PeerStat> >::const_iterator i =
-              peerStats.begin(); i != peerStats.end(); ++i) {
+        for(std::vector<SharedHandle<PeerStat> >::const_iterator i =
+              peerStats.begin(), eoi = peerStats.end(); i != eoi; ++i) {
           if((*i)->getHostname().empty() || (*i)->getProtocol().empty()) {
             continue;
           }
@@ -393,7 +383,7 @@ public:
           if (speed == 0) continue;
 
           SharedHandle<ServerStat> ss =
-            _requestGroupMan->getOrCreateServerStat((*i)->getHostname(),
+            requestGroupMan_->getOrCreateServerStat((*i)->getHostname(),
                                                     (*i)->getProtocol());
           ss->increaseCounter();
           ss->updateDownloadSpeed(speed);
@@ -418,32 +408,31 @@ public:
 
 void RequestGroupMan::updateServerStat()
 {
-  std::for_each(_requestGroups.begin(), _requestGroups.end(),
+  std::for_each(requestGroups_.begin(), requestGroups_.end(),
                 CollectServerStat(this));
 }
 
 void RequestGroupMan::removeStoppedGroup(DownloadEngine* e)
 {
-  size_t numPrev = _requestGroups.size();
+  size_t numPrev = requestGroups_.size();
 
   updateServerStat();
 
-  std::for_each(_requestGroups.begin(), _requestGroups.end(),
-                ProcessStoppedRequestGroup(e, _reservedGroups,
-                                           _downloadResults));
-
+  std::for_each(requestGroups_.begin(), requestGroups_.end(),
+                ProcessStoppedRequestGroup
+                (e, downloadResults_, reservedGroups_));
   std::deque<SharedHandle<RequestGroup> >::iterator i =
-    std::remove_if(_requestGroups.begin(),
-                   _requestGroups.end(),
+    std::remove_if(requestGroups_.begin(),
+                   requestGroups_.end(),
                    FindStoppedRequestGroup());
-  if(i != _requestGroups.end()) {
-    _requestGroups.erase(i, _requestGroups.end());
+  if(i != requestGroups_.end()) {
+    requestGroups_.erase(i, requestGroups_.end());
   }
 
-  size_t numRemoved = numPrev-_requestGroups.size();
+  size_t numRemoved = numPrev-requestGroups_.size();
   if(numRemoved > 0) {
-    if(_logger->debug()) {
-      _logger->debug("%lu RequestGroup(s) deleted.",
+    if(logger_->debug()) {
+      logger_->debug("%lu RequestGroup(s) deleted.",
                      static_cast<unsigned long>(numRemoved));
     }
   }
@@ -452,22 +441,22 @@ void RequestGroupMan::removeStoppedGroup(DownloadEngine* e)
 void RequestGroupMan::configureRequestGroup
 (const SharedHandle<RequestGroup>& requestGroup) const
 {
-  const std::string& uriSelectorValue = _option->get(PREF_URI_SELECTOR);
+  const std::string& uriSelectorValue = option_->get(PREF_URI_SELECTOR);
   if(uriSelectorValue == V_FEEDBACK) {
     requestGroup->setURISelector
-      (SharedHandle<URISelector>(new FeedbackURISelector(_serverStatMan)));
+      (SharedHandle<URISelector>(new FeedbackURISelector(serverStatMan_)));
   } else if(uriSelectorValue == V_INORDER) {
     requestGroup->setURISelector
       (SharedHandle<URISelector>(new InOrderURISelector()));
   } else if(uriSelectorValue == V_ADAPTIVE) {
     requestGroup->setURISelector
-      (SharedHandle<URISelector>(new AdaptiveURISelector(_serverStatMan,
+      (SharedHandle<URISelector>(new AdaptiveURISelector(serverStatMan_,
                                                          requestGroup.get())));
   }
 }
 
 static void createInitialCommand(const SharedHandle<RequestGroup>& requestGroup,
-                                 std::deque<Command*>& commands,
+                                 std::vector<Command*>& commands,
                                  DownloadEngine* e)
 {
   requestGroup->createInitialCommand(commands, e);
@@ -476,64 +465,73 @@ static void createInitialCommand(const SharedHandle<RequestGroup>& requestGroup,
 void RequestGroupMan::fillRequestGroupFromReserver(DownloadEngine* e)
 {
   removeStoppedGroup(e);
-  if(_maxSimultaneousDownloads <= _requestGroups.size()) {
+  if(maxSimultaneousDownloads_ <= requestGroups_.size()) {
     return;
   }
-  RequestGroups temp;
+  std::vector<SharedHandle<RequestGroup> > temp;
   unsigned int count = 0;
-  size_t num = _maxSimultaneousDownloads-_requestGroups.size();
-  while(count < num && !_reservedGroups.empty()) {
-    RequestGroupHandle groupToAdd = _reservedGroups.front();
-    _reservedGroups.pop_front();
-    Commands commands;
+  size_t num = maxSimultaneousDownloads_-requestGroups_.size();
+  while(count < num && !reservedGroups_.empty()) {
+    SharedHandle<RequestGroup> groupToAdd = reservedGroups_.front();
+    reservedGroups_.pop_front();
+    std::vector<Command*> commands;
     try {
-      if(!groupToAdd->isDependencyResolved()) {
+      if(groupToAdd->isPauseRequested()||!groupToAdd->isDependencyResolved()) {
         temp.push_back(groupToAdd);
         continue;
       }
+      // Drop pieceStorage here because paused download holds its
+      // reference.
+      groupToAdd->dropPieceStorage();
       configureRequestGroup(groupToAdd);
       createInitialCommand(groupToAdd, commands, e);
-      _requestGroups.push_back(groupToAdd);
+      groupToAdd->setRequestGroupMan(this);
+      if(commands.empty()) {
+        requestQueueCheck();
+      }
+      requestGroups_.push_back(groupToAdd);
       ++count;
       e->addCommand(commands);
       commands.clear();
-      executeStartHook(groupToAdd, e->option);
+      util::executeHookByOptName
+        (groupToAdd, e->getOption(), PREF_ON_DOWNLOAD_START);
     } catch(RecoverableException& ex) {
-      _logger->error(EX_EXCEPTION_CAUGHT, ex);
-      if(_logger->debug()) {
-        _logger->debug("Deleting temporal commands.");
+      logger_->error(EX_EXCEPTION_CAUGHT, ex);
+      if(logger_->debug()) {
+        logger_->debug("Deleting temporal commands.");
       }
       std::for_each(commands.begin(), commands.end(), Deleter());
       commands.clear();
-      if(_logger->debug()) {
-        _logger->debug("Commands deleted");
+      if(logger_->debug()) {
+        logger_->debug("Commands deleted");
       }
       groupToAdd->releaseRuntimeResource(e);
-      _downloadResults.push_back(groupToAdd->createDownloadResult());
+      downloadResults_.push_back(groupToAdd->createDownloadResult());
     }
   }
   if(!temp.empty()) {
-    _reservedGroups.insert(_reservedGroups.begin(), temp.begin(), temp.end());
+    reservedGroups_.insert(reservedGroups_.begin(), temp.begin(), temp.end());
   }
   if(count > 0) {
     e->setNoWait(true);
-    if(_logger->debug()) {
-      _logger->debug("%d RequestGroup(s) added.", count);
+    if(logger_->debug()) {
+      logger_->debug("%d RequestGroup(s) added.", count);
     }
   }
 }
 
 void RequestGroupMan::save()
 {
-  for(RequestGroups::iterator itr = _requestGroups.begin();
-      itr != _requestGroups.end(); ++itr) {
-    if((*itr)->allDownloadFinished()) {
+  for(std::deque<SharedHandle<RequestGroup> >::const_iterator itr =
+        requestGroups_.begin(), eoi = requestGroups_.end(); itr != eoi; ++itr) {
+    if((*itr)->allDownloadFinished() && 
+       !(*itr)->getDownloadContext()->isChecksumVerificationNeeded()) {
       (*itr)->removeControlFile();
     } else {
       try {
         (*itr)->saveControlFile();
       } catch(RecoverableException& e) {
-        _logger->error(EX_EXCEPTION_CAUGHT, e);
+        logger_->error(EX_EXCEPTION_CAUGHT, e);
       }
     }
   }
@@ -541,8 +539,8 @@ void RequestGroupMan::save()
 
 void RequestGroupMan::closeFile()
 {
-  for(RequestGroups::iterator itr = _requestGroups.begin();
-      itr != _requestGroups.end(); ++itr) {
+  for(std::deque<SharedHandle<RequestGroup> >::const_iterator itr =
+        requestGroups_.begin(), eoi = requestGroups_.end(); itr != eoi; ++itr) {
     (*itr)->closeFile();
   }
 }
@@ -553,8 +551,9 @@ RequestGroupMan::DownloadStat RequestGroupMan::getDownloadStat() const
   size_t error = 0;
   size_t inprogress = 0;
   downloadresultcode::RESULT lastError = downloadresultcode::FINISHED;
-  for(std::deque<SharedHandle<DownloadResult> >::const_iterator itr = _downloadResults.begin();
-      itr != _downloadResults.end(); ++itr) {
+  for(std::deque<SharedHandle<DownloadResult> >::const_iterator itr =
+        downloadResults_.begin(), eoi = downloadResults_.end();
+      itr != eoi; ++itr) {
     if((*itr)->result == downloadresultcode::FINISHED) {
       ++finished;
     } else {
@@ -562,8 +561,8 @@ RequestGroupMan::DownloadStat RequestGroupMan::getDownloadStat() const
       lastError = (*itr)->result;
     }
   }
-  for(RequestGroups::const_iterator itr = _requestGroups.begin();
-      itr != _requestGroups.end(); ++itr) {
+  for(std::deque<SharedHandle<RequestGroup> >::const_iterator itr =
+        requestGroups_.begin(), eoi = requestGroups_.end(); itr != eoi; ++itr) {
     DownloadResultHandle result = (*itr)->createDownloadResult();
     if(result->result == downloadresultcode::FINISHED) {
       ++finished;
@@ -571,7 +570,7 @@ RequestGroupMan::DownloadStat RequestGroupMan::getDownloadStat() const
       ++inprogress;
     }
   }
-  return DownloadStat(finished, error, inprogress, _reservedGroups.size(),
+  return DownloadStat(finished, error, inprogress, reservedGroups_.size(),
                       lastError);
 }
 
@@ -598,8 +597,9 @@ void RequestGroupMan::showDownloadResults(std::ostream& o) const
   int err = 0;
   int inpr = 0;
 
-  for(std::deque<SharedHandle<DownloadResult> >::const_iterator itr = _downloadResults.begin();
-      itr != _downloadResults.end(); ++itr) {
+  for(std::deque<SharedHandle<DownloadResult> >::const_iterator itr =
+        downloadResults_.begin(), eoi = downloadResults_.end();
+      itr != eoi; ++itr) {
     std::string status;
     if((*itr)->result == downloadresultcode::FINISHED) {
       status = MARK_OK;
@@ -613,8 +613,8 @@ void RequestGroupMan::showDownloadResults(std::ostream& o) const
     }
     o << formatDownloadResult(status, *itr) << "\n";
   }
-  for(RequestGroups::const_iterator itr = _requestGroups.begin();
-      itr != _requestGroups.end(); ++itr) {
+  for(std::deque<SharedHandle<RequestGroup> >::const_iterator itr =
+        requestGroups_.begin(), eoi = requestGroups_.end(); itr != eoi; ++itr) {
     DownloadResultHandle result = (*itr)->createDownloadResult();
     std::string status;
     if(result->result == downloadresultcode::FINISHED) {
@@ -632,6 +632,16 @@ void RequestGroupMan::showDownloadResults(std::ostream& o) const
     }
     o << formatDownloadResult(status, result) << "\n";
   }
+  for(std::deque<SharedHandle<RequestGroup> >::const_iterator itr =
+        reservedGroups_.begin(), eoi = reservedGroups_.end();
+      itr != eoi; ++itr) {
+    if(!(*itr)->isPauseRequested()) {
+      continue;
+    }
+    SharedHandle<DownloadResult> result = (*itr)->createDownloadResult();
+    ++inpr;
+    o << formatDownloadResult(MARK_INPR, result) << "\n";
+  }
   if(ok > 0 || err > 0 || inpr > 0) {
     o << "\n"
       << _("Status Legend:") << "\n";
@@ -691,9 +701,9 @@ bool RequestGroupMan::isSameFileBeingDownloaded(RequestGroup* requestGroup) cons
   if(!requestGroup->isPreLocalFileCheckEnabled()) {
     return false;
   }
-  std::deque<std::string> files;
-  for(RequestGroups::const_iterator itr = _requestGroups.begin();
-      itr != _requestGroups.end(); ++itr) {
+  std::vector<std::string> files;
+  for(std::deque<SharedHandle<RequestGroup> >::const_iterator itr =
+        requestGroups_.begin(), eoi = requestGroups_.end(); itr != eoi; ++itr) {
     if((*itr).get() != requestGroup) {
       const std::vector<SharedHandle<FileEntry> >& entries =
         (*itr)->getDownloadContext()->getFileEntries();
@@ -711,17 +721,17 @@ bool RequestGroupMan::isSameFileBeingDownloaded(RequestGroup* requestGroup) cons
 
 void RequestGroupMan::halt()
 {
-  for(RequestGroups::const_iterator itr = _requestGroups.begin();
-      itr != _requestGroups.end(); ++itr) {
-    (*itr)->setHaltRequested(true);
+  for(std::deque<SharedHandle<RequestGroup> >::const_iterator i =
+        requestGroups_.begin(), eoi = requestGroups_.end(); i != eoi; ++i) {
+    (*i)->setHaltRequested(true);
   }
 }
 
 void RequestGroupMan::forceHalt()
 {
-  for(RequestGroups::const_iterator itr = _requestGroups.begin();
-      itr != _requestGroups.end(); ++itr) {
-    (*itr)->setForceHaltRequested(true);
+  for(std::deque<SharedHandle<RequestGroup> >::const_iterator i =
+        requestGroups_.begin(), eoi = requestGroups_.end(); i != eoi; ++i) {
+    (*i)->setForceHaltRequested(true);
   }
 }
 
@@ -729,17 +739,17 @@ TransferStat RequestGroupMan::calculateStat()
 {
   TransferStat s;
   for(std::deque<SharedHandle<RequestGroup> >::const_iterator i =
-        _requestGroups.begin(); i != _requestGroups.end(); ++i) {
+        requestGroups_.begin(), eoi = requestGroups_.end(); i != eoi; ++i) {
     s += (*i)->calculateStat();
   }
   return s;
 }
 
 SharedHandle<DownloadResult>
-RequestGroupMan::findDownloadResult(int32_t gid) const
+RequestGroupMan::findDownloadResult(gid_t gid) const
 {
   for(std::deque<SharedHandle<DownloadResult> >::const_iterator i =
-        _downloadResults.begin(); i != _downloadResults.end(); ++i) {
+        downloadResults_.begin(), eoi = downloadResults_.end(); i != eoi; ++i) {
     if((*i)->gid == gid) {
       return *i;
     }
@@ -749,14 +759,14 @@ RequestGroupMan::findDownloadResult(int32_t gid) const
 
 void RequestGroupMan::purgeDownloadResult()
 {
-  _downloadResults.clear();
+  downloadResults_.clear();
 }
 
 SharedHandle<ServerStat>
 RequestGroupMan::findServerStat(const std::string& hostname,
                                 const std::string& protocol) const
 {
-  return _serverStatMan->find(hostname, protocol);
+  return serverStatMan_->find(hostname, protocol);
 }
 
 SharedHandle<ServerStat>
@@ -773,21 +783,21 @@ RequestGroupMan::getOrCreateServerStat(const std::string& hostname,
 
 bool RequestGroupMan::addServerStat(const SharedHandle<ServerStat>& serverStat)
 {
-  return _serverStatMan->add(serverStat);
+  return serverStatMan_->add(serverStat);
 }
 
 bool RequestGroupMan::loadServerStat(const std::string& filename)
 {
   std::ifstream in(filename.c_str(), std::ios::binary);
   if(!in) {
-    _logger->error(MSG_OPENING_READABLE_SERVER_STAT_FILE_FAILED, filename.c_str());
+    logger_->error(MSG_OPENING_READABLE_SERVER_STAT_FILE_FAILED, filename.c_str());
     return false;
   }
-  if(_serverStatMan->load(in)) {
-    _logger->notice(MSG_SERVER_STAT_LOADED, filename.c_str());
+  if(serverStatMan_->load(in)) {
+    logger_->notice(MSG_SERVER_STAT_LOADED, filename.c_str());
     return true;
   } else {
-    _logger->error(MSG_READING_SERVER_STAT_FILE_FAILED, filename.c_str());
+    logger_->error(MSG_READING_SERVER_STAT_FILE_FAILED, filename.c_str());
     return false;
   }
 }
@@ -799,39 +809,68 @@ bool RequestGroupMan::saveServerStat(const std::string& filename) const
   {
     std::ofstream out(tempfile.c_str(), std::ios::binary);
     if(!out) {
-      _logger->error(MSG_OPENING_WRITABLE_SERVER_STAT_FILE_FAILED,
+      logger_->error(MSG_OPENING_WRITABLE_SERVER_STAT_FILE_FAILED,
                      filename.c_str());
       return false;
     }
-    if(!_serverStatMan->save(out)) {
-      _logger->error(MSG_WRITING_SERVER_STAT_FILE_FAILED, filename.c_str());
+    if(!serverStatMan_->save(out)) {
+      logger_->error(MSG_WRITING_SERVER_STAT_FILE_FAILED, filename.c_str());
       return false;
     }
   }
   if(File(tempfile).renameTo(filename)) {
-    _logger->notice(MSG_SERVER_STAT_SAVED, filename.c_str());
+    logger_->notice(MSG_SERVER_STAT_SAVED, filename.c_str());
     return true;
   } else {
-    _logger->error(MSG_WRITING_SERVER_STAT_FILE_FAILED, filename.c_str());
+    logger_->error(MSG_WRITING_SERVER_STAT_FILE_FAILED, filename.c_str());
     return false;
   }
 }
 
 void RequestGroupMan::removeStaleServerStat(time_t timeout)
 {
-  _serverStatMan->removeStaleServerStat(timeout);
+  serverStatMan_->removeStaleServerStat(timeout);
 }
 
 bool RequestGroupMan::doesOverallDownloadSpeedExceed()
 {
-  return _maxOverallDownloadSpeedLimit > 0 &&
-    _maxOverallDownloadSpeedLimit < calculateStat().getDownloadSpeed();
+  return maxOverallDownloadSpeedLimit_ > 0 &&
+    maxOverallDownloadSpeedLimit_ < calculateStat().getDownloadSpeed();
 }
 
 bool RequestGroupMan::doesOverallUploadSpeedExceed()
 {
-  return _maxOverallUploadSpeedLimit > 0 &&
-    _maxOverallUploadSpeedLimit < calculateStat().getUploadSpeed();
+  return maxOverallUploadSpeedLimit_ > 0 &&
+    maxOverallUploadSpeedLimit_ < calculateStat().getUploadSpeed();
+}
+
+void RequestGroupMan::getUsedHosts
+(std::vector<std::pair<size_t, std::string> >& usedHosts)
+{
+  Request r;
+  for(std::deque<SharedHandle<RequestGroup> >::const_iterator i =
+        requestGroups_.begin(), eoi = requestGroups_.end(); i != eoi; ++i) {
+    const std::deque<SharedHandle<Request> >& inFlightReqs =
+      (*i)->getDownloadContext()->getFirstFileEntry()->getInFlightRequests();
+    for(std::deque<SharedHandle<Request> >::const_iterator j =
+          inFlightReqs.begin(), eoj = inFlightReqs.end(); j != eoj; ++j) {
+      if(r.setUri((*j)->getUri())) {
+        std::vector<std::pair<size_t, std::string> >::iterator k;
+        std::vector<std::pair<size_t, std::string> >::iterator eok =
+          usedHosts.end();
+        for(k =  usedHosts.begin(); k != eok; ++k) {
+          if((*k).second == r.getHost()) {
+            ++(*k).first;
+            break;
+          }
+        }
+        if(k == eok) {
+          usedHosts.push_back(std::make_pair(1, r.getHost()));
+        }
+      }
+    }
+  }
+  std::sort(usedHosts.begin(), usedHosts.end());
 }
 
 } // namespace aria2
