@@ -44,46 +44,47 @@ namespace aria2 {
 
 class RequestSlot {
 private:
-  Timer dispatchedTime;
-  size_t index;
-  uint32_t begin;
-  size_t length;
-  size_t blockIndex;
+  Timer dispatchedTime_;
+  size_t index_;
+  uint32_t begin_;
+  size_t length_;
+  size_t blockIndex_;
 
   // This is the piece whose index is index of this RequestSlot has.
   // To detect duplicate RequestSlot, we have to find the piece using
   // PieceStorage::getPiece() repeatedly. It turns out that this process
   // takes time(about 1.7% of processing time). To reduce it, we put piece here
   // at the construction of RequestSlot as a cache.
-  SharedHandle<Piece> _piece;
+  SharedHandle<Piece> piece_;
 
   // inlined for performance reason
   void copy(const RequestSlot& requestSlot)
   {
-    dispatchedTime = requestSlot.dispatchedTime;
-    index = requestSlot.index;
-    begin = requestSlot.begin;
-    length = requestSlot.length;
-    blockIndex = requestSlot.blockIndex;
-    _piece = requestSlot._piece;
+    dispatchedTime_ = requestSlot.dispatchedTime_;
+    index_ = requestSlot.index_;
+    begin_ = requestSlot.begin_;
+    length_ = requestSlot.length_;
+    blockIndex_ = requestSlot.blockIndex_;
+    piece_ = requestSlot.piece_;
   }
 public:
   
   RequestSlot(size_t index, uint32_t begin, size_t length, size_t blockIndex,
               const SharedHandle<Piece>& piece = SharedHandle<Piece>()):
-    dispatchedTime(global::wallclock),
-    index(index), begin(begin), length(length), blockIndex(blockIndex),
-    _piece(piece) {}
+    dispatchedTime_(global::wallclock),
+    index_(index), begin_(begin), length_(length), blockIndex_(blockIndex),
+    piece_(piece) {}
 
   RequestSlot(const RequestSlot& requestSlot):
-    dispatchedTime(requestSlot.dispatchedTime),
-    index(requestSlot.index),
-    begin(requestSlot.begin),
-    length(requestSlot.length),
-    blockIndex(requestSlot.blockIndex),
-    _piece(requestSlot._piece) {}
+    dispatchedTime_(requestSlot.dispatchedTime_),
+    index_(requestSlot.index_),
+    begin_(requestSlot.begin_),
+    length_(requestSlot.length_),
+    blockIndex_(requestSlot.blockIndex_),
+    piece_(requestSlot.piece_) {}
 
-  RequestSlot():dispatchedTime(0), index(0), begin(0), length(0), blockIndex(0)
+  RequestSlot():dispatchedTime_(0), index_(0), begin_(0), length_(0),
+                blockIndex_(0)
   {}
 
   ~RequestSlot() {}
@@ -98,8 +99,8 @@ public:
 
   bool operator==(const RequestSlot& requestSlot) const
   {
-    return index == requestSlot.index && begin == requestSlot.begin
-      && length == requestSlot.length;
+    return index_ == requestSlot.index_ && begin_ == requestSlot.begin_
+      && length_ == requestSlot.length_;
   }
 
   bool operator!=(const RequestSlot& requestSlot) const
@@ -109,10 +110,10 @@ public:
   
   bool operator<(const RequestSlot& requestSlot) const
   {
-    if(index == requestSlot.index) {
-      return begin < requestSlot.begin;
+    if(index_ == requestSlot.index_) {
+      return begin_ < requestSlot.begin_;
     } else {
-      return index < requestSlot.index;
+      return index_ < requestSlot.index_;
     }
   }
 
@@ -120,21 +121,21 @@ public:
 
   bool isTimeout(time_t timeoutSec) const;
 
-  size_t getIndex() const { return index; }
-  void setIndex(size_t index) { this->index = index; }
+  size_t getIndex() const { return index_; }
+  void setIndex(size_t index) { index_ = index; }
 
-  uint32_t getBegin() const { return begin; }
-  void setBegin(uint32_t begin) { this->begin = begin; }
+  uint32_t getBegin() const { return begin_; }
+  void setBegin(uint32_t begin) { begin_ = begin; }
 
-  size_t getLength() const { return length; }
-  void setLength(size_t length) { this->length = length; }
+  size_t getLength() const { return length_; }
+  void setLength(size_t length) { length_ = length; }
 
-  size_t getBlockIndex() const { return blockIndex; }
-  void setBlockIndex(size_t blockIndex) { this->blockIndex = blockIndex; }
+  size_t getBlockIndex() const { return blockIndex_; }
+  void setBlockIndex(size_t blockIndex) { blockIndex_ = blockIndex; }
 
   const SharedHandle<Piece>& getPiece() const
   {
-    return _piece;
+    return piece_;
   }
 
   static RequestSlot nullSlot;
