@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,35 +36,42 @@
 #define _D_SEED_CHECK_COMMAND_H_
 
 #include "Command.h"
-#include "BtContextAwareCommand.h"
-#include "DownloadEngine.h"
-#include "TimeA2.h"
-#include "SeedCriteria.h"
-#include "RequestGroupAware.h"
+#include "SharedHandle.h"
 
-class SeedCheckCommand : public Command,
-			 public BtContextAwareCommand,
-			 public RequestGroupAware
+namespace aria2 {
+
+class RequestGroup;
+class DownloadEngine;
+class SeedCriteria;
+class BtRuntime;
+class PieceStorage;
+
+class SeedCheckCommand : public Command
 {
 private:
-  DownloadEngine* e;
-  Time checkPoint;
-  SeedCriteriaHandle seedCriteria;
-  bool checkStarted;
+  RequestGroup* requestGroup_;
+  DownloadEngine* e_;
+  SharedHandle<PieceStorage> pieceStorage_;
+  SharedHandle<BtRuntime> btRuntime_;
+  SharedHandle<SeedCriteria> seedCriteria_;
+  bool checkStarted_;
 public:
-  SeedCheckCommand(int cuid,
-		   RequestGroup* requestGroup,
-		   DownloadEngine* e,
-		   const BtContextHandle& btContext,
-		   SeedCriteriaHandle seedCriteria);
+  SeedCheckCommand(cuid_t cuid,
+                   RequestGroup* requestGroup,
+                   DownloadEngine* e,
+                   const SharedHandle<SeedCriteria>& seedCriteria);
 
-  virtual ~SeedCheckCommand() {}
+  virtual ~SeedCheckCommand();
 
   virtual bool execute();
 
-  void setSeedCriteria(SeedCriteriaHandle seedCriteria) {
-    this->seedCriteria = seedCriteria;
-  }
+  void setSeedCriteria(const SharedHandle<SeedCriteria>& seedCriteria);
+
+  void setBtRuntime(const SharedHandle<BtRuntime>& btRuntime);
+
+  void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage);
 };
 
+} // namespace aria2
+
 #endif // _D_SEED_CHECK_COMMAND_H_
