@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,11 +38,13 @@
 #include "common.h"
 
 #include <deque>
+#include <vector>
 #include <map>
 
 #include "SharedHandle.h"
-#include "TimeA2.h"
+#include "TimerA2.h"
 #include "Command.h"
+#include "BitfieldMan.h"
 
 namespace aria2 {
 
@@ -53,15 +55,13 @@ class PeerStat;
 class DownloadContext;
 class PieceStorage;
 class Piece;
+class FileEntry;
 
-class SegmentEntry {
-public:
+struct SegmentEntry {
   cuid_t cuid;
   SharedHandle<Segment> segment;
-public:
-  SegmentEntry(cuid_t cuid, const SharedHandle<Segment>& segment);
-
-  ~SegmentEntry();
+  SegmentEntry(cuid_t cuid, const SharedHandle<Segment>& segment):
+    cuid(cuid), segment(segment) {}
 };
 
 typedef SharedHandle<SegmentEntry> SegmentEntryHandle;
@@ -72,34 +72,43 @@ typedef std::deque<SegmentEntryHandle> SegmentEntries;
  */
 class SegmentMan {
 private:
-  const Option* _option;
+  const Option* option_;
 
-  Logger* logger;
+  Logger* logger_;
 
-  SharedHandle<DownloadContext> _downloadContext;
+  SharedHandle<DownloadContext> downloadContext_;
 
-  SharedHandle<PieceStorage> _pieceStorage;
+  SharedHandle<PieceStorage> pieceStorage_;
 
-  SegmentEntries usedSegmentEntries;
+  SegmentEntries usedSegmentEntries_;
 
-  std::deque<SharedHandle<PeerStat> > peerStats;
+  // Remember writtenLength for each segment. The key is an index of a
+  // segment. The value is writtenLength for that segment.
+  std::map<size_t, size_t> segmentWrittenLengthMemo_;
+
+  // Used for calculating download speed.
+  std::vector<SharedHandle<PeerStat> > peerStats_;
+
+  // Keep track of fastest PeerStat for each server
+  std::vector<SharedHandle<PeerStat> > fastestPeerStats_;
 
   // key: PeerStat's cuid, value: its download speed
-  std::map<cuid_t, unsigned int> _peerStatDlspdMap;
+  std::map<cuid_t, unsigned int> peerStatDlspdMap_;
 
-  Time _lastPeerStatDlspdMapUpdated;
+  Timer lastPeerStatDlspdMapUpdated_;
 
-  unsigned int _cachedDlspd;
+  unsigned int cachedDlspd_;
+
+  BitfieldMan ignoreBitfield_;
 
   SharedHandle<Segment> checkoutSegment(cuid_t cuid,
-					const SharedHandle<Piece>& piece);
+                                        const SharedHandle<Piece>& piece);
 
-  SharedHandle<SegmentEntry> findSlowerSegmentEntry
-  (const SharedHandle<PeerStat>& peerStat);
+  void cancelSegment(const SharedHandle<Segment>& segment);
 public:
   SegmentMan(const Option* option,
-	     const SharedHandle<DownloadContext>& downloadContext,
-	     const SharedHandle<PieceStorage>& pieceStorage);
+             const SharedHandle<DownloadContext>& downloadContext,
+             const SharedHandle<PieceStorage>& pieceStorage);
 
   ~SegmentMan();
 
@@ -126,10 +135,18 @@ public:
    * Fill segments which are assigned to the command whose CUID is cuid.
    * This function doesn't clear passed segments.
    */
-  void getInFlightSegment(std::deque<SharedHandle<Segment> >& segments,
-			  cuid_t cuid);
+  void getInFlightSegment(std::vector<SharedHandle<Segment> >& segments,
+                          cuid_t cuid);
 
-  SharedHandle<Segment> getSegment(cuid_t cuid);
+  SharedHandle<Segment> getSegment(cuid_t cuid, size_t minSplitSize);
+
+  // Checkouts segments in the range of fileEntry and push back to
+  // segments until segments.size() < maxSegments holds false
+  void getSegment(std::vector<SharedHandle<Segment> >& segments,
+                  cuid_t cuid,
+                  size_t minSplitSize,
+                  const SharedHandle<FileEntry>& fileEntry,
+                  size_t maxSegments);
 
   /**
    * Returns a segment whose index is index. 
@@ -137,7 +154,14 @@ public:
    * to another cuid or has been downloaded, then returns a segment instance
    * whose isNull call is true.
    */
-  SharedHandle<Segment> getSegment(cuid_t cuid, size_t index);
+  SharedHandle<Segment> getSegmentWithIndex(cuid_t cuid, size_t index);
+
+  // Returns a currently used segment whose index is index and written
+  // length is 0.  The current owner(in idle state) of segment cancels
+  // the segment and cuid command acquires the ownership of the
+  // segment.  If no such segment exists, returns null.
+  SharedHandle<Segment> getCleanSegmentIfOwnerIsIdle(cuid_t cuid, size_t index);
+
   /**
    * Updates download status.
    */
@@ -147,6 +171,13 @@ public:
    * uses.
    */
   void cancelSegment(cuid_t cuid);
+
+  void cancelSegment(cuid_t cuid, const SharedHandle<Segment>& segment);
+
+  void cancelAllSegments();
+
+  void eraseSegmentWrittenLengthMemo();
+
   /**
    * Tells SegmentMan that the segment has been downloaded successfully.
    */
@@ -171,21 +202,28 @@ public:
    */
   uint64_t getDownloadLength() const;
 
-  /**
-   * Registers given peerStat if it has not been registerd and returns true.
-   * Otherwise does nothing and returns false.
-   */
-  bool registerPeerStat(const SharedHandle<PeerStat>& peerStat);
 
-  /**
-   * Returns peerStat whose cuid is given cuid. If it is not found, returns
-   * 0.
-   */
+  // If there is inactive PeerStat in peerStats_, it is replaced with
+  // given peerStat. If no such PeerStat exist, the given peerStat is
+  // inserted.
+  void registerPeerStat(const SharedHandle<PeerStat>& peerStat);
+
+  const std::vector<SharedHandle<PeerStat> >& getPeerStats() const
+  {
+    return peerStats_;
+  }
+
   SharedHandle<PeerStat> getPeerStat(cuid_t cuid) const;
 
-  const std::deque<SharedHandle<PeerStat> >& getPeerStats() const
+  // If there is slower PeerStat than given peerStat for the same
+  // hostname and protocol in fastestPeerStats_, the former is
+  // replaced with latter. If there are no PeerStat with same hostname
+  // and protocol with given peerStat, given peerStat is inserted.
+  void updateFastestPeerStat(const SharedHandle<PeerStat>& peerStat);
+
+  const std::vector<SharedHandle<PeerStat> >& getFastestPeerStats() const
   {
-    return peerStats;
+    return fastestPeerStats_;
   }
 
   /**
@@ -201,9 +239,15 @@ public:
   uint64_t calculateSessionDownloadLength() const;
 
   size_t countFreePieceFrom(size_t index) const;
-};
 
-typedef SharedHandle<SegmentMan> SegmentManHandle;
+  // Excludes segments that fileEntry covers from segment selection.
+  void ignoreSegmentFor(const SharedHandle<FileEntry>& fileEntry);
+
+  // Includes segments that fileEntry covers in segment selection.
+  void recognizeSegmentFor(const SharedHandle<FileEntry>& fileEntry);
+
+  bool allSegmentsIgnored() const;
+};
 
 } // namespace aria2
 
