@@ -35,7 +35,7 @@
 #ifndef _D_SEQUENCE_H_
 #define _D_SEQUENCE_H_
 
-#include <deque>
+#include <vector>
 
 namespace aria2 {
 
@@ -43,54 +43,55 @@ template<typename T>
 class Sequence
 {
 public:
-  // Generates value in [_first, _last). _last is not included.
+  // Generates value in [first_, last_). last_ is not included.
   class Value {
   private:
-    T _first;
-    T _last;
+    T first_;
+    T last_;
   public:
-    Value(const T& first, const T& last):_first(first), _last(last) {}
+    Value(const T& first, const T& last):first_(first), last_(last) {}
 
     T next()
     {
-      return _first++;
+      return first_++;
     }
     
     bool hasNext() const
     {
-      return _first != _last;
+      return first_ != last_;
     }
   };
 
-  typedef std::deque<Value> Values;
+  typedef std::vector<Value> Values;
 private:
-  Values _values;
+  Values values_;
+  typename Values::iterator cur_;
 public:
   Sequence(const Values& values):
-    _values(values) {}
+    values_(values), cur_(values_.begin())  {}
 
   Sequence() {}
 
   T next()
   {
-    if(_values.empty()) {
+    if(cur_ == values_.end()) {
       return T();
     }
-    T t = _values.front().next();
-    if(!_values.front().hasNext()) {
-      _values.pop_front();
+    T t = (*cur_).next();
+    if(!(*cur_).hasNext()) {
+      ++cur_;
     }
     return t;
   }
 
   bool hasNext()
   {
-    return !_values.empty();
+    return cur_ != values_.end();
   }
 
-  std::deque<T> flush()
+  std::vector<T> flush()
   {
-    std::deque<T> r;
+    std::vector<T> r;
     while(hasNext()) {
       r.push_back(next());
     }
