@@ -43,11 +43,9 @@ class SimpleBtMessage : public AbstractBtMessage {
 public:
   SimpleBtMessage(uint8_t id, const std::string& name);
 
-  virtual ~SimpleBtMessage();
-
   virtual void send();
 
-  virtual const unsigned char* getMessage() = 0;
+  virtual unsigned char* createMessage() = 0;
 
   virtual size_t getMessageLength() = 0;
 
