@@ -36,7 +36,7 @@
 #define _D_SLEEP_COMMAND_H_
 
 #include "Command.h"
-#include "TimeA2.h"
+#include "TimerA2.h"
 
 namespace aria2 {
 
@@ -45,13 +45,13 @@ class RequestGroup;
 
 class SleepCommand:public Command {
 private:
-  DownloadEngine* engine;
-  RequestGroup* _requestGroup;
-  Command* nextCommand;
-  time_t wait;
-  Time checkPoint;
+  DownloadEngine* engine_;
+  RequestGroup* requestGroup_;
+  Command* nextCommand_;
+  time_t wait_;
+  Timer checkPoint_;
 public:
-  SleepCommand(int32_t cuid, DownloadEngine* e, RequestGroup* requestGroup,
+  SleepCommand(cuid_t cuid, DownloadEngine* e, RequestGroup* requestGroup,
                Command* nextCommand, time_t wait);
   virtual ~SleepCommand();
   bool execute();
