@@ -36,20 +36,20 @@
 #define _D_SPEED_CALC_H_
 
 #include "common.h"
-#include "TimeA2.h"
+#include "TimerA2.h"
 
 namespace aria2 {
 
 class SpeedCalc {
 private:
-  uint64_t lengthArray[2];
-  int sw;
-  Time cpArray[2];
-  unsigned int maxSpeed;
-  unsigned int prevSpeed;
-  Time start;
-  uint64_t accumulatedLength;
-  time_t nextInterval;
+  uint64_t lengthArray_[2];
+  int sw_;
+  Timer cpArray_[2];
+  unsigned int maxSpeed_;
+  unsigned int prevSpeed_;
+  Timer start_;
+  uint64_t accumulatedLength_;
+  time_t nextInterval_;
 
   bool isIntervalOver() const;
 
@@ -65,7 +65,7 @@ public:
   unsigned int calculateSpeed();
 
   unsigned int getMaxSpeed() const {
-    return maxSpeed;
+    return maxSpeed_;
   }
 
   unsigned int calculateAvgSpeed() const;
