@@ -38,27 +38,39 @@
 #include "Logger.h"
 #include "message.h"
 #include "FileEntry.h"
+#include "ServerStatMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
 
 namespace aria2 {
 
-TimedHaltCommand::TimedHaltCommand(int32_t cuid, DownloadEngine* e,
-                                   time_t secondsToHalt):
-  TimeBasedCommand(cuid, e, secondsToHalt, true) {}
+TimedHaltCommand::TimedHaltCommand(cuid_t cuid, DownloadEngine* e,
+                                   time_t secondsToHalt,
+                                   bool forceHalt):
+  TimeBasedCommand(cuid, e, secondsToHalt, true),
+  forceHalt_(forceHalt) {}
 
 TimedHaltCommand::~TimedHaltCommand() {}
 
 void TimedHaltCommand::preProcess()
 {
-  if(_e->_requestGroupMan->downloadFinished() || _e->isHaltRequested()) {
-    _exit = true;
+  if(getDownloadEngine()->getRequestGroupMan()->downloadFinished() ||
+     getDownloadEngine()->isHaltRequested()) {
+    enableExit();
   }
 }
 
 void TimedHaltCommand::process()
 {
-  if(!_e->isHaltRequested()) {
-    logger->notice(MSG_TIME_HAS_PASSED, _interval);
-    _e->requestHalt();
+  if(!getDownloadEngine()->isHaltRequested()) {
+    getLogger()->notice(MSG_TIME_HAS_PASSED, getInterval());
+    if(forceHalt_) {
+      getLogger()->notice("This is emergency shutdown.");
+      getDownloadEngine()->requestForceHalt();
+    } else {
+      getDownloadEngine()->requestHalt();
+    }
+    enableExit();
   }
 }
 
