@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,42 +36,65 @@
 #define _D_TRACKER_WATCHER_COMMAND_H_
 
 #include "Command.h"
-#include "BtContextAwareCommand.h"
-#include "RequestGroupAware.h"
+#include "SharedHandle.h"
+
+namespace aria2 {
 
 class DownloadEngine;
 class RequestGroup;
-typedef SharedHandle<RequestGroup> RequestGroupHandle;
+class PeerStorage;
+class PieceStorage;
+class BtRuntime;
+class BtAnnounce;
+class Option;
 
-class TrackerWatcherCommand : public Command,
-			      public BtContextAwareCommand,
-			      public RequestGroupAware
+class TrackerWatcherCommand : public Command
 {
 private:
-  DownloadEngine* e;
+  RequestGroup* requestGroup_;
 
-  RequestGroupHandle _trackerRequestGroup;
+  DownloadEngine* e_;
+
+  SharedHandle<PeerStorage> peerStorage_;
+
+  SharedHandle<PieceStorage> pieceStorage_;
+
+  SharedHandle<BtRuntime> btRuntime_;
+
+  SharedHandle<BtAnnounce> btAnnounce_;
+
+  SharedHandle<RequestGroup> trackerRequestGroup_;
   /**
    * Returns a command for announce request. Returns 0 if no announce request
    * is needed.
    */
-  RequestGroupHandle createRequestGroup(const string& url);
+  SharedHandle<RequestGroup> createRequestGroup(const std::string& url);
 
-  string getTrackerResponse(const RequestGroupHandle& requestGroup);
+  std::string getTrackerResponse(const SharedHandle<RequestGroup>& requestGroup);
 
-  void processTrackerResponse(const string& response);
+  void processTrackerResponse(const std::string& response);
 
+  const SharedHandle<Option>& getOption() const;
 public:
-  TrackerWatcherCommand(int32_t cuid,
-			RequestGroup* requestGroup,
-			DownloadEngine* e,
-			const BtContextHandle& btContext);
+  TrackerWatcherCommand(cuid_t cuid,
+                        RequestGroup* requestGroup,
+                        DownloadEngine* e);
 
   virtual ~TrackerWatcherCommand();
 
-  RequestGroupHandle createAnnounce();
+  SharedHandle<RequestGroup> createAnnounce();
 
   virtual bool execute();
+
+  void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage);
+
+  void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage);
+
+  void setBtRuntime(const SharedHandle<BtRuntime>& btRuntime);
+
+  void setBtAnnounce(const SharedHandle<BtAnnounce>& btAnnounce);
 };
 
+} // namespace aria2
+
 #endif // _D_TRACKER_WATCHER_COMMAND_H_
