@@ -37,47 +37,50 @@
 #include "util.h"
 #include "bittorrent_helper.h"
 #include "PeerStorage.h"
-#include "PeerListProcessor.h"
 #include "DlAbortEx.h"
 #include "message.h"
 #include "StringFormat.h"
-#include "bencode.h"
+#include "bencode2.h"
 #include "a2functional.h"
+#include "wallclock.h"
 
 namespace aria2 {
 
 const std::string UTPexExtensionMessage::EXTENSION_NAME = "ut_pex";
 
 UTPexExtensionMessage::UTPexExtensionMessage(uint8_t extensionMessageID):
-  _extensionMessageID(extensionMessageID),
-  _interval(DEFAULT_INTERVAL),
-  _maxFreshPeer(DEFAULT_MAX_FRESH_PEER),
-  _maxDroppedPeer(DEFAULT_MAX_DROPPED_PEER) {}
+  extensionMessageID_(extensionMessageID),
+  interval_(DEFAULT_INTERVAL),
+  maxFreshPeer_(DEFAULT_MAX_FRESH_PEER),
+  maxDroppedPeer_(DEFAULT_MAX_DROPPED_PEER) {}
 
 UTPexExtensionMessage::~UTPexExtensionMessage() {}
 
 std::string UTPexExtensionMessage::getPayload()
 {
   std::pair<std::string, std::string> freshPeerPair =
-    createCompactPeerListAndFlag(_freshPeers);
+    createCompactPeerListAndFlag(freshPeers_);
   std::pair<std::string, std::string> droppedPeerPair =
-    createCompactPeerListAndFlag(_droppedPeers);
+    createCompactPeerListAndFlag(droppedPeers_);
 
-  BDE dict = BDE::dict();
-  dict["added"] = freshPeerPair.first;
-  dict["added.f"] = freshPeerPair.second;
-  dict["dropped"] = droppedPeerPair.first;
-  return bencode::encode(dict);
+  Dict dict;
+  dict.put("added", freshPeerPair.first);
+  dict.put("added.f", freshPeerPair.second);
+  dict.put("dropped", droppedPeerPair.first);
+  return bencode2::encode(&dict);
 }
 
 std::pair<std::string, std::string>
-UTPexExtensionMessage::createCompactPeerListAndFlag(const Peers& peers)
+UTPexExtensionMessage::createCompactPeerListAndFlag
+(const std::vector<SharedHandle<Peer> >& peers)
 {
   std::string addrstring;
   std::string flagstring;
-  for(Peers::const_iterator itr = peers.begin(); itr != peers.end(); ++itr) {
+  for(std::vector<SharedHandle<Peer> >::const_iterator itr = peers.begin(),
+        eoi = peers.end(); itr != eoi; ++itr) {
     unsigned char compact[6];
-    if(bittorrent::createcompact(compact, (*itr)->ipaddr, (*itr)->port)) {
+    if(bittorrent::createcompact
+       (compact, (*itr)->getIPAddress(), (*itr)->getPort())) {
       addrstring.append(&compact[0], &compact[6]);
       flagstring += (*itr)->isSeeder() ? "2" : "0";
     }
@@ -87,20 +90,20 @@ UTPexExtensionMessage::createCompactPeerListAndFlag(const Peers& peers)
 
 std::string UTPexExtensionMessage::toString() const
 {
-  return strconcat("ut_pex added=", util::uitos(_freshPeers.size()),
-                   ", dropped=", util::uitos(_droppedPeers.size()));
+  return strconcat("ut_pex added=", util::uitos(freshPeers_.size()),
+                   ", dropped=", util::uitos(droppedPeers_.size()));
 }
 
 void UTPexExtensionMessage::doReceivedAction()
 {
-  _peerStorage->addPeer(_freshPeers);
+  peerStorage_->addPeer(freshPeers_);
 }
 
-bool UTPexExtensionMessage::addFreshPeer(const PeerHandle& peer)
+bool UTPexExtensionMessage::addFreshPeer(const SharedHandle<Peer>& peer)
 {
   if(!peer->isIncomingPeer() &&
-     !peer->getFirstContactTime().elapsed(_interval)) {
-    _freshPeers.push_back(peer);
+     peer->getFirstContactTime().difference(global::wallclock) < interval_) {
+    freshPeers_.push_back(peer);
     return true;
   } else {
     return false;
@@ -109,14 +112,15 @@ bool UTPexExtensionMessage::addFreshPeer(const PeerHandle& peer)
 
 bool UTPexExtensionMessage::freshPeersAreFull() const
 {
-  return _freshPeers.size() >= _maxFreshPeer;
+  return freshPeers_.size() >= maxFreshPeer_;
 }
 
-bool UTPexExtensionMessage::addDroppedPeer(const PeerHandle& peer)
+bool UTPexExtensionMessage::addDroppedPeer(const SharedHandle<Peer>& peer)
 {
   if(!peer->isIncomingPeer() &&
-     !peer->getBadConditionStartTime().elapsed(_interval)) {
-    _droppedPeers.push_back(peer);
+     peer->getBadConditionStartTime().
+     difference(global::wallclock) < interval_) {
+    droppedPeers_.push_back(peer);
     return true;
   } else {
     return false;
@@ -125,23 +129,23 @@ bool UTPexExtensionMessage::addDroppedPeer(const PeerHandle& peer)
 
 bool UTPexExtensionMessage::droppedPeersAreFull() const
 {
-  return _droppedPeers.size() >= _maxDroppedPeer;
+  return droppedPeers_.size() >= maxDroppedPeer_;
 }
 
 void UTPexExtensionMessage::setMaxFreshPeer(size_t maxFreshPeer)
 {
-  _maxFreshPeer = maxFreshPeer;
+  maxFreshPeer_ = maxFreshPeer;
 }
 
 void UTPexExtensionMessage::setMaxDroppedPeer(size_t maxDroppedPeer)
 {
-  _maxDroppedPeer = maxDroppedPeer;
+  maxDroppedPeer_ = maxDroppedPeer;
 }
 
 void UTPexExtensionMessage::setPeerStorage
 (const SharedHandle<PeerStorage>& peerStorage)
 {
-  _peerStorage = peerStorage;
+  peerStorage_ = peerStorage;
 }
 
 UTPexExtensionMessageHandle
@@ -153,17 +157,16 @@ UTPexExtensionMessage::create(const unsigned char* data, size_t len)
   }
   UTPexExtensionMessageHandle msg(new UTPexExtensionMessage(*data));
 
-  const BDE dict = bencode::decode(data+1, len-1);
-  if(dict.isDict()) {
-    PeerListProcessor proc;
-    const BDE& added = dict["added"];
-    if(added.isString()) {
-      proc.extractPeerFromCompact(added, std::back_inserter(msg->_freshPeers));
+  SharedHandle<ValueBase> decoded = bencode2::decode(data+1, len-1);
+  const Dict* dict = asDict(decoded);
+  if(dict) {
+    const String* added = asString(dict->get("added"));
+    if(added) {
+      bittorrent::extractPeer(added, std::back_inserter(msg->freshPeers_));
     }
-    const BDE& dropped = dict["dropped"];
-    if(dropped.isString()) {
-      proc.extractPeerFromCompact(dropped,
-                                  std::back_inserter(msg->_droppedPeers));
+    const String* dropped = asString(dict->get("dropped"));
+    if(dropped) {
+      bittorrent::extractPeer(dropped, std::back_inserter(msg->droppedPeers_));
     }
   }
   return msg;
