@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -46,22 +46,22 @@ class DirectDiskAdaptor;
 
 class UnknownLengthPieceStorage:public PieceStorage {
 private:
-  SharedHandle<DownloadContext> _downloadContext;
+  SharedHandle<DownloadContext> downloadContext_;
 
-  const Option* _option;
+  const Option* option_;
   
-  SharedHandle<DirectDiskAdaptor> _diskAdaptor;
+  SharedHandle<DirectDiskAdaptor> diskAdaptor_;
 
-  SharedHandle<DiskWriterFactory> _diskWriterFactory;
+  SharedHandle<DiskWriterFactory> diskWriterFactory_;
 
-  uint64_t _totalLength;
+  uint64_t totalLength_;
 
-  bool _downloadFinished;
+  bool downloadFinished_;
 
-  SharedHandle<Piece> _piece;
+  SharedHandle<Piece> piece_;
 public:
   UnknownLengthPieceStorage(const SharedHandle<DownloadContext>& downloadContext,
-			    const Option* option);
+                            const Option* option);
 
   virtual ~UnknownLengthPieceStorage();
 
@@ -82,7 +82,7 @@ public:
   virtual SharedHandle<Piece> getMissingPiece(const SharedHandle<Peer>& peer);
 
   virtual SharedHandle<Piece> getMissingPiece
-  (const SharedHandle<Peer>& peer, const std::deque<size_t>& excludedIndexes);
+  (const SharedHandle<Peer>& peer, const std::vector<size_t>& excludedIndexes);
 
   /**
    * Returns a piece that the peer has but localhost doesn't.
@@ -94,7 +94,7 @@ public:
   virtual SharedHandle<Piece> getMissingFastPiece(const SharedHandle<Peer>& peer);
 
   virtual SharedHandle<Piece> getMissingFastPiece
-  (const SharedHandle<Peer>& peer, const std::deque<size_t>& excludedIndexes);
+  (const SharedHandle<Peer>& peer, const std::vector<size_t>& excludedIndexes);
 
 #endif // ENABLE_BITTORRENT
 
@@ -104,7 +104,7 @@ public:
    * Returns a missing piece if available. Otherwise returns 0;
    */
   virtual SharedHandle<Piece> getSparseMissingUnusedPiece
-  (const unsigned char* ignoreBitfield, size_t length);
+  (size_t minSplitSize, const unsigned char* ignoreBitfield, size_t length);
 
   /**
    * Returns a missing piece whose index is index.
@@ -140,18 +140,18 @@ public:
 
   virtual uint64_t getTotalLength()
   {
-    return _totalLength;
+    return totalLength_;
   }
 
   virtual uint64_t getFilteredTotalLength()
   {
-    return _totalLength;
+    return totalLength_;
   }
 
   virtual uint64_t getCompletedLength()
   {
     // TODO we have to return actual completed length here?
-    return _totalLength;
+    return totalLength_;
   }
 
   virtual uint64_t getFilteredCompletedLength()
@@ -170,7 +170,7 @@ public:
    */
   virtual bool downloadFinished()
   {
-    return _downloadFinished;
+    return downloadFinished_;
   }
 
   /**
@@ -194,7 +194,7 @@ public:
   }
 
   virtual void setBitfield(const unsigned char* bitfield,
-			   size_t bitfieldLength) {}
+                           size_t bitfieldLength) {}
   
   virtual size_t getBitfieldLength()
   {
@@ -221,15 +221,15 @@ public:
    * Adds piece index to advertise to other commands. They send have message
    * based on this information.
    */
-  virtual void advertisePiece(int32_t cuid, size_t index) {}
+  virtual void advertisePiece(cuid_t cuid, size_t index) {}
 
   /**
    * Returns piece index which is not advertised by the caller command and
    * newer than lastCheckTime.
    */
   virtual void
-  getAdvertisedPieceIndexes(std::deque<size_t>& indexes,
-			    int32_t myCuid, const Time& lastCheckTime)
+  getAdvertisedPieceIndexes(std::vector<size_t>& indexes,
+                            cuid_t myCuid, const Timer& lastCheckTime)
   {}
 
   /**
@@ -251,27 +251,29 @@ public:
    * Do nothing because loading in-flight piece is not supported for this
    * class.
    */
-  virtual void addInFlightPiece(const std::deque<SharedHandle<Piece> >& pieces) {}
+  virtual void addInFlightPiece
+  (const std::vector<SharedHandle<Piece> >& pieces) {}
 
   virtual size_t countInFlightPiece()
   {
     return 0;
   }
 
-  virtual void getInFlightPieces(std::deque<SharedHandle<Piece> >& pieces);
+  virtual void getInFlightPieces(std::vector<SharedHandle<Piece> >& pieces);
 
   virtual void addPieceStats(size_t index) {}
 
   virtual void addPieceStats(const unsigned char* bitfield,
-			     size_t bitfieldLength) {}
+                             size_t bitfieldLength) {}
 
   virtual void subtractPieceStats(const unsigned char* bitfield,
-				  size_t bitfieldLength) {}
+                                  size_t bitfieldLength) {}
 
   virtual void updatePieceStats(const unsigned char* newBitfield,
-				size_t newBitfieldLength,
-				const unsigned char* oldBitfield) {}
+                                size_t newBitfieldLength,
+                                const unsigned char* oldBitfield) {}
 
+  virtual size_t getNextUsedIndex(size_t index) { return 0; }
 
   void setDiskWriterFactory(const SharedHandle<DiskWriterFactory>& diskWriterFactory);
 };
