@@ -34,7 +34,6 @@
 /* copyright --> */
 #include "XmlRpcMethod.h"
 #include "DownloadEngine.h"
-#include "BDE.h"
 #include "LogFactory.h"
 #include "RecoverableException.h"
 #include "message.h"
@@ -47,20 +46,27 @@
 #include "XmlRpcResponse.h"
 #include "prefs.h"
 #include "StringFormat.h"
+#include "RequestGroupMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
+#include "ServerStatMan.h"
+#include "FileEntry.h"
+#include "DlAbortEx.h"
 
 namespace aria2 {
 
 namespace xmlrpc {
 
 XmlRpcMethod::XmlRpcMethod():
-  _optionParser(OptionParser::getInstance()),
-  _logger(LogFactory::getInstance()) {}
+  optionParser_(OptionParser::getInstance()),
+  logger_(LogFactory::getInstance()) {}
 
-BDE XmlRpcMethod::createErrorResponse(const Exception& e)
+SharedHandle<ValueBase> XmlRpcMethod::createErrorResponse
+(const Exception& e)
 {
-  BDE params = BDE::dict();
-  params["faultCode"] = BDE(1);
-  params["faultString"] = BDE(e.what());
+  SharedHandle<Dict> params = Dict::g();
+  params->put("faultCode", Integer::g(1));
+  params->put("faultString", std::string(e.what()));
   return params;
 }
 
@@ -70,7 +76,9 @@ XmlRpcResponse XmlRpcMethod::execute
   try {
     return XmlRpcResponse(0, process(req, e));
   } catch(RecoverableException& e) {
-    _logger->debug(EX_EXCEPTION_CAUGHT, e);
+    if(logger_->debug()) {
+      logger_->debug(EX_EXCEPTION_CAUGHT, e);
+    }
     return XmlRpcResponse(1, createErrorResponse(e));
   }
 }
@@ -78,16 +86,17 @@ XmlRpcResponse XmlRpcMethod::execute
 template<typename InputIterator>
 static void gatherOption
 (InputIterator first, InputIterator last,
- const std::set<std::string>& changeableOptions,
+ const std::set<std::string>& allowedOptions,
  const SharedHandle<Option>& option,
  const SharedHandle<OptionParser>& optionParser)
 {
   for(; first != last; ++first) {
     const std::string& optionName = (*first).first;
-    if(changeableOptions.count(optionName) == 0) {
+    if(allowedOptions.count(optionName) == 0) {
       throw DL_ABORT_EX
         (StringFormat
-         ("%s cannot be changed or unknown option.", optionName.c_str()).str());
+         ("%s option cannot be used in this context.",
+          optionName.c_str()).str());
     } else {
       SharedHandle<OptionHandler> optionHandler =
         optionParser->findByName(optionName);
@@ -97,29 +106,35 @@ static void gatherOption
            ("We don't know how to deal with %s option",
             optionName.c_str()).str());
       }
-      // header and index-out option can take array as value
-      const BDE& value = (*first).second;
-      if((optionName == PREF_HEADER || optionName == PREF_INDEX_OUT) &&
-         value.isList()){
-        for(BDE::List::const_iterator argiter = value.listBegin();
-            argiter != value.listEnd(); ++argiter) {
-          if((*argiter).isString()) {
-            optionHandler->parse(*option.get(), (*argiter).s());
+      const String* opval = asString((*first).second);
+      if(opval) {
+        optionHandler->parse(*option.get(), opval->s());
+      } else {
+        // header and index-out option can take array as value
+        const List* oplist = asList((*first).second);
+        if(oplist &&
+           (optionName == PREF_HEADER || optionName == PREF_INDEX_OUT)) {
+          for(List::ValueType::const_iterator argiter = oplist->begin(),
+                eoi = oplist->end(); argiter != eoi; ++argiter) {
+            const String* opval = asString(*argiter);
+            if(opval) {
+              optionHandler->parse(*option.get(), opval->s());
+            }
           }
         }
-      } else if(value.isString()) {
-        optionHandler->parse(*option.get(), value.s());
       }
     }
   }  
 }
 
 void XmlRpcMethod::gatherRequestOption
-(const SharedHandle<Option>& option, const BDE& optionsDict)
+(const SharedHandle<Option>& option, const Dict* optionsDict)
 {
-  gatherOption(optionsDict.dictBegin(), optionsDict.dictEnd(),
-               listRequestOptions(),
-               option, _optionParser);
+  if(optionsDict) {
+    gatherOption(optionsDict->begin(), optionsDict->end(),
+                 listRequestOptions(),
+                 option, optionParser_);
+  }
 }
 
 // Copy option in the range [optNameFirst, optNameLast) from src to
@@ -145,17 +160,18 @@ const std::set<std::string>& listChangeableOptions()
     PREF_MAX_DOWNLOAD_LIMIT,
     PREF_MAX_UPLOAD_LIMIT
   };
-  static std::set<std::string> options
-    (&OPTIONS[0], &OPTIONS[arrayLength(OPTIONS)]);
+  static std::set<std::string> options(vbegin(OPTIONS), vend(OPTIONS));
   return options;
 }
 
 void XmlRpcMethod::gatherChangeableOption
-(const SharedHandle<Option>& option, const BDE& optionsDict)
+(const SharedHandle<Option>& option, const Dict* optionsDict)
 {
-  gatherOption(optionsDict.dictBegin(), optionsDict.dictEnd(),
-               listChangeableOptions(),
-               option, _optionParser);
+  if(optionsDict) {
+    gatherOption(optionsDict->begin(), optionsDict->end(),
+                 listChangeableOptions(),
+                 option, optionParser_);
+  }
 }
 
 void XmlRpcMethod::applyChangeableOption(Option* dest, Option* src) const
@@ -170,18 +186,21 @@ const std::set<std::string>& listChangeableGlobalOptions()
     PREF_MAX_OVERALL_UPLOAD_LIMIT,
     PREF_MAX_OVERALL_DOWNLOAD_LIMIT,
     PREF_MAX_CONCURRENT_DOWNLOADS,
+    PREF_LOG,
+    PREF_LOG_LEVEL
   };
-  static std::set<std::string> options
-    (&OPTIONS[0], &OPTIONS[arrayLength(OPTIONS)]);
+  static std::set<std::string> options(vbegin(OPTIONS), vend(OPTIONS));
   return options;
 }
 
 void XmlRpcMethod::gatherChangeableGlobalOption
-(const SharedHandle<Option>& option, const BDE& optionsDict)
+(const SharedHandle<Option>& option, const Dict* optionsDict)
 {
-  gatherOption(optionsDict.dictBegin(), optionsDict.dictEnd(),
-               listChangeableGlobalOptions(),
-               option, _optionParser);
+  if(optionsDict) {
+    gatherOption(optionsDict->begin(), optionsDict->end(),
+                 listChangeableGlobalOptions(),
+                 option, optionParser_);
+  }
 }
 
 void XmlRpcMethod::applyChangeableGlobalOption(Option* dest, Option* src) const
