@@ -150,6 +150,9 @@ const std::string PREF_MAX_FILE_NOT_FOUND("max-file-not-found");
 // value: epoll | select
 const std::string PREF_EVENT_POLL("event-poll");
 const std::string V_EPOLL("epoll");
+const std::string V_KQUEUE("kqueue");
+const std::string V_PORT("port");
+const std::string V_POLL("poll");
 const std::string V_SELECT("select");
 // value: 1*digit
 const std::string PREF_XML_RPC_LISTEN_PORT("xml-rpc-listen-port");
@@ -167,6 +170,7 @@ const std::string PREF_XML_RPC_PASSWD("xml-rpc-passwd");
 const std::string PREF_XML_RPC_MAX_REQUEST_SIZE("xml-rpc-max-request-size");
 // value: string
 const std::string PREF_ON_DOWNLOAD_START("on-download-start");
+const std::string PREF_ON_DOWNLOAD_PAUSE("on-download-pause");
 const std::string PREF_ON_DOWNLOAD_STOP("on-download-stop");
 const std::string PREF_ON_DOWNLOAD_COMPLETE("on-download-complete");
 const std::string PREF_ON_DOWNLOAD_ERROR("on-download-error");
@@ -178,6 +182,22 @@ const std::string PREF_INTERFACE("interface");
 const std::string PREF_DISABLE_IPV6("disable-ipv6");
 // value: true | false
 const std::string PREF_HUMAN_READABLE("human-readable");
+// value: true | false
+const std::string PREF_REMOVE_CONTROL_FILE("remove-control-file");
+// value: true | false
+const std::string PREF_ALWAYS_RESUME("always-resume");
+// value: 1*digit
+const std::string PREF_MAX_RESUME_FAILURE_TRIES("max-resume-failure-tries");
+// value: string that your file system recognizes as a file name.
+const std::string PREF_SAVE_SESSION("save-session");
+// value: 1*digit
+const std::string PREF_MAX_CONNECTION_PER_SERVER("max-connection-per-server");
+// value: 1*digit
+const std::string PREF_MIN_SPLIT_SIZE("min-split-size");
+// value: true | false
+const std::string PREF_CONDITIONAL_GET("conditional-get");
+// value: true | false
+const std::string PREF_SELECT_LEAST_USED_HOST("select-least-used-host");
 
 /**
  * FTP related preferences
@@ -226,6 +246,8 @@ const std::string PREF_USE_HEAD("use-head");
 const std::string PREF_HTTP_AUTH_CHALLENGE("http-auth-challenge");
 // value: true | false
 const std::string PREF_HTTP_NO_CACHE("http-no-cache");
+// value: true | false
+const std::string PREF_HTTP_ACCEPT_GZIP("http-accept-gzip");
 
 /** 
  * Proxy related preferences
@@ -240,6 +262,14 @@ const std::string PREF_NO_PROXY("no-proxy");
 const std::string PREF_PROXY_METHOD("proxy-method");
 const std::string V_GET("get");
 const std::string V_TUNNEL("tunnel");
+const std::string PREF_HTTP_PROXY_USER("http-proxy-user");
+const std::string PREF_HTTP_PROXY_PASSWD("http-proxy-passwd");
+const std::string PREF_HTTPS_PROXY_USER("https-proxy-user");
+const std::string PREF_HTTPS_PROXY_PASSWD("https-proxy-passwd");
+const std::string PREF_FTP_PROXY_USER("ftp-proxy-user");
+const std::string PREF_FTP_PROXY_PASSWD("ftp-proxy-passwd");
+const std::string PREF_ALL_PROXY_USER("all-proxy-user");
+const std::string PREF_ALL_PROXY_PASSWD("all-proxy-passwd");
 
 /**
  * BitTorrent related preferences
@@ -316,6 +346,18 @@ const std::string PREF_BT_PRIORITIZE_PIECE("bt-prioritize-piece");
 const std::string PREF_BT_SAVE_METADATA("bt-save-metadata");
 // values: true | false
 const std::string PREF_BT_METADATA_ONLY("bt-metadata-only");
+// values: true | false
+const std::string PREF_BT_ENABLE_LPD("bt-enable-lpd");
+// values: string
+const std::string PREF_BT_LPD_INTERFACE("bt-lpd-interface");
+// values: 1*digit
+const std::string PREF_BT_TRACKER_TIMEOUT("bt-tracker-timeout");
+// values: 1*digit
+const std::string PREF_BT_TRACKER_CONNECT_TIMEOUT("bt-tracker-connect-timeout");
+// values: 1*digit
+const std::string PREF_DHT_MESSAGE_TIMEOUT("dht-message-timeout");
+// values: string
+const std::string PREF_ON_BT_DOWNLOAD_COMPLETE("on-bt-download-complete");
 
 /**
  * Metalink related preferences
