@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -154,6 +154,9 @@ extern const std::string PREF_MAX_FILE_NOT_FOUND;
 // value: epoll | select
 extern const std::string PREF_EVENT_POLL;
 extern const std::string V_EPOLL;
+extern const std::string V_KQUEUE;
+extern const std::string V_PORT;
+extern const std::string V_POLL;
 extern const std::string V_SELECT;
 // value: 1*digit
 extern const std::string PREF_XML_RPC_LISTEN_PORT;
@@ -171,6 +174,7 @@ extern const std::string PREF_XML_RPC_PASSWD;
 extern const std::string PREF_XML_RPC_MAX_REQUEST_SIZE;
 // value: string
 extern const std::string PREF_ON_DOWNLOAD_START;
+extern const std::string PREF_ON_DOWNLOAD_PAUSE;
 extern const std::string PREF_ON_DOWNLOAD_STOP;
 extern const std::string PREF_ON_DOWNLOAD_COMPLETE;
 extern const std::string PREF_ON_DOWNLOAD_ERROR;
@@ -180,6 +184,24 @@ extern const std::string PREF_XML_RPC_LISTEN_ALL;
 extern const std::string PREF_INTERFACE;
 // value: true | false
 extern const std::string PREF_DISABLE_IPV6;
+// value: true | false
+extern const std::string PREF_HUMAN_READABLE;
+// value: true | false
+extern const std::string PREF_REMOVE_CONTROL_FILE;
+// value: true | false
+extern const std::string PREF_ALWAYS_RESUME;
+// value: 1*digit
+extern const std::string PREF_MAX_RESUME_FAILURE_TRIES;
+// value: string that your file system recognizes as a file name.
+extern const std::string PREF_SAVE_SESSION;
+// value: 1*digit
+extern const std::string PREF_MAX_CONNECTION_PER_SERVER;
+// value: 1*digit
+extern const std::string PREF_MIN_SPLIT_SIZE;
+// value: true | false
+extern const std::string PREF_CONDITIONAL_GET;
+// value: true | false
+extern const std::string PREF_SELECT_LEAST_USED_HOST;
 
 /**
  * FTP related preferences
@@ -226,6 +248,10 @@ extern const std::string PREF_CHECK_CERTIFICATE;
 extern const std::string PREF_USE_HEAD;
 // value: true | false
 extern const std::string PREF_HTTP_AUTH_CHALLENGE;
+// value: true | false
+extern const std::string PREF_HTTP_NO_CACHE;
+// value: true | false
+extern const std::string PREF_HTTP_ACCEPT_GZIP;
 
 /**;
  * Proxy related preferences
@@ -240,6 +266,14 @@ extern const std::string PREF_NO_PROXY;
 extern const std::string PREF_PROXY_METHOD;
 extern const std::string V_GET;
 extern const std::string V_TUNNEL;
+extern const std::string PREF_HTTP_PROXY_USER;
+extern const std::string PREF_HTTP_PROXY_PASSWD;
+extern const std::string PREF_HTTPS_PROXY_USER;
+extern const std::string PREF_HTTPS_PROXY_PASSWD;
+extern const std::string PREF_FTP_PROXY_USER;
+extern const std::string PREF_FTP_PROXY_PASSWD;
+extern const std::string PREF_ALL_PROXY_USER;
+extern const std::string PREF_ALL_PROXY_PASSWD;
 
 /**
  * BitTorrent related preferences
@@ -314,6 +348,20 @@ extern const std::string PREF_BT_STOP_TIMEOUT;
 extern const std::string PREF_BT_PRIORITIZE_PIECE;
 // values: true | false
 extern const std::string PREF_BT_SAVE_METADATA;
+// values: true | false
+extern const std::string PREF_BT_METADATA_ONLY;
+// values: true | false
+extern const std::string PREF_BT_ENABLE_LPD;
+// values: string
+extern const std::string PREF_BT_LPD_INTERFACE;
+// values: 1*digit
+extern const std::string PREF_BT_TRACKER_TIMEOUT;
+// values: 1*digit
+extern const std::string PREF_BT_TRACKER_CONNECT_TIMEOUT;
+// values: 1*digit
+extern const std::string PREF_DHT_MESSAGE_TIMEOUT;
+// values: string
+extern const std::string PREF_ON_BT_DOWNLOAD_COMPLETE;
 
 /**
  * Metalink related preferences
