@@ -78,6 +78,8 @@
 #include "bitfield.h"
 #include "DownloadHandlerConstants.h"
 #include "RequestGroup.h"
+#include "LogFactory.h"
+#include "Option.h"
 #ifdef ENABLE_MESSAGE_DIGEST
 # include "MessageDigestHelper.h"
 #endif // ENABLE_MESSAGE_DIGEST
@@ -396,7 +398,7 @@ std::string fromHex(const std::string& src)
   if(src.size()%2) {
     return dest;
   }
-  for(size_t i = 0; i < src.size(); i += 2) {
+  for(size_t i = 0, eoi = src.size(); i < eoi; i += 2) {
     unsigned char high = hexCharToUInt(src[i]);
     unsigned char low = hexCharToUInt(src[i+1]);
     if(high == 255 || low == 255) {
@@ -679,11 +681,50 @@ std::string iso8859ToUtf8(const std::string& src)
   return dest;
 }
 
+template<typename OutputIterator>
+static void parseParam(OutputIterator out, const std::string& header)
+{
+  for(std::string::const_iterator i = header.begin(), eoi = header.end();
+      i != eoi;) {
+    std::string::const_iterator paramFirst = i;
+    std::string::const_iterator paramLast = paramFirst;
+    for(; paramLast != eoi && *paramLast != '=' && *paramLast != ';';
+        ++paramLast);
+    std::string param;
+    if(paramLast == eoi || *paramLast == ';') {
+      // No value, parmname only
+      param = std::string(paramFirst, paramLast);
+    } else {
+      for(; paramLast != eoi && *paramLast != '"' && *paramLast != ';';
+          ++paramLast);
+      if(paramLast != eoi && *paramLast == '"') {
+        // quoted-string
+        ++paramLast;
+        for(; paramLast != eoi && *paramLast != '"'; ++paramLast);
+        if(paramLast != eoi) {
+          ++paramLast;
+        }
+        param = std::string(paramFirst, paramLast);
+        for(; paramLast != eoi && *paramLast != ';'; ++paramLast);
+      } else {
+        param = std::string(paramFirst, paramLast);
+      }
+    }
+    trimSelf(param);
+    *out++ = param;
+    if(paramLast == eoi) {
+      break;
+    }
+    i = paramLast;
+    ++i;
+  }
+}
+
 std::string getContentDispositionFilename(const std::string& header)
 {
   std::string filename;
   std::vector<std::string> params;
-  split(header, std::back_inserter(params), A2STR::SEMICOLON_C, true);
+  parseParam(std::back_inserter(params), header);
   for(std::vector<std::string>::const_iterator i = params.begin(),
         eoi = params.end(); i != eoi; ++i) {
     const std::string& param = *i;
@@ -964,7 +1005,7 @@ bool isLowercase(const std::string& what)
   if(what.empty()) {
     return false;
   }
-  for(uint32_t i = 0; i < what.size(); ++i) {
+  for(uint32_t i = 0, eoi = what.size(); i < eoi; ++i) {
     if(!('a' <= what[i] && what[i] <= 'z')) {
       return false;
     }
@@ -977,7 +1018,7 @@ bool isUppercase(const std::string& what)
   if(what.empty()) {
     return false;
   }
-  for(uint32_t i = 0; i < what.size(); ++i) {
+  for(uint32_t i = 0, eoi = what.size(); i < eoi; ++i) {
     if(!('A' <= what[i] && what[i] <= 'Z')) {
       return false;
     }
@@ -997,7 +1038,7 @@ unsigned int alphaToNum(const std::string& alphabets)
     base = 'A';
   }
   uint64_t num = 0;
-  for(size_t i = 0; i < alphabets.size(); ++i) {
+  for(size_t i = 0, eoi = alphabets.size(); i < eoi; ++i) {
     unsigned int v = alphabets[i]-base;
     num = num*26+v;
     if(num > UINT32_MAX) {
@@ -1233,13 +1274,13 @@ bool detectDirTraversal(const std::string& s)
 namespace {
 class EscapePath {
 private:
-  char _repChar;
+  char repChar_;
 public:
-  EscapePath(const char& repChar):_repChar(repChar) {}
+  EscapePath(const char& repChar):repChar_(repChar) {}
 
   char operator()(const char& c) {
     if(0x00 <= c && c <=0x1f) {
-      return _repChar;
+      return repChar_;
     }
 #ifdef __MINGW32__
     // We don't escape '/' because we use it as a path separator.
@@ -1247,7 +1288,7 @@ public:
       { '"', '*', ':', '<', '>', '?', '\\', '|' };
     if(std::find(vbegin(WIN_INVALID_PATH_CHARS), vend(WIN_INVALID_PATH_CHARS),
                  c) != vend(WIN_INVALID_PATH_CHARS)) {
-      return _repChar;
+      return repChar_;
     }
 #endif // __MINGW32__
     return c;
@@ -1305,6 +1346,66 @@ void removeMetalinkContentTypes(const SharedHandle<RequestGroup>& group)
   }
 }
 
+void executeHook(const std::string& command, gid_t gid)
+{
+  LogFactory::getInstance()->info("Executing user command: %s %s",
+                                  command.c_str(), util::itos(gid).c_str());
+#ifndef __MINGW32__
+  pid_t cpid = fork();
+  if(cpid == -1) {
+    LogFactory::getInstance()->error("fork() failed."
+                                     " Cannot execute user command.");
+  } else if(cpid == 0) {
+    execl(command.c_str(), command.c_str(), util::itos(gid).c_str(),
+          reinterpret_cast<char*>(0));
+    perror(("Could not execute user command: "+command).c_str());
+    exit(EXIT_FAILURE);
+  }
+#else
+  PROCESS_INFORMATION pi;
+  STARTUPINFO si;
+
+  memset(&si, 0, sizeof (si));
+  si.cb = sizeof(STARTUPINFO);
+
+  memset(&pi, 0, sizeof (pi));
+
+  std::string cmdline = command;
+  strappend(cmdline, " ", util::itos(gid));
+
+  DWORD rc = CreateProcess(
+                           NULL,
+                           (LPSTR)cmdline.c_str(),
+                           NULL,
+                           NULL,
+                           true,
+                           NULL,
+                           NULL,
+                           0,
+                           &si,
+                           &pi);
+
+  if(!rc)
+    LogFactory::getInstance()->error("CreateProcess() failed."
+                                     " Cannot execute user command.");
+#endif 
+}
+
+void executeHookByOptName
+(const SharedHandle<RequestGroup>& group, const Option* option,
+ const std::string& opt)
+{
+  executeHookByOptName(group.get(), option, opt);
+}
+
+void executeHookByOptName
+(const RequestGroup* group, const Option* option, const std::string& opt)
+{
+  if(!option->blank(opt)) {
+    executeHook(option->get(opt), group->getGID());
+  }
+}
+
 } // namespace util
 
 } // namespace aria2
