@@ -14,7 +14,7 @@
 #include "array_fun.h"
 #include "messageDigest.h"
 #include "a2netcompat.h"
-#include "bencode.h"
+#include "bencode2.h"
 #include "TestUtil.h"
 #include "base32.h"
 
@@ -63,6 +63,8 @@ class BittorrentHelperTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testParseMagnet_base32);
   CPPUNIT_TEST(testMetadata2Torrent);
   CPPUNIT_TEST(testTorrent2Magnet);
+  CPPUNIT_TEST(testExtractPeerFromList);
+  CPPUNIT_TEST(testExtract2PeersFromList);
   CPPUNIT_TEST_SUITE_END();
 public:
   void setUp() {
@@ -106,31 +108,13 @@ public:
   void testParseMagnet_base32();
   void testMetadata2Torrent();
   void testTorrent2Magnet();
+  void testExtractPeerFromList();
+  void testExtract2PeersFromList();
 };
 
 
 CPPUNIT_TEST_SUITE_REGISTRATION(BittorrentHelperTest);
 
-static const BDE& getAnnounceList(const SharedHandle<DownloadContext>& dctx)
-{
-  return dctx->getAttribute(BITTORRENT)[ANNOUNCE_LIST];
-}
-
-static const std::string& getMode(const SharedHandle<DownloadContext>& dctx)
-{
-  return dctx->getAttribute(BITTORRENT)[MODE].s();
-}
-
-static const std::string& getName(const SharedHandle<DownloadContext>& dctx)
-{
-  return dctx->getAttribute(BITTORRENT)[NAME].s();
-}
-
-static const BDE& getNodes(const SharedHandle<DownloadContext>& dctx)
-{
-  return dctx->getAttribute(BITTORRENT)[NODES];
-}
-
 void BittorrentHelperTest::testGetInfoHash() {
   SharedHandle<DownloadContext> dctx(new DownloadContext());
   load("test.torrent", dctx);
@@ -210,21 +194,21 @@ void BittorrentHelperTest::testGetFileModeMulti() {
   SharedHandle<DownloadContext> dctx(new DownloadContext());
   load("test.torrent", dctx);
 
-  CPPUNIT_ASSERT_EQUAL(MULTI, getMode(dctx));
+  CPPUNIT_ASSERT_EQUAL(MULTI, getTorrentAttrs(dctx)->mode);
 }
 
 void BittorrentHelperTest::testGetFileModeSingle() {
   SharedHandle<DownloadContext> dctx(new DownloadContext());
   load("single.torrent", dctx);
 
-  CPPUNIT_ASSERT_EQUAL(SINGLE, getMode(dctx));
+  CPPUNIT_ASSERT_EQUAL(SINGLE, getTorrentAttrs(dctx)->mode);
 }
 
 void BittorrentHelperTest::testGetNameMulti() {
   SharedHandle<DownloadContext> dctx(new DownloadContext());
   load("test.torrent", dctx);
 
-  CPPUNIT_ASSERT_EQUAL(std::string("aria2-test"), getName(dctx));
+  CPPUNIT_ASSERT_EQUAL(std::string("aria2-test"), getTorrentAttrs(dctx)->name);
 }
 
 void BittorrentHelperTest::testGetNameSingle() {
@@ -233,7 +217,8 @@ void BittorrentHelperTest::testGetNameSingle() {
 
   CPPUNIT_ASSERT_EQUAL(std::string("./aria2-0.8.2.tar.bz2"),
                        dctx->getBasePath());
-  CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.8.2.tar.bz2"), getName(dctx));
+  CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.8.2.tar.bz2"),
+                       getTorrentAttrs(dctx)->name);
 }
 
 void BittorrentHelperTest::testOverrideName()
@@ -242,46 +227,41 @@ void BittorrentHelperTest::testOverrideName()
   load("test.torrent", dctx, "aria2-override.name");
   CPPUNIT_ASSERT_EQUAL(std::string("./aria2-override.name"),
                        dctx->getBasePath());
-  CPPUNIT_ASSERT_EQUAL(std::string("aria2-override.name"), getName(dctx));
+  CPPUNIT_ASSERT_EQUAL(std::string("aria2-override.name"),
+                       getTorrentAttrs(dctx)->name);
 }
 
 
 void BittorrentHelperTest::testGetAnnounceTier() {
   SharedHandle<DownloadContext> dctx(new DownloadContext());
   load("single.torrent", dctx);
-
-  const BDE& announceList = getAnnounceList(dctx);
-  
+  SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
   // There is 1 tier.
-  CPPUNIT_ASSERT_EQUAL((size_t)1, announceList.size());
+  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->announceList.size());
 
-  const BDE& tier = announceList[0]; 
-  CPPUNIT_ASSERT_EQUAL((size_t)1, tier.size());
+  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->announceList[0].size());
   CPPUNIT_ASSERT_EQUAL(std::string("http://aria.rednoah.com/announce.php"),
-                       tier[0].s());
-
+                       attrs->announceList[0][0]);
 }
 
 void BittorrentHelperTest::testGetAnnounceTierAnnounceList() {
   SharedHandle<DownloadContext> dctx(new DownloadContext());
   load("test.torrent", dctx);
-
-  const BDE& announceList = getAnnounceList(dctx);
-  
+  SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
   // There are 3 tiers.
-  CPPUNIT_ASSERT_EQUAL((size_t)3, announceList.size());
+  CPPUNIT_ASSERT_EQUAL((size_t)3, attrs->announceList.size());
 
-  const BDE& tier1 = announceList[0];
-  CPPUNIT_ASSERT_EQUAL((size_t)1, tier1.size());
-  CPPUNIT_ASSERT_EQUAL(std::string("http://tracker1"), tier1[0].s());
+  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->announceList[0].size());
+  CPPUNIT_ASSERT_EQUAL(std::string("http://tracker1"),
+                       attrs->announceList[0][0]);
 
-  const BDE& tier2 = announceList[1];
-  CPPUNIT_ASSERT_EQUAL((size_t)1, tier2.size());
-  CPPUNIT_ASSERT_EQUAL(std::string("http://tracker2"), tier2[0].s());
+  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->announceList[1].size());
+  CPPUNIT_ASSERT_EQUAL(std::string("http://tracker2"),
+                       attrs->announceList[1][0]);
 
-  const BDE& tier3 = announceList[2];
-  CPPUNIT_ASSERT_EQUAL((size_t)1, tier3.size());
-  CPPUNIT_ASSERT_EQUAL(std::string("http://tracker3"), tier3[0].s());
+  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->announceList[2].size());
+  CPPUNIT_ASSERT_EQUAL(std::string("http://tracker3"),
+                       attrs->announceList[2][0]);
 }
 
 void BittorrentHelperTest::testGetPieceLength() {
@@ -317,7 +297,7 @@ void BittorrentHelperTest::testComputeFastSet()
     std::vector<size_t> fastSet;
     computeFastSet(fastSet, ipaddr, numPieces, infoHash, fastSetSize);
     size_t ans[] = { 686, 459, 278, 200, 404, 834, 64, 203, 760, 950 };
-    std::vector<size_t> ansSet(&ans[0], &ans[arrayLength(ans)]);
+    std::vector<size_t> ansSet(vbegin(ans), vend(ans));
     CPPUNIT_ASSERT(std::equal(fastSet.begin(), fastSet.end(), ansSet.begin()));
   }
   ipaddr = "10.0.0.1";
@@ -325,7 +305,7 @@ void BittorrentHelperTest::testComputeFastSet()
     std::vector<size_t> fastSet;
     computeFastSet(fastSet, ipaddr, numPieces, infoHash, fastSetSize);
     size_t ans[] = { 568, 188, 466, 452, 550, 662, 109, 226, 398, 11 };
-    std::vector<size_t> ansSet(&ans[0], &ans[arrayLength(ans)]);
+    std::vector<size_t> ansSet(vbegin(ans), vend(ans));
     CPPUNIT_ASSERT(std::equal(fastSet.begin(), fastSet.end(), ansSet.begin()));
   }
   // See when pieces < fastSetSize
@@ -334,7 +314,7 @@ void BittorrentHelperTest::testComputeFastSet()
     std::vector<size_t> fastSet;
     computeFastSet(fastSet, ipaddr, numPieces, infoHash, fastSetSize);
     size_t ans[] = { 8, 6, 7, 5, 1, 4, 0, 2, 3 };
-    std::vector<size_t> ansSet(&ans[0], &ans[arrayLength(ans)]);
+    std::vector<size_t> ansSet(vbegin(ans), vend(ans));
     CPPUNIT_ASSERT(std::equal(fastSet.begin(), fastSet.end(), ansSet.begin()));
   }
 }
@@ -351,24 +331,24 @@ void BittorrentHelperTest::testGetFileEntries_multiFileUrlList() {
     fileEntries.begin();
 
   const SharedHandle<FileEntry>& fileEntry1 = *itr;
-  CPPUNIT_ASSERT_EQUAL(std::string("./aria2-test/aria2/src/aria2c"),
+  CPPUNIT_ASSERT_EQUAL(std::string("./aria2-test@/aria2@/src@/aria2c@"),
                        fileEntry1->getPath());
   const std::deque<std::string>& uris1 = fileEntry1->getRemainingUris();
   CPPUNIT_ASSERT_EQUAL((size_t)2, uris1.size());
-  CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/dist/aria2-test/aria2/src/aria2c"),
+  CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/dist/aria2-test%40/aria2%40/src%40/aria2c%40"),
                        uris1[0]);
-  CPPUNIT_ASSERT_EQUAL(std::string("http://mirror/dist/aria2-test/aria2/src/aria2c"),
+  CPPUNIT_ASSERT_EQUAL(std::string("http://mirror/dist/aria2-test%40/aria2%40/src%40/aria2c%40"),
                        uris1[1]);
 
   ++itr;
   const SharedHandle<FileEntry>& fileEntry2 = *itr;
-  CPPUNIT_ASSERT_EQUAL(std::string("./aria2-test/aria2-0.2.2.tar.bz2"),
+  CPPUNIT_ASSERT_EQUAL(std::string("./aria2-test@/aria2-0.2.2.tar.bz2"),
                        fileEntry2->getPath());
   const std::deque<std::string>& uris2 = fileEntry2->getRemainingUris();
   CPPUNIT_ASSERT_EQUAL((size_t)2, uris2.size());
-  CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/dist/aria2-test/aria2-0.2.2.tar.bz2"),
+  CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/dist/aria2-test%40/aria2-0.2.2.tar.bz2"),
                        uris2[0]);
-  CPPUNIT_ASSERT_EQUAL(std::string("http://mirror/dist/aria2-test/aria2-0.2.2.tar.bz2"),
+  CPPUNIT_ASSERT_EQUAL(std::string("http://mirror/dist/aria2-test%40/aria2-0.2.2.tar.bz2"),
                        uris2[1]);
 }
 
@@ -400,11 +380,11 @@ void BittorrentHelperTest::testGetFileEntries_singleFileUrlListEndsWithSlash() {
   CPPUNIT_ASSERT_EQUAL((size_t)1, fileEntries.size());
 
   const SharedHandle<FileEntry>& fileEntry1 = fileEntries.front();
-  CPPUNIT_ASSERT_EQUAL(std::string("./aria2.tar.bz2"),
+  CPPUNIT_ASSERT_EQUAL(std::string("./aria2@.tar.bz2"),
                        fileEntry1->getPath());
   const std::deque<std::string>& uris1 = fileEntry1->getRemainingUris();
   CPPUNIT_ASSERT_EQUAL((size_t)1, uris1.size());
-  CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/dist/aria2.tar.bz2"),
+  CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/dist/aria2%40.tar.bz2"),
                        uris1[0]);
 }
 
@@ -440,7 +420,8 @@ void BittorrentHelperTest::testLoadFromMemory_overrideName()
   SharedHandle<DownloadContext> dctx(new DownloadContext());
   loadFromMemory(memory, dctx, "default", "aria2-override.name");
 
-  CPPUNIT_ASSERT_EQUAL(std::string("aria2-override.name"), getName(dctx));
+  CPPUNIT_ASSERT_EQUAL(std::string("aria2-override.name"),
+                       getTorrentAttrs(dctx)->name);
 }
 
 void BittorrentHelperTest::testLoadFromMemory_multiFileDirTraversal()
@@ -486,12 +467,12 @@ void BittorrentHelperTest::testGetNodes()
     SharedHandle<DownloadContext> dctx(new DownloadContext());
     loadFromMemory(memory, dctx, "default");
 
-    const BDE& nodes = getNodes(dctx);
-    CPPUNIT_ASSERT_EQUAL((size_t)2, nodes.size());
-    CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"), nodes[0][HOSTNAME].s());
-    CPPUNIT_ASSERT_EQUAL((uint16_t)6881, (uint16_t)nodes[0][PORT].i());
-    CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), nodes[1][HOSTNAME].s());
-    CPPUNIT_ASSERT_EQUAL((uint16_t)6882, (uint16_t)nodes[1][PORT].i());
+    SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+    CPPUNIT_ASSERT_EQUAL((size_t)2, attrs->nodes.size());
+    CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"), attrs->nodes[0].first);
+    CPPUNIT_ASSERT_EQUAL((uint16_t)6881, attrs->nodes[0].second);
+    CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), attrs->nodes[1].first);
+    CPPUNIT_ASSERT_EQUAL((uint16_t)6882, attrs->nodes[1].second);
   }
   {
     // empty hostname
@@ -506,10 +487,10 @@ void BittorrentHelperTest::testGetNodes()
     SharedHandle<DownloadContext> dctx(new DownloadContext());
     loadFromMemory(memory, dctx, "default");
 
-    const BDE& nodes = getNodes(dctx);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, nodes.size());
-    CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), nodes[0][HOSTNAME].s());
-    CPPUNIT_ASSERT_EQUAL((uint16_t)6882, (uint16_t)nodes[0][PORT].i());
+    SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+    CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->nodes.size());
+    CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), attrs->nodes[0].first);
+    CPPUNIT_ASSERT_EQUAL((uint16_t)6882, attrs->nodes[0].second);
   }
   {
     // bad port 
@@ -524,10 +505,10 @@ void BittorrentHelperTest::testGetNodes()
     SharedHandle<DownloadContext> dctx(new DownloadContext());
     loadFromMemory(memory, dctx, "default");
 
-    const BDE& nodes = getNodes(dctx);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, nodes.size());
-    CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), nodes[0][HOSTNAME].s());
-    CPPUNIT_ASSERT_EQUAL((uint16_t)6882, (uint16_t)nodes[0][PORT].i());
+    SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+    CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->nodes.size());
+    CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), attrs->nodes[0].first);
+    CPPUNIT_ASSERT_EQUAL((uint16_t)6882, attrs->nodes[0].second);
   }
   {
     // port missing
@@ -542,10 +523,10 @@ void BittorrentHelperTest::testGetNodes()
     SharedHandle<DownloadContext> dctx(new DownloadContext());
     loadFromMemory(memory, dctx, "default");
 
-    const BDE& nodes = getNodes(dctx);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, nodes.size());
-    CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), nodes[0][HOSTNAME].s());
-    CPPUNIT_ASSERT_EQUAL((uint16_t)6882, (uint16_t)nodes[0][PORT].i());
+    SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+    CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->nodes.size());
+    CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), attrs->nodes[0].first);
+    CPPUNIT_ASSERT_EQUAL((uint16_t)6882, attrs->nodes[0].second);
   }
   {
     // nodes is not a list
@@ -559,7 +540,8 @@ void BittorrentHelperTest::testGetNodes()
     SharedHandle<DownloadContext> dctx(new DownloadContext());
     loadFromMemory(memory, dctx, "default");
 
-    CPPUNIT_ASSERT_EQUAL((size_t)0, getNodes(dctx).size());
+    SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+    CPPUNIT_ASSERT_EQUAL((size_t)0, attrs->nodes.size());
   }
   {
     // the element of node is not Data
@@ -574,10 +556,10 @@ void BittorrentHelperTest::testGetNodes()
     SharedHandle<DownloadContext> dctx(new DownloadContext());
     loadFromMemory(memory, dctx, "default");
 
-    const BDE& nodes = getNodes(dctx);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, nodes.size());
-    CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), nodes[0][HOSTNAME].s());
-    CPPUNIT_ASSERT_EQUAL((uint16_t)6882, (uint16_t)nodes[0][PORT].i());
+    SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+    CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->nodes.size());
+    CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), attrs->nodes[0].first);
+    CPPUNIT_ASSERT_EQUAL((uint16_t)6882, attrs->nodes[0].second);
   }
 }
 
@@ -643,11 +625,12 @@ void BittorrentHelperTest::testUTF8Torrent()
 {
   SharedHandle<DownloadContext> dctx(new DownloadContext());
   load("utf8.torrent", dctx);
-  CPPUNIT_ASSERT_EQUAL(std::string("name in utf-8"), getName(dctx));
+  CPPUNIT_ASSERT_EQUAL(std::string("name in utf-8"),
+                       getTorrentAttrs(dctx)->name);
   CPPUNIT_ASSERT_EQUAL(std::string("./name in utf-8/path in utf-8"),
                        dctx->getFirstFileEntry()->getPath());
   CPPUNIT_ASSERT_EQUAL(std::string("This is utf8 comment."),
-                       dctx->getAttribute(BITTORRENT)[COMMENT].s());
+                       getTorrentAttrs(dctx)->comment);
 }
 
 void BittorrentHelperTest::testEtc()
@@ -655,11 +638,11 @@ void BittorrentHelperTest::testEtc()
   SharedHandle<DownloadContext> dctx(new DownloadContext());
   load("test.torrent", dctx);
   CPPUNIT_ASSERT_EQUAL(std::string("REDNOAH.COM RULES"),
-                       dctx->getAttribute(BITTORRENT)[COMMENT].s());
+                       getTorrentAttrs(dctx)->comment);
   CPPUNIT_ASSERT_EQUAL(std::string("aria2"),
-                       dctx->getAttribute(BITTORRENT)[CREATED_BY].s());
-  CPPUNIT_ASSERT_EQUAL((int64_t)1123456789,
-                       dctx->getAttribute(BITTORRENT)[CREATION_DATE].i());
+                       getTorrentAttrs(dctx)->createdBy);
+  CPPUNIT_ASSERT_EQUAL((time_t)1123456789,
+                       getTorrentAttrs(dctx)->creationDate);
 }
 
 void BittorrentHelperTest::testCreatecompact()
@@ -698,13 +681,12 @@ void BittorrentHelperTest::testMetadata() {
   SharedHandle<DownloadContext> dctx(new DownloadContext());
   load("test.torrent", dctx);
   std::string torrentData = readFile("test.torrent");
-  BDE tr = bencode::decode(torrentData);
-  BDE infoDic = tr["info"];
-  std::string metadata = bencode::encode(infoDic);
-  const BDE& attrs = dctx->getAttribute(bittorrent::BITTORRENT);
-  CPPUNIT_ASSERT(metadata == attrs[bittorrent::METADATA].s());
-  CPPUNIT_ASSERT_EQUAL(metadata.size(),
-                       (size_t)attrs[bittorrent::METADATA_SIZE].i());
+  SharedHandle<ValueBase> tr = bencode2::decode(torrentData);
+  SharedHandle<ValueBase> infoDic = asDict(tr)->get("info");
+  std::string metadata = bencode2::encode(infoDic);
+  SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+  CPPUNIT_ASSERT(metadata == attrs->metadata);
+  CPPUNIT_ASSERT_EQUAL(metadata.size(), attrs->metadataSize);
 }
 
 void BittorrentHelperTest::testParseMagnet()
@@ -712,29 +694,28 @@ void BittorrentHelperTest::testParseMagnet()
   std::string magnet =
     "magnet:?xt=urn:btih:248d0a1cd08284299de78d5c1ed359bb46717d8c&dn=aria2"
     "&tr=http://tracker1&tr=http://tracker2";
-  BDE attrs = bittorrent::parseMagnet(magnet);
+  SharedHandle<TorrentAttribute> attrs = bittorrent::parseMagnet(magnet);
   CPPUNIT_ASSERT_EQUAL(std::string("248d0a1cd08284299de78d5c1ed359bb46717d8c"),
-                       util::toHex(attrs[bittorrent::INFO_HASH].s()));
-  CPPUNIT_ASSERT_EQUAL(std::string("[METADATA]aria2"),
-                       attrs[bittorrent::NAME].s());
-  CPPUNIT_ASSERT_EQUAL((size_t)2, attrs[bittorrent::ANNOUNCE_LIST].size());
+                       util::toHex(attrs->infoHash));
+  CPPUNIT_ASSERT_EQUAL(std::string("[METADATA]aria2"), attrs->name);
+  CPPUNIT_ASSERT_EQUAL((size_t)2, attrs->announceList.size());
   CPPUNIT_ASSERT_EQUAL(std::string("http://tracker1"),
-                       attrs[bittorrent::ANNOUNCE_LIST][0][0].s());
+                       attrs->announceList[0][0]);
   CPPUNIT_ASSERT_EQUAL(std::string("http://tracker2"),
-                       attrs[bittorrent::ANNOUNCE_LIST][1][0].s());
+                       attrs->announceList[1][0]);
 
   magnet = "magnet:?xt=urn:btih:248d0a1cd08284299de78d5c1ed359bb46717d8c";
   attrs = bittorrent::parseMagnet(magnet);
   CPPUNIT_ASSERT_EQUAL
     (std::string("[METADATA]248d0a1cd08284299de78d5c1ed359bb46717d8c"),
-     attrs[bittorrent::NAME].s());
-  CPPUNIT_ASSERT(attrs[bittorrent::ANNOUNCE_LIST].size() == 0);
+     attrs->name);
+  CPPUNIT_ASSERT(attrs->announceList.empty());
 
   magnet = "magnet:?xt=urn:sha1:7899bdb90a026c746f3cbc10839dd9b2a2a3e985&"
     "xt=urn:btih:248d0a1cd08284299de78d5c1ed359bb46717d8c";
   attrs = bittorrent::parseMagnet(magnet);
   CPPUNIT_ASSERT_EQUAL(std::string("248d0a1cd08284299de78d5c1ed359bb46717d8c"),
-                       util::toHex(attrs[bittorrent::INFO_HASH].s()));
+                       util::toHex(attrs->infoHash));
 }
 
 void BittorrentHelperTest::testParseMagnet_base32()
@@ -742,22 +723,20 @@ void BittorrentHelperTest::testParseMagnet_base32()
   std::string infoHash = "248d0a1cd08284299de78d5c1ed359bb46717d8c";
   std::string base32InfoHash = base32::encode(util::fromHex(infoHash));
   std::string magnet = "magnet:?xt=urn:btih:"+base32InfoHash+"&dn=aria2";
-  BDE attrs = bittorrent::parseMagnet(magnet);
+  SharedHandle<TorrentAttribute> attrs = bittorrent::parseMagnet(magnet);
   CPPUNIT_ASSERT_EQUAL
     (std::string("248d0a1cd08284299de78d5c1ed359bb46717d8c"),
-     util::toHex(attrs[bittorrent::INFO_HASH].s()));
+     util::toHex(attrs->infoHash));
 }
 
 void BittorrentHelperTest::testMetadata2Torrent()
 {
   std::string metadata = "METADATA";
-  BDE attrs = BDE::dict();
-  BDE announceList = BDE::list();
-  attrs[ANNOUNCE_LIST] = announceList;
+  SharedHandle<TorrentAttribute> attrs(new TorrentAttribute());
   CPPUNIT_ASSERT_EQUAL
     (std::string("d4:infoMETADATAe"), metadata2Torrent(metadata, attrs));
-  announceList << BDE::list();
-  announceList[0] << std::string("http://localhost/announce");
+  attrs->announceList.push_back(std::vector<std::string>());
+  attrs->announceList[0].push_back("http://localhost/announce");
   CPPUNIT_ASSERT_EQUAL
     (std::string("d"
                  "13:announce-list"
@@ -778,7 +757,44 @@ void BittorrentHelperTest::testTorrent2Magnet()
                  "&tr=http%3A%2F%2Ftracker1"
                  "&tr=http%3A%2F%2Ftracker2"
                  "&tr=http%3A%2F%2Ftracker3"),
-     torrent2Magnet(dctx->getAttribute(BITTORRENT)));
+     torrent2Magnet(getTorrentAttrs(dctx)));
+}
+
+void BittorrentHelperTest::testExtractPeerFromList()
+{
+  std::string peersString =
+    "d5:peersld2:ip11:192.168.0.17:peer id20:aria2-00000000000000"
+    "4:porti2006eeee";
+
+  SharedHandle<ValueBase> dict = bencode2::decode(peersString);
+  
+  std::deque<SharedHandle<Peer> > peers;
+  extractPeer(asDict(dict)->get("peers"), std::back_inserter(peers));
+  CPPUNIT_ASSERT_EQUAL((size_t)1, peers.size());
+  SharedHandle<Peer> peer = *peers.begin();
+  CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"), peer->getIPAddress());
+  CPPUNIT_ASSERT_EQUAL((uint16_t)2006, peer->getPort());
+}
+
+void BittorrentHelperTest::testExtract2PeersFromList()
+{
+  std::string peersString =
+    "d5:peersld2:ip11:192.168.0.17:peer id20:aria2-00000000000000"
+    "4:porti65535eed2:ip11:192.168.0.27:peer id20:aria2-00000000000000"
+    "4:porti2007eeee";
+
+  SharedHandle<ValueBase> dict = bencode2::decode(peersString);
+
+  std::deque<SharedHandle<Peer> > peers;
+  extractPeer(asDict(dict)->get("peers"), std::back_inserter(peers));
+  CPPUNIT_ASSERT_EQUAL((size_t)2, peers.size());
+  SharedHandle<Peer> peer = *peers.begin();
+  CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"), peer->getIPAddress());
+  CPPUNIT_ASSERT_EQUAL((uint16_t)65535, peer->getPort());
+
+  peer = *(peers.begin()+1);
+  CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), peer->getIPAddress());
+  CPPUNIT_ASSERT_EQUAL((uint16_t)2007, peer->getPort());
 }
 
 } // namespace bittorrent
