@@ -1,4 +1,11 @@
 #include "DHTRoutingTableSerializer.h"
+
+#include <cstring>
+#include <sstream>
+#include <iostream>
+
+#include <cppunit/extensions/HelperMacros.h>
+
 #include "Exception.h"
 #include "util.h"
 #include "DHTNode.h"
@@ -6,10 +13,6 @@
 #include "DHTConstants.h"
 #include "bittorrent_helper.h"
 #include "a2netcompat.h"
-#include <cstring>
-#include <sstream>
-#include <iostream>
-#include <cppunit/extensions/HelperMacros.h>
 
 namespace aria2 {
 
@@ -34,13 +37,13 @@ void DHTRoutingTableSerializerTest::testSerialize()
   SharedHandle<DHTNode> localNode(new DHTNode());
 
   SharedHandle<DHTNode> nodesSrc[3];
-  for(size_t i = 0; i < arrayLength(nodesSrc); ++i) {
+  for(size_t i = 0; i < A2_ARRAY_LEN(nodesSrc); ++i) {
     nodesSrc[i].reset(new DHTNode());
     nodesSrc[i]->setIPAddress("192.168.0."+util::uitos(i+1));
     nodesSrc[i]->setPort(6881+i);
   }
   nodesSrc[1]->setIPAddress("non-numerical-name");
-  std::deque<SharedHandle<DHTNode> > nodes(&nodesSrc[0], &nodesSrc[arrayLength(nodesSrc)]);
+  std::vector<SharedHandle<DHTNode> > nodes(vbegin(nodesSrc), vend(nodesSrc));
   
   DHTRoutingTableSerializer s;
   s.setLocalNode(localNode);
