@@ -2,7 +2,6 @@
 
 #include <iostream>
 #include <string>
-#include <deque>
 #include <algorithm>
 
 #include <cppunit/extensions/HelperMacros.h>
@@ -36,11 +35,11 @@ class DownloadHelperTest:public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE_END();
 private:
-  SharedHandle<Option> _option;
+  SharedHandle<Option> option_;
 public:
   void setUp()
   {
-    _option.reset(new Option());
+    option_.reset(new Option());
   }
 
   void tearDown() {}
@@ -70,81 +69,68 @@ void DownloadHelperTest::testCreateRequestGroupForUri()
     "http://bravo/file",
     "http://charlie/file"
   };
-  std::deque<std::string> uris(&array[0], &array[arrayLength(array)]);
-  _option->put(PREF_SPLIT, "3");
-  _option->put(PREF_DIR, "/tmp");
-  _option->put(PREF_OUT, "file.out");
+  std::vector<std::string> uris(vbegin(array), vend(array));
+  option_->put(PREF_SPLIT, "7");
+  option_->put(PREF_MAX_CONNECTION_PER_SERVER, "2");
+  option_->put(PREF_DIR, "/tmp");
+  option_->put(PREF_OUT, "file.out");
   {
-    std::deque<SharedHandle<RequestGroup> > result;
-    
-    createRequestGroupForUri(result, _option, uris);
-    
+    std::vector<SharedHandle<RequestGroup> > result;
+    createRequestGroupForUri(result, option_, uris);
     CPPUNIT_ASSERT_EQUAL((size_t)1, result.size());
     SharedHandle<RequestGroup> group = result[0];
-    std::deque<std::string> uris;
-    group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
-    CPPUNIT_ASSERT_EQUAL((size_t)3, uris.size());
-    for(size_t i = 0; i < arrayLength(array); ++i) {
-      CPPUNIT_ASSERT_EQUAL(array[i], uris[i]);
+    std::vector<std::string> xuris;
+    group->getDownloadContext()->getFirstFileEntry()->getUris(xuris);
+    CPPUNIT_ASSERT_EQUAL((size_t)6, xuris.size());
+    for(size_t i = 0; i < 6; ++i) {
+      CPPUNIT_ASSERT_EQUAL(array[i%3], xuris[i]);
     }
-    CPPUNIT_ASSERT_EQUAL((unsigned int)3, group->getNumConcurrentCommand());
+    CPPUNIT_ASSERT_EQUAL((unsigned int)7, group->getNumConcurrentCommand());
     SharedHandle<DownloadContext> ctx = group->getDownloadContext();
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), ctx->getDir());
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp/file.out"), ctx->getBasePath());
   }
-  _option->put(PREF_SPLIT, "5");
+  option_->put(PREF_SPLIT, "5");
   {
-    std::deque<SharedHandle<RequestGroup> > result;
-    
-    createRequestGroupForUri(result, _option, uris);
-    
+    std::vector<SharedHandle<RequestGroup> > result;
+    createRequestGroupForUri(result, option_, uris);
     CPPUNIT_ASSERT_EQUAL((size_t)1, result.size());
     SharedHandle<RequestGroup> group = result[0];
-    std::deque<std::string> uris;
-    group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
-    CPPUNIT_ASSERT_EQUAL((size_t)5, uris.size());
-    for(size_t i = 0; i < arrayLength(array); ++i) {
-      CPPUNIT_ASSERT_EQUAL(array[i], uris[i]);
+    std::vector<std::string> xuris;
+    group->getDownloadContext()->getFirstFileEntry()->getUris(xuris);
+    CPPUNIT_ASSERT_EQUAL((size_t)5, xuris.size());
+    for(size_t i = 0; i < 5; ++i) {
+      CPPUNIT_ASSERT_EQUAL(array[i%3], xuris[i]);
     }
-    for(size_t i = 0; i < 5-arrayLength(array); ++i) {
-      CPPUNIT_ASSERT_EQUAL(array[i], uris[i+arrayLength(array)]);
-    }
-    CPPUNIT_ASSERT_EQUAL((unsigned int)5, group->getNumConcurrentCommand());
   }
-  _option->put(PREF_SPLIT, "2");
+  option_->put(PREF_SPLIT, "2");
   {
-    std::deque<SharedHandle<RequestGroup> > result;
-    
-    createRequestGroupForUri(result, _option, uris);
-    
+    std::vector<SharedHandle<RequestGroup> > result;
+    createRequestGroupForUri(result, option_, uris);
     CPPUNIT_ASSERT_EQUAL((size_t)1, result.size());
     SharedHandle<RequestGroup> group = result[0];
-    std::deque<std::string> uris;
-    group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
-    CPPUNIT_ASSERT_EQUAL((size_t)3, uris.size());
-    for(size_t i = 0; i < arrayLength(array); ++i) {
-      CPPUNIT_ASSERT_EQUAL(array[i], uris[i]);
+    std::vector<std::string> xuris;
+    group->getDownloadContext()->getFirstFileEntry()->getUris(xuris);
+    CPPUNIT_ASSERT_EQUAL((size_t)3, xuris.size());
+    for(size_t i = 0; i < 3; ++i) {
+      CPPUNIT_ASSERT_EQUAL(array[i%3], xuris[i]);
     }
-    CPPUNIT_ASSERT_EQUAL((unsigned int)2, group->getNumConcurrentCommand());
   }
-  _option->put(PREF_FORCE_SEQUENTIAL, V_TRUE);
+  option_->put(PREF_FORCE_SEQUENTIAL, V_TRUE);
   {
-    std::deque<SharedHandle<RequestGroup> > result;
-    
-    createRequestGroupForUri(result, _option, uris);
-    
+    std::vector<SharedHandle<RequestGroup> > result;
+    createRequestGroupForUri(result, option_, uris);
     CPPUNIT_ASSERT_EQUAL((size_t)3, result.size());
-
     // for alpha server
     SharedHandle<RequestGroup> alphaGroup = result[0];
-    std::deque<std::string> alphaURIs;
+    std::vector<std::string> alphaURIs;
     alphaGroup->getDownloadContext()->getFirstFileEntry()->getUris(alphaURIs);
     CPPUNIT_ASSERT_EQUAL((size_t)2, alphaURIs.size());
     for(size_t i = 0; i < 2; ++i) {
-      CPPUNIT_ASSERT_EQUAL(array[0], uris[0]);
+      CPPUNIT_ASSERT_EQUAL(array[0], alphaURIs[i]);
     }
     CPPUNIT_ASSERT_EQUAL((unsigned int)2,
-			 alphaGroup->getNumConcurrentCommand());
+                         alphaGroup->getNumConcurrentCommand());
     SharedHandle<DownloadContext> alphaCtx = alphaGroup->getDownloadContext();
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), alphaCtx->getDir());
     // See filename is not assigned yet
@@ -158,19 +144,20 @@ void DownloadHelperTest::testCreateRequestGroupForUri_parameterized()
     "http://{alpha, bravo}/file",
     "http://charlie/file"
   };
-  std::deque<std::string> uris(&array[0], &array[arrayLength(array)]);
-  _option->put(PREF_SPLIT, "3");
-  _option->put(PREF_DIR, "/tmp");
-  _option->put(PREF_OUT, "file.out");
-  _option->put(PREF_PARAMETERIZED_URI, V_TRUE);
+  std::vector<std::string> uris(vbegin(array), vend(array));
+  option_->put(PREF_MAX_CONNECTION_PER_SERVER, "1");
+  option_->put(PREF_SPLIT, "3");
+  option_->put(PREF_DIR, "/tmp");
+  option_->put(PREF_OUT, "file.out");
+  option_->put(PREF_PARAMETERIZED_URI, V_TRUE);
   {
-    std::deque<SharedHandle<RequestGroup> > result;
+    std::vector<SharedHandle<RequestGroup> > result;
     
-    createRequestGroupForUri(result, _option, uris);
+    createRequestGroupForUri(result, option_, uris);
     
     CPPUNIT_ASSERT_EQUAL((size_t)1, result.size());
     SharedHandle<RequestGroup> group = result[0];
-    std::deque<std::string> uris;
+    std::vector<std::string> uris;
     group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
     CPPUNIT_ASSERT_EQUAL((size_t)3, uris.size());
 
@@ -194,41 +181,42 @@ void DownloadHelperTest::testCreateRequestGroupForUri_BitTorrent()
     "http://bravo/file",
     "http://charlie/file"
   };
-  std::deque<std::string> uris(&array[0], &array[arrayLength(array)]);
-  _option->put(PREF_SPLIT, "3");
-  _option->put(PREF_DIR, "/tmp");
-  _option->put(PREF_OUT, "file.out");
+  std::vector<std::string> uris(vbegin(array), vend(array));
+  option_->put(PREF_MAX_CONNECTION_PER_SERVER, "1");
+  option_->put(PREF_SPLIT, "3");
+  option_->put(PREF_DIR, "/tmp");
+  option_->put(PREF_OUT, "file.out");
   {
-    std::deque<SharedHandle<RequestGroup> > result;
+    std::vector<SharedHandle<RequestGroup> > result;
     
-    createRequestGroupForUri(result, _option, uris);
+    createRequestGroupForUri(result, option_, uris);
     
     CPPUNIT_ASSERT_EQUAL((size_t)2, result.size());
     SharedHandle<RequestGroup> group = result[0];
-    std::deque<std::string> uris;
-    group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
-    CPPUNIT_ASSERT_EQUAL((size_t)3, uris.size());
+    std::vector<std::string> xuris;
+    group->getDownloadContext()->getFirstFileEntry()->getUris(xuris);
+    CPPUNIT_ASSERT_EQUAL((size_t)3, xuris.size());
 
-    CPPUNIT_ASSERT_EQUAL(array[0], uris[0]);
-    CPPUNIT_ASSERT_EQUAL(array[2], uris[1]);
-    CPPUNIT_ASSERT_EQUAL(array[3], uris[2]);
+    CPPUNIT_ASSERT_EQUAL(array[0], xuris[0]);
+    CPPUNIT_ASSERT_EQUAL(array[2], xuris[1]);
+    CPPUNIT_ASSERT_EQUAL(array[3], xuris[2]);
 
     CPPUNIT_ASSERT_EQUAL((unsigned int)3, group->getNumConcurrentCommand());
     SharedHandle<DownloadContext> ctx = group->getDownloadContext();
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), ctx->getDir());
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp/file.out"),
-			 ctx->getBasePath());
+                         ctx->getBasePath());
 
     SharedHandle<RequestGroup> torrentGroup = result[1];
-    std::deque<std::string> auxURIs;
+    std::vector<std::string> auxURIs;
     torrentGroup->getDownloadContext()->getFirstFileEntry()->getUris(auxURIs);
     CPPUNIT_ASSERT(auxURIs.empty());
     CPPUNIT_ASSERT_EQUAL((unsigned int)3,
-			 torrentGroup->getNumConcurrentCommand());
+                         torrentGroup->getNumConcurrentCommand());
     SharedHandle<DownloadContext> btctx = torrentGroup->getDownloadContext();
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), btctx->getDir());
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp/aria2-test"),
-			 btctx->getBasePath());    
+                         btctx->getBasePath());    
   }
 }
 #endif // ENABLE_BITTORRENT
@@ -242,15 +230,16 @@ void DownloadHelperTest::testCreateRequestGroupForUri_Metalink()
     "http://charlie/file",
     "test.xml"
   };
-  std::deque<std::string> uris(&array[0], &array[arrayLength(array)]);
-  _option->put(PREF_SPLIT, "3");
-  _option->put(PREF_METALINK_SERVERS, "2");
-  _option->put(PREF_DIR, "/tmp");
-  _option->put(PREF_OUT, "file.out");
+  std::vector<std::string> uris(vbegin(array), vend(array));
+  option_->put(PREF_MAX_CONNECTION_PER_SERVER, "1");
+  option_->put(PREF_SPLIT, "3");
+  option_->put(PREF_METALINK_SERVERS, "2");
+  option_->put(PREF_DIR, "/tmp");
+  option_->put(PREF_OUT, "file.out");
   {
-    std::deque<SharedHandle<RequestGroup> > result;
+    std::vector<SharedHandle<RequestGroup> > result;
     
-    createRequestGroupForUri(result, _option, uris);
+    createRequestGroupForUri(result, option_, uris);
     
     // group1: http://alpha/file, ...
     // group2-7: 6 file entry in Metalink and 1 torrent file download
@@ -261,49 +250,50 @@ void DownloadHelperTest::testCreateRequestGroupForUri_Metalink()
 #endif // !ENABLE_BITTORRENT
 
     SharedHandle<RequestGroup> group = result[0];
-    std::deque<std::string> uris;
-    group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
-    CPPUNIT_ASSERT_EQUAL((size_t)3, uris.size());
+    std::vector<std::string> xuris;
+    group->getDownloadContext()->getFirstFileEntry()->getUris(xuris);
+    CPPUNIT_ASSERT_EQUAL((size_t)3, xuris.size());
     for(size_t i = 0; i < 3; ++i) {
-      CPPUNIT_ASSERT_EQUAL(array[i], uris[i]);
+      CPPUNIT_ASSERT_EQUAL(array[i], xuris[i]);
     }
     CPPUNIT_ASSERT_EQUAL((unsigned int)3, group->getNumConcurrentCommand());
     SharedHandle<DownloadContext> ctx = group->getDownloadContext();
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), ctx->getDir());
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp/file.out"),
-			 ctx->getBasePath());
+                         ctx->getBasePath());
 
     SharedHandle<RequestGroup> aria2052Group = result[1];
     CPPUNIT_ASSERT_EQUAL((unsigned int)1, // because of maxconnections attribute
-			 aria2052Group->getNumConcurrentCommand());
+                         aria2052Group->getNumConcurrentCommand());
     SharedHandle<DownloadContext> aria2052Ctx =
       aria2052Group->getDownloadContext();
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), aria2052Ctx->getDir());
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp/aria2-0.5.2.tar.bz2"),
-			 aria2052Ctx->getBasePath());
+                         aria2052Ctx->getBasePath());
     
     SharedHandle<RequestGroup> aria2051Group = result[2];
     CPPUNIT_ASSERT_EQUAL((unsigned int)2,
-			 aria2051Group->getNumConcurrentCommand());
+                         aria2051Group->getNumConcurrentCommand());
   }
 }
 #endif // ENABLE_METALINK
 
 void DownloadHelperTest::testCreateRequestGroupForUriList()
 {
-  _option->put(PREF_SPLIT, "3");
-  _option->put(PREF_INPUT_FILE, "input_uris.txt");
-  _option->put(PREF_DIR, "/tmp");
-  _option->put(PREF_OUT, "file.out");
+  option_->put(PREF_MAX_CONNECTION_PER_SERVER, "3");
+  option_->put(PREF_SPLIT, "3");
+  option_->put(PREF_INPUT_FILE, "input_uris.txt");
+  option_->put(PREF_DIR, "/tmp");
+  option_->put(PREF_OUT, "file.out");
 
-  std::deque<SharedHandle<RequestGroup> > result;
+  std::vector<SharedHandle<RequestGroup> > result;
   
-  createRequestGroupForUriList(result, _option);
+  createRequestGroupForUriList(result, option_);
 
   CPPUNIT_ASSERT_EQUAL((size_t)2, result.size());
 
   SharedHandle<RequestGroup> fileGroup = result[0];
-  std::deque<std::string> fileURIs;
+  std::vector<std::string> fileURIs;
   fileGroup->getDownloadContext()->getFirstFileEntry()->getUris(fileURIs);
   CPPUNIT_ASSERT_EQUAL(std::string("http://alpha/file"), fileURIs[0]);
   CPPUNIT_ASSERT_EQUAL(std::string("http://bravo/file"), fileURIs[1]);
@@ -312,13 +302,13 @@ void DownloadHelperTest::testCreateRequestGroupForUriList()
   SharedHandle<DownloadContext> fileCtx = fileGroup->getDownloadContext();
   CPPUNIT_ASSERT_EQUAL(std::string("/mydownloads"), fileCtx->getDir());
   CPPUNIT_ASSERT_EQUAL(std::string("/mydownloads/myfile.out"),
-		       fileCtx->getBasePath());
+                       fileCtx->getBasePath());
 
   SharedHandle<RequestGroup> fileISOGroup = result[1];
   SharedHandle<DownloadContext> fileISOCtx = fileISOGroup->getDownloadContext();
   CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), fileISOCtx->getDir());
   CPPUNIT_ASSERT_EQUAL(std::string("/tmp/file.out"),
-		       fileISOCtx->getBasePath());
+                       fileISOCtx->getBasePath());
 }
 
 #ifdef ENABLE_BITTORRENT
@@ -330,45 +320,47 @@ void DownloadHelperTest::testCreateRequestGroupForBitTorrent()
     "http://charlie/file"
   };
 
-  std::deque<std::string> auxURIs(&array[0], &array[arrayLength(array)]);
-  _option->put(PREF_SPLIT, "5");
-  _option->put(PREF_TORRENT_FILE, "test.torrent");
-  _option->put(PREF_DIR, "/tmp");
-  _option->put(PREF_OUT, "file.out");
+  std::vector<std::string> auxURIs(vbegin(array), vend(array));
+  option_->put(PREF_MAX_CONNECTION_PER_SERVER, "2");
+  option_->put(PREF_SPLIT, "5");
+  option_->put(PREF_TORRENT_FILE, "test.torrent");
+  option_->put(PREF_DIR, "/tmp");
+  option_->put(PREF_OUT, "file.out");
   {
-    std::deque<SharedHandle<RequestGroup> > result;
+    std::vector<SharedHandle<RequestGroup> > result;
   
-    createRequestGroupForBitTorrent(result, _option, auxURIs);
+    createRequestGroupForBitTorrent(result, option_, auxURIs);
 
     CPPUNIT_ASSERT_EQUAL((size_t)1, result.size());
 
     SharedHandle<RequestGroup> group = result[0];
-    std::deque<std::string> uris;
+    std::vector<std::string> uris;
     group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
-    // See -s option is ignored
+    // See -s option is ignored. See processRootDictionary() in
+    // bittorrent_helper.cc
     CPPUNIT_ASSERT_EQUAL((size_t)3, uris.size());
-    for(size_t i = 0; i < arrayLength(array); ++i) {
+    for(size_t i = 0; i < A2_ARRAY_LEN(array); ++i) {
       CPPUNIT_ASSERT_EQUAL(array[i]+"/aria2-test/aria2/src/aria2c", uris[i]);
     }
     CPPUNIT_ASSERT_EQUAL((unsigned int)5, group->getNumConcurrentCommand());
   }
   {
     // no URIs are given
-    std::deque<SharedHandle<RequestGroup> > result;
-    std::deque<std::string> emptyURIs;
-    createRequestGroupForBitTorrent(result, _option, emptyURIs);
+    std::vector<SharedHandle<RequestGroup> > result;
+    std::vector<std::string> emptyURIs;
+    createRequestGroupForBitTorrent(result, option_, emptyURIs);
 
     CPPUNIT_ASSERT_EQUAL((size_t)1, result.size());
     SharedHandle<RequestGroup> group = result[0];
-    std::deque<std::string> uris;
+    std::vector<std::string> uris;
     group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
     CPPUNIT_ASSERT_EQUAL((size_t)0, uris.size());
   }
-  _option->put(PREF_FORCE_SEQUENTIAL, V_TRUE);
+  option_->put(PREF_FORCE_SEQUENTIAL, V_TRUE);
   {
-    std::deque<SharedHandle<RequestGroup> > result;
+    std::vector<SharedHandle<RequestGroup> > result;
   
-    createRequestGroupForBitTorrent(result, _option, auxURIs);
+    createRequestGroupForBitTorrent(result, option_, auxURIs);
 
     // See --force-requencial is ignored
     CPPUNIT_ASSERT_EQUAL((size_t)1, result.size());
@@ -379,15 +371,15 @@ void DownloadHelperTest::testCreateRequestGroupForBitTorrent()
 #ifdef ENABLE_METALINK
 void DownloadHelperTest::testCreateRequestGroupForMetalink()
 {
-  _option->put(PREF_SPLIT, "3");
-  _option->put(PREF_METALINK_FILE, "test.xml");
-  _option->put(PREF_METALINK_SERVERS, "5");
-  _option->put(PREF_DIR, "/tmp");
-  _option->put(PREF_OUT, "file.out");
+  option_->put(PREF_SPLIT, "3");
+  option_->put(PREF_METALINK_FILE, "test.xml");
+  option_->put(PREF_METALINK_SERVERS, "5");
+  option_->put(PREF_DIR, "/tmp");
+  option_->put(PREF_OUT, "file.out");
   {
-    std::deque<SharedHandle<RequestGroup> > result;
+    std::vector<SharedHandle<RequestGroup> > result;
   
-    createRequestGroupForMetalink(result, _option);
+    createRequestGroupForMetalink(result, option_);
 
 #ifdef ENABLE_BITTORRENT
     CPPUNIT_ASSERT_EQUAL((size_t)6, result.size());
@@ -395,14 +387,14 @@ void DownloadHelperTest::testCreateRequestGroupForMetalink()
     CPPUNIT_ASSERT_EQUAL((size_t)5, result.size());
 #endif // !ENABLE_BITTORRENT
     SharedHandle<RequestGroup> group = result[0];
-    std::deque<std::string> uris;
+    std::vector<std::string> uris;
     group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
     std::sort(uris.begin(), uris.end());
     CPPUNIT_ASSERT_EQUAL((size_t)2, uris.size());
     CPPUNIT_ASSERT_EQUAL(std::string("ftp://ftphost/aria2-0.5.2.tar.bz2"),
-			 uris[0]);
+                         uris[0]);
     CPPUNIT_ASSERT_EQUAL(std::string("http://httphost/aria2-0.5.2.tar.bz2"),
-			 uris[1]);
+                         uris[1]);
     // See numConcurrentCommand is 1 because of maxconnections attribute.
     CPPUNIT_ASSERT_EQUAL((unsigned int)1, group->getNumConcurrentCommand());
   }
