@@ -31,7 +31,7 @@ void GZipDecoderTest::testDecode()
   GZipDecoder decoder;
   decoder.init();
 
-  std::string outfile("/tmp/aria2_GZipDecoderTest_testDecode");
+  std::string outfile("./aria2_GZipDecoderTest_testDecode");
 
   char buf[4096];
   std::ifstream in("gzip_decode_test.gz", std::ios::binary);
@@ -51,8 +51,8 @@ void GZipDecoderTest::testDecode()
 
 #ifdef ENABLE_MESSAGE_DIGEST
   CPPUNIT_ASSERT_EQUAL(std::string("8b577b33c0411b2be9d4fa74c7402d54a8d21f96"),
-		       MessageDigestHelper::digest(MessageDigestContext::SHA1,
-						   outfile));
+                       MessageDigestHelper::digest(MessageDigestContext::SHA1,
+                                                   outfile));
 #endif // ENABLE_MESSAGE_DIGEST
 }
 
