@@ -29,6 +29,7 @@ class HttpRequestTest : public CppUnit::TestFixture {
   CPPUNIT_TEST(testCreateRequest_query);
   CPPUNIT_TEST(testCreateRequest_head);
   CPPUNIT_TEST(testCreateRequest_ipv6LiteralAddr);
+  CPPUNIT_TEST(testCreateRequest_endOffsetOverride);
   CPPUNIT_TEST(testCreateProxyRequest);
   CPPUNIT_TEST(testIsRangeSatisfied);
   CPPUNIT_TEST(testUserAgent);
@@ -37,14 +38,14 @@ class HttpRequestTest : public CppUnit::TestFixture {
   CPPUNIT_TEST(testEnableAcceptEncoding);
   CPPUNIT_TEST_SUITE_END();
 private:
-  SharedHandle<Option> _option;
-  SharedHandle<AuthConfigFactory> _authConfigFactory;
+  SharedHandle<Option> option_;
+  SharedHandle<AuthConfigFactory> authConfigFactory_;
 public:
   void setUp()
   {
-    _option.reset(new Option());
-    _option->put(PREF_HTTP_AUTH_CHALLENGE, V_TRUE);
-    _authConfigFactory.reset(new AuthConfigFactory());
+    option_.reset(new Option());
+    option_->put(PREF_HTTP_AUTH_CHALLENGE, V_TRUE);
+    authConfigFactory_.reset(new AuthConfigFactory());
   }
 
   void testGetStartByte();
@@ -55,6 +56,7 @@ public:
   void testCreateRequest_query();
   void testCreateRequest_head();
   void testCreateRequest_ipv6LiteralAddr();
+  void testCreateRequest_endOffsetOverride();
   void testCreateProxyRequest();
   void testIsRangeSatisfied();
   void testUserAgent();
@@ -137,7 +139,7 @@ void HttpRequestTest::testCreateRequest()
   httpRequest.setRequest(request);
   httpRequest.setSegment(segment);
   httpRequest.setFileEntry(fileEntry);
-  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
+  httpRequest.setAuthConfigFactory(authConfigFactory_, option_.get());
 
   // remove "Connection: close" and add end byte range
   request->setPipeliningHint(true);  
@@ -235,11 +237,11 @@ void HttpRequestTest::testCreateRequest()
   httpRequest.setSegment(segment);
 
   // enable http auth
-  _option->put(PREF_HTTP_USER, "aria2user");
-  _option->put(PREF_HTTP_PASSWD, "aria2passwd");
+  option_->put(PREF_HTTP_USER, "aria2user");
+  option_->put(PREF_HTTP_PASSWD, "aria2passwd");
 
-  CPPUNIT_ASSERT(_authConfigFactory->activateBasicCred
-                 ("localhost", "/", _option.get()));
+  CPPUNIT_ASSERT(authConfigFactory_->activateBasicCred
+                 ("localhost", "/", option_.get()));
 
   expectedText = "GET /archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
     "User-Agent: aria2\r\n"
@@ -310,8 +312,8 @@ void HttpRequestTest::testCreateRequest()
 
 void HttpRequestTest::testCreateRequest_ftp()
 {
-  _option->put(PREF_FTP_USER, "aria2user");
-  _option->put(PREF_FTP_PASSWD, "aria2passwd");
+  option_->put(PREF_FTP_USER, "aria2user");
+  option_->put(PREF_FTP_PASSWD, "aria2passwd");
 
   SharedHandle<Request> request(new Request());
   request->setUri("ftp://localhost:8080/archives/aria2-1.0.0.tar.bz2");
@@ -330,7 +332,7 @@ void HttpRequestTest::testCreateRequest_ftp()
   httpRequest.setRequest(request);
   httpRequest.setSegment(segment);
   httpRequest.setFileEntry(fileEntry);
-  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
+  httpRequest.setAuthConfigFactory(authConfigFactory_, option_.get());
   httpRequest.setProxyRequest(proxyRequest);
 
   std::string expectedText =
@@ -396,7 +398,7 @@ void HttpRequestTest::testCreateRequest_with_cookie()
   httpRequest.setSegment(segment);
   httpRequest.setFileEntry(fileEntry);
   httpRequest.setCookieStorage(st);
-  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
+  httpRequest.setAuthConfigFactory(authConfigFactory_, option_.get());
 
   std::string expectedText = "GET /archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
     "User-Agent: aria2\r\n"
@@ -462,7 +464,7 @@ void HttpRequestTest::testCreateRequest_query()
   HttpRequest httpRequest;
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
+  httpRequest.setAuthConfigFactory(authConfigFactory_, option_.get());
 
   std::string expectedText =
     "GET /wiki?id=9ad5109a-b8a5-4edf-9373-56a1c34ae138 HTTP/1.1\r\n"
@@ -485,7 +487,7 @@ void HttpRequestTest::testCreateRequest_head()
 
   HttpRequest httpRequest;
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
+  httpRequest.setAuthConfigFactory(authConfigFactory_, option_.get());
   
   std::stringstream result(httpRequest.createRequest());
   std::string line;
@@ -494,6 +496,50 @@ void HttpRequestTest::testCreateRequest_head()
   CPPUNIT_ASSERT_EQUAL(std::string("HEAD /aria2-1.0.0.tar.bz2 HTTP/1.1"), line);
 }
 
+void HttpRequestTest::testCreateRequest_endOffsetOverride()
+{
+  SharedHandle<Request> request(new Request());
+  request->setUri("http://localhost/myfile");
+  HttpRequest httpRequest;
+  httpRequest.disableContentEncoding();
+  httpRequest.setRequest(request);
+  httpRequest.setAuthConfigFactory(authConfigFactory_, option_.get());
+  SharedHandle<Piece> p(new Piece(0, 1024*1024));
+  SharedHandle<Segment> segment(new PiecedSegment(1024*1024, p));
+  httpRequest.setSegment(segment);
+  httpRequest.setEndOffsetOverride(1024*1024*1024);
+  SharedHandle<FileEntry> fileEntry
+    (new FileEntry("file", 1024*1024*1024*10LL, 0));
+  httpRequest.setFileEntry(fileEntry);
+  // End byte is not passed if start byte is 0.
+  std::string expectedText =
+    "GET /myfile HTTP/1.1\r\n"
+    "User-Agent: aria2\r\n"
+    "Accept: */*\r\n"
+    "Host: localhost\r\n"
+    "Pragma: no-cache\r\n"
+    "Cache-Control: no-cache\r\n"
+    "Connection: close\r\n"
+    "\r\n";
+  
+  CPPUNIT_ASSERT_EQUAL(expectedText, httpRequest.createRequest());
+
+  segment->updateWrittenLength(1);
+
+  expectedText =
+    "GET /myfile HTTP/1.1\r\n"
+    "User-Agent: aria2\r\n"
+    "Accept: */*\r\n"
+    "Host: localhost\r\n"
+    "Pragma: no-cache\r\n"
+    "Cache-Control: no-cache\r\n"
+    "Connection: close\r\n"
+    "Range: bytes=1-1073741823\r\n"
+    "\r\n";
+  
+  CPPUNIT_ASSERT_EQUAL(expectedText, httpRequest.createRequest());
+}
+
 void HttpRequestTest::testCreateProxyRequest()
 {
   SharedHandle<Request> request(new Request());
@@ -626,7 +672,7 @@ void HttpRequestTest::testUserAgent()
   httpRequest.setRequest(request);
   //httpRequest.setSegment(segment);
   httpRequest.setUserAgent("aria2 (Linux)");
-  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
+  httpRequest.setAuthConfigFactory(authConfigFactory_, option_.get());
 
   std::string expectedText = "GET /archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
     "User-Agent: aria2 (Linux)\r\n"
@@ -661,7 +707,7 @@ void HttpRequestTest::testAddHeader()
   HttpRequest httpRequest;
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
+  httpRequest.setAuthConfigFactory(authConfigFactory_, option_.get());
   httpRequest.addHeader("X-ARIA2: v0.13\nX-ARIA2-DISTRIBUTE: enabled\n");
   httpRequest.addHeader("Accept: text/html");
   std::string expectedText = "GET /archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
@@ -689,9 +735,8 @@ void HttpRequestTest::testAddAcceptType()
   HttpRequest httpRequest;
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
-  httpRequest.addAcceptType(&acceptTypes[0],
-                            &acceptTypes[arrayLength(acceptTypes)]);
+  httpRequest.setAuthConfigFactory(authConfigFactory_, option_.get());
+  httpRequest.addAcceptType(vbegin(acceptTypes), vend(acceptTypes));
 
   std::string expectedText =
     "GET /archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
@@ -713,27 +758,37 @@ void HttpRequestTest::testEnableAcceptEncoding()
 
   HttpRequest httpRequest;
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
+  httpRequest.setAuthConfigFactory(authConfigFactory_, option_.get());
 
   std::string acceptEncodings;
 #ifdef HAVE_LIBZ
   acceptEncodings += "deflate, gzip";
 #endif // HAVE_LIBZ
   
-  std::string expectedText =
+  std::string expectedTextHead =
     "GET /archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
     "User-Agent: aria2\r\n"
     "Accept: */*\r\n";
-  if(!acceptEncodings.empty()) {
-    expectedText += "Accept-Encoding: "+acceptEncodings+"\r\n";
-  }
-  expectedText +=
+  std::string expectedTextTail =
     "Host: localhost\r\n"
     "Pragma: no-cache\r\n"
     "Cache-Control: no-cache\r\n"
     "Connection: close\r\n"
     "\r\n";
 
+  std::string expectedText = expectedTextHead;
+  expectedText += expectedTextTail;
+  CPPUNIT_ASSERT_EQUAL(expectedText, httpRequest.createRequest());
+
+  expectedText = expectedTextHead;
+  if(!acceptEncodings.empty()) {
+    expectedText += "Accept-Encoding: ";
+    expectedText += acceptEncodings;
+    expectedText += "\r\n";
+  }
+  expectedText += expectedTextTail;
+
+  httpRequest.enableAcceptGZip();
   CPPUNIT_ASSERT_EQUAL(expectedText, httpRequest.createRequest());
 }
 
@@ -744,7 +799,7 @@ void HttpRequestTest::testCreateRequest_ipv6LiteralAddr()
   HttpRequest httpRequest;
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
+  httpRequest.setAuthConfigFactory(authConfigFactory_, option_.get());
 
   CPPUNIT_ASSERT(httpRequest.createRequest().find("Host: [::1]") != std::string::npos);
 
