@@ -20,19 +20,23 @@ public:
 
 CPPUNIT_TEST_SUITE_REGISTRATION(MagnetTest);
 
+static const std::string& nthStr(const SharedHandle<ValueBase>& v, size_t index)
+{
+  return asString(asList(v)->get(index))->s();
+}
+
 void MagnetTest::testParse()
 {
-  BDE r = parse
+  SharedHandle<Dict> r = parse
     ("magnet:?xt=urn:btih:248d0a1cd08284299de78d5c1ed359bb46717d8c&dn=aria2"
-     "&tr=http://tracker1&tr=http://tracker2");
+     "&tr=http%3A%2F%2Ftracker1&tr=http://tracker2");
   CPPUNIT_ASSERT_EQUAL
     (std::string("urn:btih:248d0a1cd08284299de78d5c1ed359bb46717d8c"),
-     r["xt"][0].s());
-  CPPUNIT_ASSERT_EQUAL(std::string("aria2"), r["dn"][0].s());
-  CPPUNIT_ASSERT_EQUAL(std::string("http://tracker1"), r["tr"][0].s());
-  CPPUNIT_ASSERT_EQUAL(std::string("http://tracker2"), r["tr"][1].s());
-
-  CPPUNIT_ASSERT(parse("http://localhost").isNone());
+     nthStr(r->get("xt"), 0));
+  CPPUNIT_ASSERT_EQUAL(std::string("aria2"), nthStr(r->get("dn"), 0));
+  CPPUNIT_ASSERT_EQUAL(std::string("http://tracker1"), nthStr(r->get("tr"), 0));
+  CPPUNIT_ASSERT_EQUAL(std::string("http://tracker2"), nthStr(r->get("tr"), 1));
+  CPPUNIT_ASSERT(parse("http://localhost").isNull());
 }
 
 } // namespace magnet
