@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -80,9 +80,7 @@ public:
 
   virtual void send() {}
 
-  virtual bool validate(std::deque<std::string>& errors) {
-    return false;
-  }
+  virtual void validate() {}
 
   virtual void onAbortOutstandingRequestEvent
   (const BtAbortOutstandingRequestEvent& event) {}
@@ -101,9 +99,9 @@ public:
 template<typename T>
 class WrapBtMessage:public MockBtMessage {
 public:
-  SharedHandle<T> _m;
+  SharedHandle<T> m_;
   
-  WrapBtMessage(const SharedHandle<T>& m):_m(m) {}
+  WrapBtMessage(const SharedHandle<T>& m):m_(m) {}
 };
 
 
